@@ -32,7 +32,7 @@ import org.broad.igv.ui.UIConstants;
 import org.broad.igv.ui.util.PropertyManager;
 import org.broad.igv.ui.util.ColorTable;
 import org.broad.igv.util.ColorUtilities;
-import org.broad.igv.util.IGVHttpClientUtils;
+import org.broad.igv.util.HttpUtils;
 
 import static org.broad.igv.ui.util.UIUtilities.getcommaSeparatedRGBString;
 
@@ -72,6 +72,7 @@ public class PreferenceManager implements PropertyManager {
     public static final String SAM_COMPUTE_INSERT_SIZE_THRESHOLD = "SAM.COMPUTE_ISZIE";
     public static final String SAM_AUTO_SORT = "SAM.AUTOSORT";
     public static final String SAM_SHADE_CENTER = "SAM.SHADE_CENTER";
+    public static final String SAM_SHOW_CENTER_LINE = "SAM.SHOW_CENTER_LINE";
     public static final String SAM_SHOW_REF_SEQ = "SAM.SHOW_REF_SEQ";
     public static final String SAM_SHOW_COV_TRACK = "SAM.SHOW_COV_TRACK";
     public static final String SAM_SHADE_BASE_QUALITY = "SAM.SHADE_BASE_QUALITY";
@@ -88,8 +89,11 @@ public class PreferenceManager implements PropertyManager {
     public static final String SAM_COLOR_BY = "SAM.COLOR_BY";
     public static final String SAM_FILTER_FAILED_READS = "SAM.FILTER_FAILED_READS";
     public static final String SAM_COMPUTE_ISIZES = "SAM.COMPUTE_ISIZES";
+    public static final String SAM_FLAG_ZERO_QUALITY = "SAM.FLAG_ZERO_QUALITY";
     //dhmay adding 20110208
     public static final String SAM_SHOW_JUNCTION_TRACK = "SAM.SHOW_JUNCTION_TRACK";
+    public static final String SAM_JUNCTION_MIN_FLANKING_WIDTH = "SAM.JUNCTION_MIN_FLANKING_WIDTH";
+    public static final String SAM_JUNCTION_MIN_COVERAGE = "SAM.JUNCTION_MIN_COVERAGE";
 
 
     public static final String EXPAND_FEAUTRE_TRACKS = "EXPAND_FEATURE_TRACKS";
@@ -100,6 +104,7 @@ public class PreferenceManager implements PropertyManager {
     final public static String RECENT_SESSION_KEY = "IGV.Session.recent.sessions";
     final public static String TRACK_HEIGHT_KEY = "IGV.track.height";
     final public static String CHART_TRACK_HEIGHT_KEY = "IGV.chart.track.height";
+    final public static String CHART_SHOW_ALL_HEATMAP = "CHART.SHOW_ALL_HEATMAP";
     final public static String SHOW_MISSING_DATA_KEY = "IGV.track.show.missing.data";
     final public static String SHOW_ATTRIBUTE_VIEWS_KEY = "IGV.track.show.attribute.views";
     final public static String SHOW_SINGLE_TRACK_PANE_KEY = "IGV.single.track.pane";
@@ -127,7 +132,7 @@ public class PreferenceManager implements PropertyManager {
     final public static String ENABLE_LINKED_SORTING = "ENABLE_LINKED_SORTING";
     final public static String TRACK_ATTRIBUTE_NAME_KEY = "TRACK_ATTRIBUTE_NAME_KEY";
     final public static String DATA_SERVER_URL_KEY = "MASTER_RESOURCE_FILE_KEY";
-    final public static String CHECKED_RESOURCES_KEY = "CHECKED_RESOURCES_KEY";
+    //final public static String CHECKED_RESOURCES_KEY = "CHECKED_RESOURCES_KEY";
     final public static String DEFINE_GENOME_INPUT_DIRECTORY_KEY = "DEFINE_GENOME_INPUT_DIRECTORY_KEY";
     final public static String MAF_SPECIES_KEY = "MAF_SPECIES_KEY";
     final public static String PROBE_MAPPING_KEY = "PROBE_MAPPING_KEY";
@@ -142,6 +147,7 @@ public class PreferenceManager implements PropertyManager {
     final public static String PROXY_HOST = "PROXY.HOST";
     final public static String PROXY_PORT = "PROXY.PORT";
     final public static String PROXY_AUTHENTICATE = "PROXY.AUTHENTICATE";
+    final public static String PROXY_NTLM = "PROXY.NTLM";
     final public static String PROXY_USER = "PROXY.USERNAME";
     final public static String PROXY_PW = "PROXY.PW";
 
@@ -173,6 +179,26 @@ public class PreferenceManager implements PropertyManager {
     public static final String NAME_PANEL_WIDTH = "NAME_PANEL_WIDTH";
     public static final String BACKGROUND_COLOR = "BACKGROUND_COLOR";
 
+    public static final String GENOME_SPACE_ENABLE = "GENOME_SPACE_ENABLE";
+    public static final String GENOME_SPACE_ID_SERVER = "GENOME_SPACE_ID_SERVER";
+    public static final String GENOME_SPACE_DM_SERVER = "GENOME_SPACE_DM_SERVER";
+    public static final String GENOME_SPACE_ATM_SERVER = "GENOME_SPACE_ATM_SERVER";
+
+    public static final String DB_ENABLED = "DB_ENABLED";
+    public static final String DB_HOST = "DB_HOST";
+    public static final String DB_NAME = "DB_NAME";
+    public static final String DB_PORT = "DB_PORT";
+
+    /*
+   public static final String GENOME_SPACE_ID_SERVER = "identitytest.genomespace.org";
+
+
+   public static final String identityServerUrl = "https://identitytest.genomespace.org:8443/identityServer/basic";
+   public static String dmServer = "https://dmtest.genomespace.org:8444/datamanager/";
+   public static final String atmServer = "https://atmtest.genomespace.org:8443/atm/";
+
+    */
+
 
     public static String DEFAULT_DATA_SERVER_URL;
 
@@ -614,9 +640,23 @@ public class PreferenceManager implements PropertyManager {
         preferences.putOverride(DATA_SERVER_URL_KEY, url);
     }
 
+    /**
+     * Temporaily overide a preference.   This override will persist for
+     * the duration of the session, or until the user explicitly changes it.
+     *
+     * @param key
+     * @param value
+     */
+    public void override(String key, String value) {
+        preferences.putOverride(key, value);
+    }
+
+    public void loadOverrides(String overridePropertyFilePath) {
+        preferences.loadOverrides(overridePropertyFilePath);
+        clearCaches();
+    }
 
     public void setShowAttributeView(boolean isShowable) {
-
         put(PreferenceManager.SHOW_ATTRIBUTE_VIEWS_KEY, Boolean.toString(isShowable));
     }
 
@@ -850,7 +890,7 @@ public class PreferenceManager implements PropertyManager {
         remove(PreferenceManager.PROXY_AUTHENTICATE);
         remove(PreferenceManager.PROXY_USER);
         remove(PreferenceManager.PROXY_PW);
-        IGVHttpClientUtils.updateProxySettings();
+        HttpUtils.getInstance().updateProxySettings();
     }
 
 
@@ -877,7 +917,7 @@ public class PreferenceManager implements PropertyManager {
         defaultValues.put(JOIN_ADJACENT_SEGMENTS_KEY, "false");
         defaultValues.put(USE_BYTE_RANGE, "true");
         defaultValues.put(OVERLAY_MUTATION_TRACKS, "true");
-        defaultValues.put(SHOW_ORPHANED_MUTATIONS, "false");
+        defaultValues.put(SHOW_ORPHANED_MUTATIONS, "true");
         defaultValues.put(COLOR_MUTATIONS, "false");
         defaultValues.put(ENABLE_LINKED_SORTING, "true");
         defaultValues.put(SHOW_SINGLE_TRACK_PANE_KEY, "false");
@@ -895,9 +935,9 @@ public class PreferenceManager implements PropertyManager {
         defaultValues.put(CHART_DRAW_Y_AXIS, "false");
         defaultValues.put(CHART_AUTOSCALE, "true");
         defaultValues.put(CHART_SHOW_DATA_RANGE, "true");
-
         defaultValues.put(CHART_COLOR_TRACK_NAME, "true");
         defaultValues.put(CHART_TRACK_HEIGHT_KEY, "40");
+        defaultValues.put(CHART_SHOW_ALL_HEATMAP, "false");
 
         defaultValues.put(SAM_SHOW_DUPLICATES, "false");
         defaultValues.put(SAM_SHOW_SOFT_CLIPPED, "false");
@@ -905,6 +945,7 @@ public class PreferenceManager implements PropertyManager {
         defaultValues.put(SAM_AUTO_SORT, "false");
         defaultValues.put(SAM_SHADE_CENTER, "true");
         defaultValues.put(SAM_SHOW_REF_SEQ, "false");
+        defaultValues.put(SAM_SHOW_CENTER_LINE, "true");
         defaultValues.put(SAM_SHOW_COV_TRACK, "true");
         defaultValues.put(SAM_SHADE_BASE_QUALITY, "true");
         defaultValues.put(SAM_FILTER_ALIGNMENTS, "false");
@@ -925,8 +966,10 @@ public class PreferenceManager implements PropertyManager {
         defaultValues.put(SAM_MAX_VISIBLE_RANGE, "30");
         defaultValues.put(SAM_COLOR_BY, "INSERT_SIZE");
         defaultValues.put(SAM_COMPUTE_ISIZES, "false");
+        defaultValues.put(SAM_FLAG_ZERO_QUALITY, "true");
         defaultValues.put(SAM_SHOW_JUNCTION_TRACK, "false");
-
+        defaultValues.put(SAM_JUNCTION_MIN_FLANKING_WIDTH, "0");
+        defaultValues.put(SAM_JUNCTION_MIN_COVERAGE, "1");
 
         defaultValues.put(NORMALIZE_COVERAGE, "false");
 
@@ -971,6 +1014,17 @@ public class PreferenceManager implements PropertyManager {
         defaultValues.put(NAME_PANEL_WIDTH, "160");
         defaultValues.put(BACKGROUND_COLOR, "250,250,250");
 
+        defaultValues.put(GENOME_SPACE_ENABLE, "false");
+        defaultValues.put(GENOME_SPACE_ID_SERVER, "https://identitytest.genomespace.org/identityServer/basic");
+        defaultValues.put(GENOME_SPACE_DM_SERVER, "https://dmtest.genomespace.org/datamanager/");
+        defaultValues.put(GENOME_SPACE_ATM_SERVER, "https://atmtest.genomespace.org/atm/");
+
+        defaultValues.put(DB_ENABLED, "false");
+        defaultValues.put(DB_HOST, "");
+        defaultValues.put(DB_NAME, "");
+        defaultValues.put(DB_PORT, "-1");
+
+
     }
 
 }
