@@ -232,7 +232,7 @@ public abstract class AbstractDataSource implements DataSource {
 
                     if (e < startLocation) {
                         continue;
-                    } else if (s > endLocation) {
+                    } else if (s >= endLocation) {
                         break;
                     }
 
@@ -256,65 +256,51 @@ public abstract class AbstractDataSource implements DataSource {
                 int lastEndBin = 0;
 
                 int size = starts.length;
+
+                // Loop through and bin scores for this interval.
                 for (int i = 0; i < size; i++) {
+
+                    if (starts[i] >= endLocation) {
+                        break;  // We're beyond the end of the requested interval
+                    }
+
+                    // Bound feature at interval, other "piece" will be in another tile.
                     int s = Math.max(startLocation, starts[i]);
                     int e = ends == null ? s + 1 : Math.min(endLocation, ends[i]);
-                    String probeName = features == null ? null : features[i];
                     float v = values[i] * normalizationFactor;
 
                     if (e < startLocation || Float.isNaN(v)) {
-                        continue;
-                    } else if (s > endLocation) {
-                        break;
+                        continue;    // Not yet to interval, or not a number
                     }
 
+                    String probeName = features == null ? null : features[i];
+
+                    // Compute bin numbers, relative to start of this tile
                     int endBin = (int) ((e - startLocation) / scale);
+                    int startBin = (int) ((s - startLocation) / scale);
 
-
-                    if (endBin == lastEndBin) {
-                        // Add to previous bin
-                        accumulator.add(e - s, v, probeName);
-                        if (accumulatedStart < 0) accumulatedStart = s;
-                        accumulatedEnd = e;
-                    } else {
-                        // Previous bin is complete, start a new one.
+                    // If this feature spans multiple bins, or extends beyond last end bin, record
+                    if (endBin > lastEndBin || endBin > startBin) {
                         if (accumulator.hasData()) {
-                            LocusScore ls;
-                            if (accumulator.getNpts() == 1) {
-                                ls = new NamedScore(accumulatedStart, accumulatedEnd, accumulator.getData()[0], accumulator.getNames()[0]);
-                            } else {
-                                float value = accumulator.getValue();
-                                ls = new CompositeScore(accumulatedStart, accumulatedEnd, value, accumulator.getData(),
-                                        accumulator.getNames(), windowFunction);
-                            }
-                            scores.add(ls);
+                            scores.add(getCompositeScore(accumulator, accumulatedStart, accumulatedEnd));
                             accumulator = new Accumulator(windowFunction, 5);
                         }
+                    }
 
-
-                        // If the current score spans multiple bins add it now
-                        int startBin = Math.max(0, (int) ((s - startLocation) / scale));
-                        if ((endBin - startBin) > 1) {
-                            scores.add(new NamedScore(s, e, v, probeName));
-                        } else {
-                            accumulator.add(e - s, v, probeName);
-                            accumulatedStart = s;
-                            accumulatedEnd = e;
-                        }
+                    if (endBin > startBin) {
+                        scores.add(new NamedScore(s, e, v, probeName));
+                    } else {
+                        if (!accumulator.hasData()) accumulatedStart = s;
+                        accumulatedEnd = e;
+                        accumulator.add(e - s, v, probeName);
                     }
 
                     lastEndBin = endBin;
                 }
+
+                // Cleanup
                 if (accumulator.hasData()) {
-                    LocusScore ls;
-                    if (accumulator.getNpts() == 1) {
-                        ls = new NamedScore(accumulatedStart, accumulatedEnd, accumulator.getData()[0], accumulator.getNames()[0]);
-                    } else {
-                        float value = accumulator.getValue();
-                        ls = new CompositeScore(accumulatedStart, accumulatedEnd, value, accumulator.getData(),
-                                accumulator.getNames(), windowFunction);
-                    }
-                    scores.add(ls);
+                    scores.add(getCompositeScore(accumulator, accumulatedStart, accumulatedEnd));
                 }
 
                 tile.addAllScores(scores);
@@ -326,6 +312,19 @@ public abstract class AbstractDataSource implements DataSource {
         return tile;
     }
 
+    private LocusScore getCompositeScore(Accumulator accumulator, int accumulatedStart, int accumulatedEnd) {
+        LocusScore ls;
+        if (accumulator.getNpts() == 1) {
+            ls = new NamedScore(accumulatedStart, accumulatedEnd, accumulator.getData()[0], accumulator.getNames()[0]);
+        } else {
+            float value = accumulator.getValue();
+            ls = new CompositeScore(accumulatedStart, accumulatedEnd, value, accumulator.getData(),
+                    accumulator.getNames(), windowFunction);
+        }
+        return ls;
+
+    }
+
 
     /**
      * Return true if the data has been log normalized.
