@@ -1,41 +1,40 @@
 /*
- * Copyright (c) 2007-2010 by The Broad Institute, Inc. and the Massachusetts Institute of Technology.
- * All Rights Reserved.
+ * Copyright (c) 2007-2011 by The Broad Institute of MIT and Harvard.  All Rights Reserved.
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL), Version 2.1 which
- * is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
+ * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
  *
- * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR WARRANTIES OF
- * ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING, WITHOUT LIMITATION, WARRANTIES
- * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT
- * OR OTHER DEFECTS, WHETHER OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR
- * RESPECTIVE TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES OF
- * ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES, ECONOMIC
- * DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER THE BROAD OR MIT SHALL
- * BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT SHALL KNOW OF THE POSSIBILITY OF THE
- * FOREGOING.
+ * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR
+ * WARRANTES OF ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING,
+ * WITHOUT LIMITATION, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
+ * PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT OR OTHER DEFECTS, WHETHER
+ * OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR RESPECTIVE
+ * TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES
+ * OF ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES,
+ * ECONOMIC DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER
+ * THE BROAD OR MIT SHALL BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT
+ * SHALL KNOW OF THE POSSIBILITY OF THE FOREGOING.
  */
 package org.broad.igv.data;
 
 //~--- non-JDK imports --------------------------------------------------------
 
+import org.broad.igv.feature.genome.GenomeManager;
+import org.broad.igv.ui.IGV;
+import org.broad.igv.ui.util.MessageUtils;
 import org.broad.igv.util.collections.FloatArrayList;
 import org.broad.igv.util.collections.IntArrayList;
 import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
-import org.broad.igv.event.StatusChangeEvent;
 import org.broad.igv.exceptions.ParserException;
-import org.broad.igv.feature.Genome;
-import org.broad.igv.feature.GenomeManager;
-import org.broad.igv.listener.StatusListener;
+import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.track.TrackType;
 import org.broad.igv.track.WindowFunction;
-import org.broad.igv.util.SeekableStream;
 import org.broad.igv.util.*;
-import org.broad.igv.util.SeekableStreamFactory;
+import org.broad.igv.util.stream.IGVSeekableStreamFactory;
+import org.broad.tribble.readers.AsciiLineReader;
+import org.broad.tribble.util.SeekableStream;
 
-import java.awt.*;
-import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStream;
@@ -55,30 +54,27 @@ public class IGVDatasetParser {
 
     private static Logger log = Logger.getLogger(IGVDatasetParser.class);
     private ResourceLocator dataResourceLocator;
-    private int chrColumn;
-    private int startColumn;
-    private int endColumn;
-    private int firstDataColumn;
-    private boolean hasEndLocations;
-    private boolean hasCalls;
+    private int chrColumn = -1;
+    private int startColumn = -1;
+    private int endColumn = -1;
+    private int firstDataColumn = -1;
+    private int lastDataColumn = -1;
+    private int probeColumn = -1;
+    private boolean hasEndLocations = false;
+    private boolean hasCalls = false;
     private Genome genome;
+    private IGV igv;
 
 
-    public static ArrayList<StatusListener> listeners = null;
+    private int startBase = 0;
 
-    /**
-     * Constructs ...
-     *
-     * @param copyNoFile
-     * @param genomeId
-     */
-    public IGVDatasetParser(ResourceLocator copyNoFile, String genomeId) {
+    public IGVDatasetParser(ResourceLocator copyNoFile, Genome genome, IGV igv) {
         this.dataResourceLocator = copyNoFile;
-        this.genome = GenomeManager.getInstance().getGenome(genomeId);
-        initParameters();
+        this.genome = genome;
+        this.igv = igv;
     }
 
-    private void initParameters() {
+    private void setColumnDefaults() {
         String tmp = (dataResourceLocator.getPath().endsWith(".txt")
                 ? dataResourceLocator.getPath().substring(0,
                 dataResourceLocator.getPath().length() - 4) : dataResourceLocator.getPath()).toLowerCase();
@@ -87,17 +83,31 @@ public class IGVDatasetParser {
             chrColumn = 0;
             startColumn = 1;
             endColumn = 2;
+            probeColumn = 3;
             firstDataColumn = 4;
             hasEndLocations = true;
             hasCalls = false;
         } else if (tmp.endsWith(".xcn") || tmp.endsWith("cn") || tmp.endsWith(".snp") || tmp.endsWith(".loh")) {
+            probeColumn = 0;
             chrColumn = 1;
             startColumn = 2;
             endColumn = -1;
             firstDataColumn = 3;
             hasEndLocations = false;
             hasCalls = tmp.endsWith(".xcn") || tmp.endsWith(".snp");
+        } else if (tmp.endsWith(".expr")) {
+            //gene_id	bundle_id	chr	left	right	FPKM	FPKM_conf_lo	FPKM_conf_hi
+            probeColumn = 0;
+            chrColumn = 2;
+            startColumn = 3;
+            endColumn = 4;
+            startBase = 1;
+            firstDataColumn = 5;
+            lastDataColumn = 5;
+            hasEndLocations = true;
+
         } else {
+            // TODO -- popup dialog and ask user to define columns,  and csv vs tsv?
             throw new ParserException("Unknown file type: ", 0);
         }
     }
@@ -106,7 +116,7 @@ public class IGVDatasetParser {
      */
 
     public static boolean parsableMAGE_TAB(ResourceLocator file) throws IOException {
-        org.broad.igv.util.AsciiLineReader reader = null;
+        AsciiLineReader reader = null;
         try {
             reader = ParsingUtils.openAsciiReader(file);
             String nextLine = null;
@@ -151,6 +161,7 @@ public class IGVDatasetParser {
         float dataMin = 0;
         float dataMax = 0;
         //long filePosition = 0;
+        InputStream is = null;
         AsciiLineReader reader = null;
         String nextLine = null;
         ChromosomeSummary chrSummary = null;
@@ -165,7 +176,7 @@ public class IGVDatasetParser {
             int skipColumns = hasCalls ? 2 : 1;
 
             // BufferedReader reader = ParsingUtils.openBufferedReader(dataResourceLocator);
-            InputStream is = ParsingUtils.openInputStream(dataResourceLocator);
+            is = ParsingUtils.openInputStream(dataResourceLocator);
             reader = new AsciiLineReader(is);
 
             // Infer datatype from extension.  This can be overriden in the
@@ -180,19 +191,28 @@ public class IGVDatasetParser {
                 dataset.getTrackProperties().setWindowingFunction(WindowFunction.mean);
             }
 
-            // Parse comments, if any
+            // Parse comments and directives, if any
             nextLine = reader.readLine();
-
             while (nextLine.startsWith("#") || (nextLine.trim().length() == 0)) {
                 if (nextLine.length() > 0) {
-                    parseComment(nextLine, dataset);
+                    parseDirective(nextLine, dataset);
                 }
                 nextLine = reader.readLine();
             }
 
+            if (chrColumn < 0) {
+                setColumnDefaults();
+            }
+
+
             // Parse column headings
             String[] data = nextLine.trim().split("\t");
 
+            // Set last data column
+            if (lastDataColumn < 0) {
+                lastDataColumn = data.length - 1;
+            }
+
             headings = getHeadings(data, skipColumns);
 
             dataset.setDataHeadings(headings);
@@ -209,10 +229,11 @@ public class IGVDatasetParser {
             int updateCount = 5000;
             int count = 0;
             long lastPosition = 0;
+            String[] tokens = new String[headings.length + 100];
             while ((nextLine = reader.readLine()) != null) {
 
-                if (++count % updateCount == 0) {
-                    fireStatusEvent(new StatusChangeEvent("Loaded: " + count + " / " + estLineCount + " (est)"));
+                if (igv != null && ++count % updateCount == 0) {
+                    igv.setStatusBarMessage("Loaded: " + count + " / " + estLineCount + " (est)");
                 }
                 // Distance since last sample
 
@@ -239,12 +260,12 @@ public class IGVDatasetParser {
 
                     int location = -1;
                     try {
-                        location = Integer.parseInt(tokens[startColumn]);
+                        location = Integer.parseInt(tokens[startColumn]) - startBase;
 
                     } catch (NumberFormatException numberFormatException) {
                         log.error("Column " + tokens[startColumn] + " is not a number");
                         throw new ParserException("Column " + (startColumn + 1) +
-                                " must contain a numeric value." + " Found: " + tokens[startColumn],
+                                " must contain an integer value." + " Found: " + tokens[startColumn],
                                 reader.getCurrentLineNumber(), nextLine);
                     }
 
@@ -256,7 +277,7 @@ public class IGVDatasetParser {
                         } catch (NumberFormatException numberFormatException) {
                             log.error("Column " + tokens[endColumn] + " is not a number");
                             throw new ParserException("Column " + (endColumn + 1) +
-                                    " must contain a numeric value." + " Found: " + tokens[endColumn],
+                                    " must contain an integer value." + " Found: " + tokens[endColumn],
                                     reader.getCurrentLineNumber(), nextLine);
                         }
                     }
@@ -268,14 +289,6 @@ public class IGVDatasetParser {
                                 " Use igvtools (File > Run igvtools..) to sort the file.", reader.getCurrentLineNumber());
                     }
 
-
-                    if (nTokens > headings.length * skipColumns + firstDataColumn) {
-
-                        // TODO -- throw error here.  this will cause an index out of bounds exception
-                        log.info("Unexpected number of columns.  Expected " + headings.length + firstDataColumn +
-                                ". Found " + nTokens + "   (" + nextLine + ")");
-                    }
-
                     wgData.locations.add(location);
 
                     for (int idx = 0; idx < headings.length; idx++) {
@@ -320,8 +333,12 @@ public class IGVDatasetParser {
             }
         }
         finally {
-            if (reader != null) {
-                reader.close();
+            if (is != null) {
+                try {
+                    is.close();
+                } catch (IOException e) {
+                    log.error("Error closing IGVDataset stream", e);
+                }
             }
         }
 
@@ -349,22 +366,26 @@ public class IGVDatasetParser {
     private float readFloat(String token) {
         float copyNo = Float.NaN;
         try {
-            copyNo = Float.parseFloat(token);
+            if (token != null) {
+                copyNo = Float.parseFloat(token);
+            }
 
-        } catch (NumberFormatException e) {
+        }
+        catch (NumberFormatException e) {
+            // This is an expected condition.
         }
         return copyNo;
+
     }
 
     /**
      * Load data for a single chromosome.
      *
      * @param chrSummary
-     * @param columnHeaders
+     * @param dataHeaders
      * @return
      */
-    public ChromosomeData loadChromosomeData(
-            ChromosomeSummary chrSummary, String[] columnHeaders) {
+    public ChromosomeData loadChromosomeData(ChromosomeSummary chrSummary, String[] dataHeaders) {
 
         // InputStream is = null;
         try {
@@ -373,7 +394,7 @@ public class IGVDatasetParser {
             // Get an estimate of the number of snps (rows).  THIS IS ONLY AN ESTIMATE
             int nRowsEst = chrSummary.getNDataPts();
 
-            SeekableStream is = SeekableStreamFactory.getStreamFor(dataResourceLocator.getPath());
+            SeekableStream is = IGVSeekableStreamFactory.getStreamFor(dataResourceLocator.getPath());
             is.seek(chrSummary.getStartPosition());
             AsciiLineReader reader = new AsciiLineReader(is);
 
@@ -381,9 +402,10 @@ public class IGVDatasetParser {
             // Create containers to hold data
             IntArrayList startLocations = new IntArrayList(nRowsEst);
             IntArrayList endLocations = (hasEndLocations ? new IntArrayList(nRowsEst) : null);
+            List<String> probes = new ArrayList(nRowsEst);
 
             Map<String, FloatArrayList> dataMap = new HashMap();
-            for (String h : columnHeaders) {
+            for (String h : dataHeaders) {
                 dataMap.put(h, new FloatArrayList(nRowsEst));
             }
 
@@ -391,28 +413,34 @@ public class IGVDatasetParser {
             String chromosome = chrSummary.getName();
             boolean chromosomeStarted = false;
             String nextLine = reader.readLine();
+            String[] tokens = new String[dataHeaders.length + 100];
+
             while ((nextLine != null) && (nextLine.trim().length() > 0)) {
 
+                if(!nextLine.startsWith("#")) {
                 try {
                     int nTokens = ParsingUtils.split(nextLine, tokens, '\t');
-
                     String thisChromosome = genome.getChromosomeAlias(tokens[chrColumn].trim());
                     if (thisChromosome.equals(chromosome)) {
                         chromosomeStarted = true;
 
                         // chromosomeData.setMarkerId(nRows, tokens[0]);
 
-                        int start = Integer.parseInt(tokens[startColumn].trim());
+                        // The probe.  A new string is created to prevent holding on to the entire row through a substring reference
+                        String probe = new String(tokens[probeColumn]);
+                        probes.add(probe);
+
+                        int start = Integer.parseInt(tokens[startColumn].trim()) - startBase;
                         if (hasEndLocations) {
                             endLocations.add(Integer.parseInt(tokens[endColumn].trim()));
                         }
 
                         startLocations.add(start);
 
-                        for (int idx = 0; idx < columnHeaders.length; idx++) {
+                        for (int idx = 0; idx < dataHeaders.length; idx++) {
                             int i = firstDataColumn + idx * skipColumns;
-                            float copyNo = i < tokens.length ? readFloat(tokens[i]) : Float.NaN;
-                            String heading = columnHeaders[idx];
+                            float copyNo = i <= lastDataColumn ? readFloat(tokens[i]) : Float.NaN;
+                            String heading = dataHeaders[idx];
                             dataMap.get(heading).add(copyNo);
                         }
 
@@ -426,18 +454,20 @@ public class IGVDatasetParser {
                     // Skip line
                     log.info("Skipping line (NumberFormatException) " + nextLine);
                 }
+                }
 
                 nextLine = reader.readLine();
             }
 
             // Loop complete
             ChromosomeData cd = new ChromosomeData(chrSummary.getName());
+            cd.setProbes(probes.toArray(new String[]{}));
             cd.setStartLocations(startLocations.toArray());
             if (hasEndLocations) {
                 cd.setEndLocations(endLocations.toArray());
             }
 
-            for (String h : columnHeaders) {
+            for (String h : dataHeaders) {
                 cd.setData(h, dataMap.get(h).toArray());
             }
 
@@ -457,12 +487,14 @@ public class IGVDatasetParser {
      * @param comment
      * @param dataset
      */
-    private void parseComment(String comment, IGVDataset dataset) {
+    private void parseDirective(String comment, IGVDataset dataset) {
 
         String tmp = comment.substring(1, comment.length());
         if (tmp.startsWith("track")) {
             ParsingUtils.parseTrackLine(tmp, dataset.getTrackProperties());
 
+        } else if (tmp.startsWith("columns")) {
+            parseColumnLine(tmp);
         } else {
             String[] tokens = tmp.split("=");
             if (tokens.length != 2) {
@@ -480,13 +512,17 @@ public class IGVDatasetParser {
 
                     // Ignore
                 }
+            } else if (key.equals("coords")) {
+
+                startBase = Integer.parseInt(tokens[1].trim());
+
             }
         }
     }
 
     private boolean isCopyNumberFileExt(String filename) {
-        String tmp = (filename.endsWith(".txt") || filename.endsWith(".tab") || filename.endsWith(".xls")
-                ? filename.substring(0, filename.length() - 4) : filename);
+        String tmp = ((filename.endsWith(".txt") || filename.endsWith(".tab") || filename.endsWith(".xls")
+                ? filename.substring(0, filename.length() - 4) : filename)).toLowerCase();
         return tmp.endsWith(".cn") || tmp.endsWith(".xcn") || tmp.endsWith(".snp");
     }
 
@@ -519,7 +555,7 @@ public class IGVDatasetParser {
 
         ArrayList headings = new ArrayList();
         String previousHeading = null;
-        for (int i = firstDataColumn; i < tokens.length; i += skipColumns) {
+        for (int i = firstDataColumn; i <= lastDataColumn; i += skipColumns) {
             if (removeDuplicates) {
                 if (previousHeading != null && tokens[i].equals(previousHeading) || tokens[i].equals("")) {
                     continue;
@@ -534,32 +570,78 @@ public class IGVDatasetParser {
         return (String[]) headings.toArray(new String[0]);
     }
 
-    static String[] tokens = new String[10000];
 
-    /**
-     * Positin the stream at the specified position.
-     *
-     * @param is
-     * @param position
-     * @throws java.io.IOException
-     */
-    private void position(InputStream is, long position) throws IOException {
-        // This is ugly, but most streams are filestreams and we want to take advantage of 
-        // the file channel
-        if (is instanceof FileInputStream) {
-            ((FileInputStream) is).getChannel().position(position);
-        } else {
-            is.skip(position);
+    private void parseColumnLine(String tmp) {
+        String[] tokens = tmp.split("\\s+");
+        if (tokens.length > 1) {
+            for (int i = 1; i < tokens.length; i++) {
+                String[] kv = tokens[i].split("=");
+                if (kv.length == 2) {
+                    if (kv[0].toLowerCase().equals("chr")) {
+                        int c = Integer.parseInt(kv[1]);
+                        if (c < 1) {
+                            MessageUtils.showMessage("Error parisng column line: " + tmp + "<br>Column numbers must be > 0");
+                        } else {
+                            chrColumn = c - 1;
+                        }
+                    } else if (kv[0].toLowerCase().equals("start")) {
+                        int c = Integer.parseInt(kv[1]);
+                        if (c < 1) {
+                            MessageUtils.showMessage("Error parisng column line: " + tmp + "<br>Column numbers must be > 0");
+                        } else {
+                            startColumn = c - 1;
+                        }
+
+
+                    } else if (kv[0].toLowerCase().equals("end")) {
+                        int c = Integer.parseInt(kv[1]);
+                        if (c < 1) {
+                            MessageUtils.showMessage("Error parisng column line: " + tmp + "<br>Column numbers must be > 0");
+                        } else {
+                            endColumn = c - 1;
+                            hasEndLocations = true;
+                        }
+
+
+                    } else if (kv[0].toLowerCase().equals("probe")) {
+                        int c = Integer.parseInt(kv[1]);
+                        if (c < 1) {
+                            MessageUtils.showMessage("Error parisng column line: " + tmp + "<br>Column numbers must be > 0");
+                        } else {
+                            probeColumn = c - 1;
+                        }
+
+
+                    } else if (kv[0].toLowerCase().equals("data")) {
+                        // examples  4,  4-8,  4-
+                        String[] se = kv[1].split("-");
+                        int c = Integer.parseInt(se[0]);
+                        if (c < 1) {
+                            MessageUtils.showMessage("Error parisng column line: " + tmp + "<br>Column numbers must be > 0");
+                        } else {
+                            this.firstDataColumn = c - 1;
+                        }
+                        if (se.length > 1) {
+
+                            c = Integer.parseInt(se[1]);
+                            if (c < 1) {
+                                MessageUtils.showMessage("Error parisng column line: " + tmp + "<br>Column numbers must be > 0");
+                            } else {
+                                this.lastDataColumn = c - 1;
+                            }
+                        }
+                    }
+                }
+            }
         }
-
-
     }
 
+
     private void updateWholeGenome(String currentChromosome, IGVDataset dataset, String[] headings,
                                    IGVDatasetParser.WholeGenomeData wgData) {
 
-        
-        if(!genome.getHomeChromosome().equals(Globals.CHR_ALL)) {
+
+        if (!genome.getHomeChromosome().equals(Globals.CHR_ALL)) {
             return;
         }
 
@@ -600,21 +682,4 @@ public class IGVDatasetParser {
         }
     }
 
-    public static void addListener(StatusListener s) {
-        if (listeners == null) {
-            listeners = new ArrayList();
-        }
-
-        listeners.add(s);
-    }
-
-    public void fireStatusEvent(AWTEvent evt) {
-        if (evt instanceof StatusChangeEvent) {
-            if (listeners != null) {
-                for (StatusListener listener : listeners) {
-                    listener.statusChanged((StatusChangeEvent) evt);
-                }
-            }
-        }
-    }
 }
