@@ -24,7 +24,7 @@ package org.broad.igv.exceptions;
  */
 public class DataLoadException extends RuntimeException {
 
-    String message;
+    private String message;
     private String fileName;
 
     public DataLoadException(String message, String fileName) {
@@ -33,6 +33,6 @@ public class DataLoadException extends RuntimeException {
     }
 
     public String getMessage() {
-        return "<html>An error occurred while loading:    " + fileName + "<br>" + message;
+        return "<html>An error occurred while accessing:    " + fileName + "<br>" + message;
     }
 }
\ No newline at end of file
