@@ -1,19 +1,19 @@
 /*
- * Copyright (c) 2007-2010 by The Broad Institute, Inc. and the Massachusetts Institute of Technology.
- * All Rights Reserved.
+ * Copyright (c) 2007-2011 by The Broad Institute of MIT and Harvard.  All Rights Reserved.
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL), Version 2.1 which
- * is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
+ * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
  *
- * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR WARRANTIES OF
- * ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING, WITHOUT LIMITATION, WARRANTIES
- * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT
- * OR OTHER DEFECTS, WHETHER OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR
- * RESPECTIVE TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES OF
- * ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES, ECONOMIC
- * DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER THE BROAD OR MIT SHALL
- * BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT SHALL KNOW OF THE POSSIBILITY OF THE
- * FOREGOING.
+ * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR
+ * WARRANTES OF ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING,
+ * WITHOUT LIMITATION, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
+ * PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT OR OTHER DEFECTS, WHETHER
+ * OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR RESPECTIVE
+ * TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES
+ * OF ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES,
+ * ECONOMIC DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER
+ * THE BROAD OR MIT SHALL BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT
+ * SHALL KNOW OF THE POSSIBILITY OF THE FOREGOING.
  */
 /*
  * To change this template, choose Tools | Templates
@@ -23,15 +23,14 @@ package org.broad.igv.feature;
 
 import org.apache.log4j.Logger;
 import org.broad.igv.exceptions.ParserException;
-import org.broad.igv.exceptions.DataLoadException;
-import org.broad.igv.renderer.BasicFeatureRenderer;
-import org.broad.igv.session.ViewContext;
+import org.broad.igv.feature.genome.Genome;
+import org.broad.igv.renderer.IGVFeatureRenderer;
 import org.broad.igv.track.FeatureCollectionSource;
 import org.broad.igv.track.FeatureTrack;
 import org.broad.igv.track.TrackProperties;
 import org.broad.igv.track.TrackType;
-import org.broad.igv.ui.IGVMainFrame;
-import org.broad.igv.util.AsciiLineReader;
+import org.broad.igv.ui.IGV;
+import org.broad.tribble.readers.AsciiLineReader;
 import org.broad.igv.util.ParsingUtils;
 import org.broad.igv.util.ResourceLocator;
 
@@ -46,40 +45,44 @@ import java.util.List;
  */
 public abstract class AbstractFeatureParser implements FeatureParser {
 
-    private static Logger log = Logger.getLogger(IGVMainFrame.class);
+    private static Logger log = Logger.getLogger(IGV.class);
     private String filePath;
     protected Genome genome;
     protected int startBase = 0;
 
     /* An object to collection track properties, if specified in the feature file. */
-    private TrackProperties trackProperties = null;
+    protected TrackProperties trackProperties = null;
 
     TrackType trackType;
+    boolean gffTags = false;
 
-    public AbstractFeatureParser() {
-        genome = ViewContext.getInstance().getGenome();
+    public AbstractFeatureParser(Genome genome) {
+        this.genome = genome;
     }
 
     /**
      * Return an parser instance appropriate the the file type.  Currently the filename
      * is used to determine file type, this is fragile obviously but what is the alternative?
      */
-    public static FeatureParser getInstanceFor(ResourceLocator locator) {
+    public static FeatureParser getInstanceFor(ResourceLocator locator, Genome genome) {
 
-        String tmp = getStrippedFilename(locator.getPath());
+        final String path = locator.getPath();
+        return getInstanceFor(path, genome);
+    }
+
+    public static FeatureParser getInstanceFor(String path, Genome genome) {
+        String tmp = getStrippedFilename(path);
 
         if (tmp.endsWith("bed") || tmp.endsWith("map")) {
-            return new BEDFileParser();
-        } else if (tmp.endsWith("psl")) {
-            return new PSLParser();
+            return new BEDFileParser(genome);
         } else if (tmp.contains("refflat")) {
-            return new UCSCGeneTableParser(UCSCGeneTableParser.Type.REFFLAT);
+            return new UCSCGeneTableParser(genome, UCSCGeneTableParser.Type.REFFLAT);
         } else if (tmp.contains("genepred") || tmp.contains("ensgene") || tmp.contains("refgene")) {
-            return new UCSCGeneTableParser(UCSCGeneTableParser.Type.GENEPRED);
+            return new UCSCGeneTableParser(genome, UCSCGeneTableParser.Type.GENEPRED);
         } else if (tmp.contains("ucscgene")) {
-            return new UCSCGeneTableParser(UCSCGeneTableParser.Type.UCSCGENE);
+            return new UCSCGeneTableParser(genome, UCSCGeneTableParser.Type.UCSCGENE);
         } else if (tmp.endsWith("gtf") || tmp.endsWith("gff") || tmp.endsWith("gff3")) {
-            return new GFFParser(locator.getPath());
+            return new GFFParser(path);
         } else if (tmp.endsWith("embl")) {
             return new EmblFeatureTableParser();
         } else {
@@ -107,24 +110,24 @@ public abstract class AbstractFeatureParser implements FeatureParser {
      * @param locator
      * @return
      */
-    public List<FeatureTrack> loadTracks(ResourceLocator locator) {
+    public List<FeatureTrack> loadTracks(ResourceLocator locator, Genome genome) {
 
-        List<Feature> features = loadFeatures(locator, -1);
+        List<org.broad.tribble.Feature> features = loadFeatures(locator, -1);
         if (features.size() == 0) {
-            throw new DataLoadException("No features were found in this file with chromosomes mapped to the current genome", locator.getPath());
+            //MessageUtils.showMessage("<html>Warning.  No features were found in " + locator.getPath() + ".<br>Track not loaded.");
         }
-        FeatureCollectionSource source = new FeatureCollectionSource(features);
+        FeatureCollectionSource source = new FeatureCollectionSource(features, genome);
         FeatureTrack track = new FeatureTrack(locator, source);
         track.setName(locator.getTrackName());
-        track.setRendererClass(BasicFeatureRenderer.class);
-        track.setMinimumHeight(35);
+        track.setRendererClass(IGVFeatureRenderer.class);
+        //track.setMinimumHeight(35);
         track.setHeight(45);
         //track.setRendererClass(GeneTrackRenderer.class);
         if (trackType != null) {
             track.setTrackType(trackType);
         }
         if (trackProperties != null) {
-            track.setTrackProperties(trackProperties);
+            track.setProperties(trackProperties);
         }
 
         List<FeatureTrack> tracks = new ArrayList();
@@ -139,7 +142,7 @@ public abstract class AbstractFeatureParser implements FeatureParser {
      * @param maxLines
      * @return
      */
-    protected List<Feature> loadFeatures(ResourceLocator locator, int maxLines) {
+    public List<org.broad.tribble.Feature> loadFeatures(ResourceLocator locator, int maxLines) {
 
         // File file = new File(locator.getPath());
         int nLines = 0;
@@ -162,7 +165,7 @@ public abstract class AbstractFeatureParser implements FeatureParser {
      * @param reader
      * @return
      */
-    public List<Feature> loadFeatures(AsciiLineReader reader) {
+    public List<org.broad.tribble.Feature> loadFeatures(AsciiLineReader reader) {
         return loadFeatures(reader, -1);
     }
 
@@ -173,15 +176,16 @@ public abstract class AbstractFeatureParser implements FeatureParser {
      * @param maxLines
      * @return
      */
-    public List<Feature> loadFeatures(AsciiLineReader reader, int maxLines) {
+    public List<org.broad.tribble.Feature> loadFeatures(AsciiLineReader reader, int maxLines) {
 
-        List<Feature> features = new ArrayList<Feature>();
+        List<org.broad.tribble.Feature> features = new ArrayList<org.broad.tribble.Feature>();
         String nextLine = null;
 
         try {
             int nLines = 0;
-            while ((nextLine = reader.readLine()) != null && (nextLine.trim().length() > 0)) {
+            while ((nextLine = reader.readLine()) != null) {
                 nextLine = nextLine.trim();
+                if (nextLine.length() == 0) continue;
                 nLines++;
                 if ((maxLines > 0) && (nLines > maxLines)) {
                     break;
@@ -202,6 +206,9 @@ public abstract class AbstractFeatureParser implements FeatureParser {
                             TrackProperties tp = new TrackProperties();
                             ParsingUtils.parseTrackLine(nextLine, tp);
                             setTrackProperties(tp);
+                            if(tp.isGffTags()) {
+                                gffTags = true;
+                            }
                         } else if (nextLine.startsWith("#coords")) {
                             try {
                                 String[] tokens = nextLine.split("=");
@@ -211,9 +218,11 @@ public abstract class AbstractFeatureParser implements FeatureParser {
                                 log.error("Error parsing coords line: " + nextLine, e);
                             }
 
+                        } else if (nextLine.startsWith("#gffTags")) {
+                            gffTags = true;
                         }
                     } else {
-                        Feature feature = parseLine(nextLine);
+                        IGVFeature feature = parseLine(nextLine);
                         if (feature != null) {
                             features.add(feature);
                         }
@@ -239,17 +248,17 @@ public abstract class AbstractFeatureParser implements FeatureParser {
             }
         }
 
-        parsingComplete(features);
+        //parsingComplete(features);
         FeatureDB.addFeatures(features);
         return features;
     }
 
-    protected void parsingComplete(List<Feature> features) {
+    protected void parsingComplete(List<IGVFeature> features) {
 
         // Default -- do nothing.
     }
 
-    abstract protected Feature parseLine(String nextLine);
+    abstract protected IGVFeature parseLine(String nextLine);
 
     protected static String getStrippedFilename(String filename) {
         String tmp = filename.toLowerCase();
@@ -270,14 +279,14 @@ public abstract class AbstractFeatureParser implements FeatureParser {
      * @param features
      * @param outputfile
      */
-    public static void dumpFeatures(List<Feature> features, String outputfile) {
+    public static void dumpFeatures(List<IGVFeature> features, String outputfile) {
 
         PrintWriter pw = null;
 
         try {
             pw = new PrintWriter(new FileWriter(outputfile));
             pw.println("Header row");
-            for (Feature gene : features) {
+            for (IGVFeature gene : features) {
                 pw.print(gene.getName() + "\t");
                 pw.print(gene.getIdentifier() + "\t");
                 pw.print(gene.getChr() + "\t");
@@ -319,4 +328,5 @@ public abstract class AbstractFeatureParser implements FeatureParser {
     public TrackProperties getTrackProperties() {
         return trackProperties;
     }
+
 }
