@@ -25,6 +25,7 @@ import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.feature.genome.GenomeManager;
 import org.broad.igv.ui.IGV;
 
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -41,7 +42,7 @@ public class FeatureDB {
     /**
      * Map for all features other than genes.
      */
-    private static Map<String, NamedFeature> featureMap = new HashMap(10000);
+    private static Map<String, NamedFeature> featureMap = Collections.synchronizedMap(new HashMap(10000));
 
     public static void addFeature(NamedFeature feature) {
 
@@ -54,10 +55,31 @@ public class FeatureDB {
             put(name, feature);
         }
         if (feature instanceof IGVFeature) {
-            final String id = ((IGVFeature) feature).getIdentifier();
+            final IGVFeature igvFeature = (IGVFeature) feature;
+            final String id = igvFeature.getIdentifier();
             if (id != null && id.length() > 0) {
                 put(id, feature);
             }
+
+            addByAttributes(igvFeature);
+
+            List<Exon> exons = igvFeature.getExons();
+            if(exons != null) {
+                for(Exon exon : exons) {
+                    addByAttributes(exon);
+                }
+            }
+        }
+    }
+
+    private static void addByAttributes(IGVFeature igvFeature) {
+        Map<String, String> attributes = igvFeature.getAttributes();
+        if (attributes != null) {
+            for (String value : attributes.values()) {
+                if (value.length() < 20) {
+                    put(value, igvFeature);
+                }
+            }
         }
     }
 
