@@ -204,14 +204,14 @@ public class GFFParser implements FeatureParser {
                     if (line.startsWith("#track") || line.startsWith("##track")) {
                         trackProperties = new TrackProperties();
                         ParsingUtils.parseTrackLine(line, trackProperties);
-                    } else if (line.startsWith("#nodecode")) {
+                    } else if (line.startsWith("#nodecode") || line.startsWith("##nodecode")) {
                         helper.setUrlDecoding(false);
-                    } else if (line.startsWith("#hide")) {
+                    } else if (line.startsWith("#hide") || line.startsWith("##hide")) {
                         String[] kv = line.split("=");
                         if (kv.length > 1) {
                             featuresToHide.addAll(Arrays.asList(kv[1].split(",")));
                         }
-                    } else if (line.startsWith("#displayName")) {
+                    } else if (line.startsWith("#displayName") || line.startsWith("##displayName")) {
                         String [] nameTokens = line.split("=");
                         if(nameTokens.length < 2) {
                             helper.setNameFields(null);
@@ -282,15 +282,16 @@ public class GFFParser implements FeatureParser {
 
                 String[] parentIds = helper.getParentIds(attributes, attributeString);
 
-                if (featureType.equals("CDS_parts")) {
+
+                 if (featureType.equals("CDS_parts")) {
                     for (String pid : parentIds) {
-                        getGFF3Transcript(pid).addCDSParts(chromosome, start, end, description);
+                        getGFF3Transcript(pid).addCDSParts(chromosome, start, end);
                     }
 
                 } else if (featureType.equals("intron")) {
 
                     for (String pid : parentIds) {
-                        getGFF3Transcript(pid).addCDSParts(chromosome, start, end, description);
+                        getGFF3Transcript(pid).addCDSParts(chromosome, start, end);
                     }
                 } else if (exonTerms.contains(featureType) && parentIds != null && parentIds.length > 0 &&
                         parentIds[0] != null && parentIds[0].length() > 0 && !parentIds[0].equals(".")) {
@@ -313,6 +314,7 @@ public class GFFParser implements FeatureParser {
 
                         Exon exon = new Exon(chromosome, start, end, strand);
                         exon.setDescription(description);
+                        exon.setAttributes(attributes);
                         exon.setUTR(utrTerms.contains(featureType));
 
                         if (phase >= 0) {
@@ -337,6 +339,7 @@ public class GFFParser implements FeatureParser {
                     BasicFeature f = new BasicFeature(chromosome, start, end, strand);
                     f.setName(getName(attributes));
                     f.setDescription(description);
+                    f.setAttributes(attributes);
 
                     if (attributes.containsKey("color")) {
                         f.setColor(ColorUtilities.stringToColor(attributes.get("color")));
@@ -477,7 +480,7 @@ public class GFFParser implements FeatureParser {
 
         Map<String, PrintWriter> writers = new HashMap();
         String [] tokens = new String[20];
-        
+
         while ((nextLine = br.readLine()) != null) {
             nextLine = nextLine.trim();
             if (!nextLine.startsWith("#")) {
@@ -548,6 +551,7 @@ public class GFFParser implements FeatureParser {
         int start = Integer.MAX_VALUE;
         int end = Integer.MIN_VALUE;
         String description;
+        Map<String, String> attributes;
 
         GFF3Transcript(String id) {
             this.id = id;
@@ -590,20 +594,26 @@ public class GFFParser implements FeatureParser {
             this.end = Math.max(cds.getEnd(), end);
         }
 
-        void addCDSParts(String chr, int start, int end, String desc) {
+        void addCDSParts(String chr, int start, int end) {
             this.chr = chr;
             this.start = Math.min(this.start, start);
             this.end = Math.max(this.end, end);
-            appendDescription(desc);
         }
 
-        void appendDescription(String desc) {
+        void appendDescription(String desc, Map<String, String> atts) {
             if (description == null) {
                 description = "<html>";
             } else {
                 description += "<br>---------<br>";
             }
             description += desc;
+
+            if(attributes == null) {
+                attributes = atts;
+            }
+            else {
+                attributes.putAll(atts);
+            }
         }
 
         /**
@@ -646,6 +656,7 @@ public class GFFParser implements FeatureParser {
                 transcript.setIdentifier(id);
                 transcript.setName(name == null ? id : name);
                 transcript.setDescription(description);
+                transcript.setAttributes(attributes);
             }
 
             if ((parentId != null) && geneCache.containsKey(parentId)) {
@@ -847,7 +858,12 @@ public class GFFParser implements FeatureParser {
             }
         }
 
-
+        /**
+         * Parse the column 9 attributes.  Attributes are separated by semicolons.
+         *
+         * @param description
+         * @param kvalues
+         */
         public void parseAttributes(String description, Map<String, String> kvalues) {
 
             List<String> kvPairs = StringUtils.breakQuotedString(description.trim(), ';');
