@@ -33,6 +33,7 @@ import org.broad.igv.util.ZipArchiveWrapper.ZipIterator;
 
 import java.io.*;
 import java.util.*;
+import java.util.regex.Pattern;
 import java.util.zip.GZIPInputStream;
 import java.util.zip.ZipInputStream;
 
@@ -45,6 +46,7 @@ public class GenomeImporter {
     public static final int MAX_CONTIGS = 1000000;
 
     static Logger log = Logger.getLogger(GenomeImporter.class);
+    public static final Pattern SEQUENCE_NAME_SPLITTER = Pattern.compile("\\s+");
 
 
     /**
@@ -305,7 +307,7 @@ public class GenomeImporter {
                 propertyFileWriter.println(Globals.GENOME_CHR_ALIAS_FILE_KEY + "=" + chrAliasFile.getName());
             }
             if (relativeSequenceLocation != null) {
-                if (!IGVHttpClientUtils.isURL(relativeSequenceLocation)) {
+                if (!HttpUtils.getInstance().isURL(relativeSequenceLocation)) {
                     relativeSequenceLocation = relativeSequenceLocation.replace('\\', '/');
                 }
                 propertyFileWriter.println(Globals.GENOME_ARCHIVE_SEQUENCE_FILE_LOCATION_KEY + "=" + relativeSequenceLocation);
@@ -321,44 +323,6 @@ public class GenomeImporter {
 
     }
 
-    /**
-     * Writes a user-defined genome property file.
-     *
-     * @param outputFile A java properties file containing tab delimetered data
-     *                   (display name [tab] genome file location [tab] genome id) about
-     *                   the user-defined genome.
-     * @param properties A list of properties to store.
-     * @throws IOException
-     */
-    public static void storeUserDefinedGenomeListToFile(File outputFile, Properties properties)
-            throws IOException {
-
-        if ((properties != null) && (outputFile != null)) {
-
-            if (!outputFile.exists()) {
-                File genomeDir = outputFile.getParentFile();
-                if (!genomeDir.exists()) {
-                    genomeDir.mkdir();
-                }
-                outputFile.createNewFile();
-            }
-
-            FileOutputStream out = null;
-            try {
-                out = new FileOutputStream(outputFile);
-                properties.store(out, "");
-            } finally {
-                if (out != null) {
-                    try {
-                        out.close();
-                    } catch (IOException e) {
-                        log.error("Error closing property file for imported genomes!", e);
-                    }
-                }
-            }
-        }
-    }
-
     /**
      * Creates chromosome sequence files.
      *
@@ -467,10 +431,10 @@ public class GenomeImporter {
                     // Find the first word break.  According the the spec the id of the sequence
                     // is the first "word",  the remaining part of the line is a comment.
 
-                    String [] tokens = fastaDataLine.split("\\s+");
+                    String [] tokens = SEQUENCE_NAME_SPLITTER.split(fastaDataLine, 2);
                     chr = tokens[0].substring(1);
                     chrSize = 0;
-                    String chrFileName = chr + GenomeManager.SEQUENCE_FILE_EXTENSION;
+                    String chrFileName = chr + ".txt";
                     String legalFileName = FileUtils.legalFileName(chrFileName);
                     if (!chrFileName.equals(legalFileName)) {
                         alteredChrFilenames = true;
