@@ -1,19 +1,19 @@
 /*
- * Copyright (c) 2007-2010 by The Broad Institute, Inc. and the Massachusetts Institute of Technology.
- * All Rights Reserved.
+ * Copyright (c) 2007-2011 by The Broad Institute of MIT and Harvard.  All Rights Reserved.
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL), Version 2.1 which
- * is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
+ * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
  *
- * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR WARRANTIES OF
- * ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING, WITHOUT LIMITATION, WARRANTIES
- * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT
- * OR OTHER DEFECTS, WHETHER OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR
- * RESPECTIVE TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES OF
- * ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES, ECONOMIC
- * DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER THE BROAD OR MIT SHALL
- * BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT SHALL KNOW OF THE POSSIBILITY OF THE
- * FOREGOING.
+ * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR
+ * WARRANTES OF ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING,
+ * WITHOUT LIMITATION, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
+ * PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT OR OTHER DEFECTS, WHETHER
+ * OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR RESPECTIVE
+ * TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES
+ * OF ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES,
+ * ECONOMIC DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER
+ * THE BROAD OR MIT SHALL BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT
+ * SHALL KNOW OF THE POSSIBILITY OF THE FOREGOING.
  */
 
 
@@ -28,11 +28,9 @@ package org.broad.igv.renderer;
 import org.broad.igv.Globals;
 import org.broad.igv.PreferenceManager;
 import org.broad.igv.feature.LocusScore;
-import org.broad.igv.track.DataTrack;
 import org.broad.igv.track.RenderContext;
 import org.broad.igv.track.Track;
 import org.broad.igv.ui.FontManager;
-import org.broad.igv.ui.MiscStuff;
 import org.broad.igv.ui.UIConstants;
 
 import java.awt.*;
@@ -44,6 +42,7 @@ import java.util.List;
  */
 public abstract class XYPlotRenderer extends DataRenderer {
 
+    private double marginFraction = 0.2;
 
 
     protected void drawDataPoint(Color graphColor, int dx, int pX, int baseY, int pY,
@@ -62,6 +61,8 @@ public abstract class XYPlotRenderer extends DataRenderer {
      */
     public synchronized void  renderScores(Track track, List<LocusScore> locusScores, RenderContext context, Rectangle arect) {
 
+        boolean showMissingData = PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SHOW_MISSING_DATA_KEY);
+
         Graphics2D noDataGraphics = context.getGraphic2DForColor(UIConstants.NO_DATA_COLOR);
         Graphics2D tickGraphics = context.getGraphic2DForColor(Color.BLACK);
 
@@ -122,7 +123,7 @@ public abstract class XYPlotRenderer extends DataRenderer {
                 continue;
             }
 
-            if (!Float.isNaN(dataY) && (score.getConfidence() > confThreshold)) {
+            if (!Float.isNaN(dataY)) {
 
 
                 // Compute the pixel y location.  Clip to bounds of rectangle.
@@ -138,7 +139,7 @@ public abstract class XYPlotRenderer extends DataRenderer {
                 drawDataPoint(color, (int) dx, (int) pX, baseY, pY, context);
 
             }
-            if (MiscStuff.isShowMissingDataEnabled()) {
+            if (showMissingData) {
 
                 // Draw from lastPx + 1  to pX - 1;
                 int w = (int) pX - lastPx - 4;
@@ -152,7 +153,7 @@ public abstract class XYPlotRenderer extends DataRenderer {
 
             }
         }
-        if (MiscStuff.isShowMissingDataEnabled()) {
+        if (showMissingData) {
             int w = (int) arect.getMaxX() - lastPx - 4;
             if (w > 0) {
                 noDataGraphics.fillRect(lastPx + 2, (int) arect.getY(), w, (int) arect.getHeight());
@@ -182,24 +183,24 @@ public abstract class XYPlotRenderer extends DataRenderer {
 
         Rectangle drawingRect = calculateDrawingRect(arect);
 
-        PreferenceManager.ChartPreferences prefs = PreferenceManager.getInstance().getChartPreferences();
+        PreferenceManager prefs = PreferenceManager.getInstance();
 
-        Color labelColor = prefs.isColorTrackName() ? track.getColor() : Color.black;
+        Color labelColor = prefs.getAsBoolean(PreferenceManager.CHART_COLOR_TRACK_NAME) ? track.getColor() : Color.black;
         Graphics2D labelGraphics = context.getGraphic2DForColor(labelColor);
 
-        labelGraphics.setFont(FontManager.getScalableFont(8));
+        labelGraphics.setFont(FontManager.getFont(8));
 
-        if (prefs.isDrawTrackName()) {
+        if (prefs.getAsBoolean(PreferenceManager.CHART_DRAW_TRACK_NAME)) {
 
             // Only attempt if track height is > 25 pixels
             if (arect.getHeight() > 25) {
                 Rectangle labelRect = new Rectangle(arect.x, arect.y + 10, arect.width, 10);
-                labelGraphics.setFont(FontManager.getScalableFont(10));
+                labelGraphics.setFont(FontManager.getFont(10));
                 GraphicUtils.drawCenteredText(track.getName(), labelRect, labelGraphics);
             }
         }
 
-        if (prefs.isDrawAxis()) {
+        if (prefs.getAsBoolean(PreferenceManager.CHART_DRAW_Y_AXIS)) {
 
             Rectangle axisRect = new Rectangle(arect.x, arect.y + 1, AXIS_AREA_WIDTH, arect.height);
 
@@ -243,7 +244,7 @@ public abstract class XYPlotRenderer extends DataRenderer {
             if (range != null) {
                 Graphics2D g = context.getGraphic2DForColor(Color.black);
                 Font font = g.getFont();
-                Font smallFont = FontManager.getScalableFont(8);
+                Font smallFont = FontManager.getFont(8);
                 try {
                     g.setFont(smallFont);
                     String minString = range.getMinimum() == 0f ? "0" : String.format("%.3f", range.getMinimum());
@@ -268,6 +269,9 @@ public abstract class XYPlotRenderer extends DataRenderer {
         // Draw boundaries if there is room
         if (adjustedRect.getHeight() >= 10) {
 
+            ///TrackProperties pros = track.getProperties();
+
+
             // midline
 
             DataRange axisDefinition = track.getDataRange();
@@ -286,36 +290,55 @@ public abstract class XYPlotRenderer extends DataRenderer {
                 getBaselineGraphics(context).drawLine((int) x, baseY, (int) maxX, baseY);
             }
 
-            PreferenceManager.ChartPreferences prefs = PreferenceManager.getInstance().getChartPreferences();
+            PreferenceManager prefs = PreferenceManager.getInstance();
 
-            Color borderColor = (prefs.isColorBorders() && track.getAltColor() == track.getColor())
+            Color borderColor = (prefs.getAsBoolean(PreferenceManager.CHART_COLOR_BORDERS) && track.getAltColor() == track.getColor())
                     ? track.getColor() : Color.lightGray;
             Graphics2D borderGraphics = context.getGraphic2DForColor(borderColor);
 
             // Draw the baseline -- todo, this is a wig track option?
             double zeroValue = axisDefinition.getBaseline();
-            int zeroX = computeYPixelValue(adjustedRect, axisDefinition, zeroValue);
-            borderGraphics.drawLine(adjustedRect.x, zeroX, adjustedRect.x + adjustedRect.width, zeroX);
+            int zeroY = computeYPixelValue(adjustedRect, axisDefinition, zeroValue);
+            borderGraphics.drawLine(adjustedRect.x, zeroY, adjustedRect.x + adjustedRect.width, zeroY);
+
+            // Optionally draw "Y" line  (UCSC track line option)
+            if(track.isDrawYLine()) {
+                Graphics2D yLineGraphics = context.getGraphic2DForColor(Color.gray);
+                int yLine = computeYPixelValue(adjustedRect, axisDefinition, track.getYLine());
+                GraphicUtils.drawDashedLine(borderGraphics, adjustedRect.x, yLine, adjustedRect.x + adjustedRect.width, yLine);
+            }
+
 
             // If the chart has + and - numbers draw both borders or none. This
             // needs documented somewhere.
             boolean drawBorders = true;
 
             if (minValue * maxValue < 0) {
-                drawBorders = prefs.isDrawBottomBorder() && prefs.isDrawTopBorder();
+                drawBorders = prefs.getAsBoolean(PreferenceManager.CHART_DRAW_BOTTOM_BORDER) &&
+                        prefs.getAsBoolean(PreferenceManager.CHART_DRAW_TOP_BORDER);
             }
 
-            if (drawBorders && prefs.isDrawTopBorder()) {
+            if (drawBorders && prefs.getAsBoolean(PreferenceManager.CHART_DRAW_TOP_BORDER)) {
                 borderGraphics.drawLine(adjustedRect.x, adjustedRect.y,
                         adjustedRect.x + adjustedRect.width, adjustedRect.y);
             }
 
-            if (drawBorders && prefs.isDrawBottomBorder()) {
+            if (drawBorders && prefs.getAsBoolean(PreferenceManager.CHART_DRAW_BOTTOM_BORDER)) {
                 borderGraphics.drawLine(adjustedRect.x, adjustedRect.y + adjustedRect.height,
                         adjustedRect.x + adjustedRect.width,
                         adjustedRect.y + adjustedRect.height);
             }
         }
+        /*
+        (CHART_DRAW_TOP_BORDER));
+        prefs.setDrawBottomBorder(getBooleanPreference(CHART_DRAW_BOTTOM_BORDER));
+        prefs.setColorBorders(getBooleanPreference(CHART_COLOR_BORDERS));
+        prefs.setDrawAxis(getBooleanPreference(CHART_DRAW_Y_AXIS));
+        prefs.setDrawTrackName(getBooleanPreference(CHART_DRAW_TRACK_NAME));
+        prefs.setColorTrackName(getBooleanPreference(CHART_COLOR_TRACK_NAME));
+        prefs.setAutoscale(getBooleanPreference(CHART_AUTOSCALE));
+        prefs.setShowDataRange(getBooleanPreference(CHART_SHOW_DATA_RANGE));
+         */
     }
 
     /**
@@ -357,7 +380,7 @@ public abstract class XYPlotRenderer extends DataRenderer {
 
     protected Rectangle calculateDrawingRect(Rectangle arect) {
 
-        double buffer = Math.min(arect.getHeight() * 0.2, 10);
+        double buffer = Math.min(arect.getHeight() * marginFraction, 10);
         Rectangle adjustedRect = new Rectangle(arect);
         adjustedRect.y = (int) (arect.getY() + buffer);
         adjustedRect.height = (int) (arect.height - (adjustedRect.y - arect.getY()));
@@ -366,4 +389,7 @@ public abstract class XYPlotRenderer extends DataRenderer {
         return adjustedRect;
     }
 
+    public void setMarginFraction(double marginFraction) {
+        this.marginFraction = marginFraction;
+    }
 }
