@@ -18,12 +18,13 @@
 package org.broad.igv.sam;
 
 import org.broad.igv.PreferenceManager;
-import org.broad.igv.feature.SequenceManager;
 import org.broad.igv.feature.Strand;
+import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.renderer.ContinuousColorScale;
 import org.broad.igv.renderer.GraphicUtils;
 import org.broad.igv.track.RenderContext;
 import org.broad.igv.ui.FontManager;
+import org.broad.igv.ui.IGV;
 import org.broad.igv.util.ChromosomeColors;
 import org.broad.igv.util.ColorUtilities;
 
@@ -67,6 +68,7 @@ public class AlignmentRenderer implements FeatureRenderer {
     static Map<String, Color> frOrientationColors;
     static Map<String, Color> ffOrientationColors;
     static Map<String, Color> rfOrientationColors;
+    private static final Color OUTLINE_COLOR = new Color(185, 185, 185);
 
     PreferenceManager prefs;
 
@@ -208,7 +210,7 @@ public class AlignmentRenderer implements FeatureRenderer {
             }
 
             // Draw posA border around the center base
-            if (locScale < 5 && renderOptions.shadeCenters) {
+            if (locScale < 5 && renderOptions.showCenterLine) {
                 // Calculate center lines
                 double center = (int) (context.getReferenceFrame().getCenter() - origin);
                 int centerLeftP = (int) (center / locScale);
@@ -283,6 +285,17 @@ public class AlignmentRenderer implements FeatureRenderer {
         }
     }
 
+    /**
+     * Draw a pair of alignments as a single "template".
+     *
+     * @param pair
+     * @param rect
+     * @param context
+     * @param renderOptions
+     * @param leaveMargin
+     * @param selectedReadNames
+     * @param font
+     */
     private void drawPairedAlignment(
             PairedAlignment pair,
             Rectangle rect,
@@ -322,6 +335,8 @@ public class AlignmentRenderer implements FeatureRenderer {
     }
 
     /**
+     * Draw a (possible) gapped alignment
+     *
      * @param alignment
      * @param rect
      * @param g
@@ -345,14 +360,15 @@ public class AlignmentRenderer implements FeatureRenderer {
         double locScale = context.getScale();
         AlignmentBlock[] blocks = alignment.getAlignmentBlocks();
 
+        // No blocks.  Note: SAM/BAM alignments always have at least 1 block
         if (blocks == null || blocks.length == 0) {
             drawSimpleAlignment(alignment, rect, g, context, renderOptions.flagUnmappedPairs);
             return;
         }
 
+        // Get the terminal block (last block with respect to read direction).  This will have an "arrow" attached.
         AlignmentBlock terminalBlock = alignment.isNegativeStrand() ? blocks[0] : blocks[blocks.length - 1];
 
-        Graphics2D greyGraphics = context.getGraphic2DForColor(new Color(185, 185, 185));
 
         int lastBlockEnd = Integer.MIN_VALUE;
 
@@ -368,40 +384,26 @@ public class AlignmentRenderer implements FeatureRenderer {
             int y = (int) (rect.getY()); // + (rect.getHeight() - h) / 2);
 
 
-            // Create polygon to represent the alignment.
-            boolean isZeroQuality = alignment.getMappingQuality() == 0;
+            // Get a graphics context for outlining reads
+            Graphics2D outlineGraphics = context.getGraphic2DForColor(OUTLINE_COLOR);
 
+            // Create polygon to represent the alignment.
+            boolean isZeroQuality = alignment.getMappingQuality() == 0 && renderOptions.flagZeroQualityAlignments;
+
+            // If we're zoomed in and this is a large block clip a pixel off each end.  TODO - why?
             if (highZoom && w > 10) {
                 x++;
                 w -= 2;
             }
 
-            // If block is out of view skip
+            // If block is out of view skip -- this is important in the case of PacBio and other platforms with very long reads
             if (x + w >= rect.x && x <= rect.getMaxX()) {
-                if (w <= 10 || h <= 10 || aBlock != terminalBlock) {
-                    g.fillRect(x, y, w, h);
-                    if (isZeroQuality) {
-                        greyGraphics.drawRect(x, y, w - 1, h);
-                    }
 
-                    if (renderOptions.flagUnmappedPairs && alignment.isPaired() && !alignment.getMate().isMapped()) {
-                        Graphics2D cRed = context.getGraphic2DForColor(Color.red);
-                        cRed.drawRect(x, y, w, h);
-                    }
+                Shape blockShape = null;
 
-                    if (selectedReadNames.containsKey(alignment.getReadName())) {
-                        Color c = selectedReadNames.get(alignment.getReadName());
-                        if (c == null) {
-                            c = Color.blue;
-                        }
-                        Graphics2D cBlue = context.getGraphic2DForColor(c);
-                        Stroke s = cBlue.getStroke();
-                        cBlue.setStroke(thickStroke);
-                        cBlue.drawRect(x, y, w, h);
-                        cBlue.setStroke(s);
-                    }
+                // If this is a terminal block draw the "arrow" to indicate strand position.  Otherwise draw a rectangle.
+                if ((aBlock == terminalBlock) && w > 10 && h > 10) {
 
-                } else {
                     int arrowLength = Math.min(5, w / 6);
 
                     // Don't draw off edge of clipping rect
@@ -431,30 +433,36 @@ public class AlignmentRenderer implements FeatureRenderer {
                     } else {
                         xPoly = new int[]{x, x + w, x + w + arrowLength, x + w, x};
                     }
-                    g.fillPolygon(xPoly, yPoly, xPoly.length);
-
-
-                    if (isZeroQuality) {
-                        greyGraphics.drawPolygon(xPoly, yPoly, xPoly.length);
-                    }
-
-                    if (renderOptions.flagUnmappedPairs && alignment.isPaired() && !alignment.getMate().isMapped()) {
-                        Graphics2D cRed = context.getGraphic2DForColor(Color.red);
-                        cRed.drawPolygon(xPoly, yPoly, xPoly.length);
-                    }
-
-                    if (selectedReadNames.containsKey(alignment.getReadName())) {
-                        Color c = selectedReadNames.get(alignment.getReadName());
-                        if (c == null) {
-                            c = Color.blue;
-                        }
-                        Graphics2D cBlue = context.getGraphic2DForColor(c);
-                        Stroke s = cBlue.getStroke();
-                        cBlue.setStroke(thickStroke);
-                        cBlue.drawPolygon(xPoly, yPoly, xPoly.length);
-                        cBlue.setStroke(s);
-                    }
+                    blockShape = new Polygon(xPoly, yPoly, xPoly.length);
                 }
+                else {
+                    // Not a terminal block, or too small for arrow
+                    blockShape = new Rectangle(x, y, w, h);
+                }
+
+                g.fill(blockShape);
+
+                if (isZeroQuality) {
+                    outlineGraphics.draw(blockShape);
+                }
+
+                if (renderOptions.flagUnmappedPairs && alignment.isPaired() && !alignment.getMate().isMapped()) {
+                    Graphics2D cRed = context.getGraphic2DForColor(Color.red);
+                    cRed.draw(blockShape);
+                }
+
+                if (selectedReadNames.containsKey(alignment.getReadName())) {
+                    Color c = selectedReadNames.get(alignment.getReadName());
+                    if (c == null) {
+                        c = Color.blue;
+                    }
+                    Graphics2D cBlue = context.getGraphic2DForColor(c);
+                    Stroke s = cBlue.getStroke();
+                    cBlue.setStroke(thickStroke);
+                    cBlue.draw(blockShape);
+                    cBlue.setStroke(s);
+                }
+
             }
 
 
@@ -517,7 +525,8 @@ public class AlignmentRenderer implements FeatureRenderer {
         double locScale = context.getScale();
         double origin = context.getOrigin();
         String chr = context.getChr();
-        String genome = context.getGenomeId();
+        //String genomeId = context.getGenomeId();
+        Genome genome = IGV.getInstance().getGenomeManager().getCurrentGenome();
 
         byte[] read = block.getBases();
         boolean isSoftClipped = block.isSoftClipped();
@@ -538,7 +547,7 @@ public class AlignmentRenderer implements FeatureRenderer {
 
             int start = block.getStart();
             int end = start + read.length;
-            byte[] reference = isSoftClipped ? null : SequenceManager.readSequence(genome, chr, start, end);
+            byte[] reference = isSoftClipped ? null : genome.getSequence(chr, start, end);
 
 
             // Loop through base pair coordinates
@@ -551,13 +560,18 @@ public class AlignmentRenderer implements FeatureRenderer {
                 // Is this base posA mismatch?  Note '=' means indicates posA match by definition
                 // If we do not have posA valid reference we assume posA match.  Soft clipped
                 // bases are considered mismatched by definition
-                boolean misMatch =
-                        isSoftClipped ||
-                                (read[idx] != '=' &&
-                                        reference != null &&
-                                        idx < reference.length &&
-                                        reference[idx] != 0 &&
-                                        reference[idx] != read[idx]);
+                boolean misMatch;
+                if (isSoftClipped) {
+                    misMatch = true;  // <= by definition, any matches are coincidence
+                } else {
+                    final byte refbase = reference[idx];
+                    final byte readbase = read[idx];
+                    misMatch = readbase != '=' &&
+                            reference != null &&
+                            idx < reference.length &&
+                            refbase != 0 &&
+                            !compareBases(refbase, readbase);
+                }
 
                 if (misMatch || showAllBases) {
                     char c = (char) read[loc - start];
@@ -602,11 +616,60 @@ public class AlignmentRenderer implements FeatureRenderer {
                         }
                     }
                 }
-
             }
         }
     }
 
+    /**
+     * Return true if the two bases can be considered a match.  The comparison is case-insentive, and
+     * ambiguity codes.
+     *
+     * @param refbase
+     * @param readbase
+     * @return
+     */
+    private static boolean compareBases(byte refbase, byte readbase) {
+        // Force both bases to upper case
+        if (refbase > 90) {
+            refbase = (byte) (refbase - 32);
+        }
+        if (readbase > 90) {
+            readbase = (byte) (readbase - 32);
+        }
+        if (refbase == readbase) {
+            return true;
+        }
+        switch (refbase) {
+            case 'N':
+                return true; // Everything matches 'N'
+            case 'U':
+                return readbase == 'T';
+            case 'M':
+                return readbase == 'A' || readbase == 'C';
+            case 'R':
+                return readbase == 'A' || readbase == 'G';
+            case 'W':
+                return readbase == 'A' || readbase == 'T';
+            case 'S':
+                return readbase == 'C' || readbase == 'G';
+            case 'Y':
+                return readbase == 'C' || readbase == 'T';
+            case 'K':
+                return readbase == 'G' || readbase == 'T';
+            case 'V':
+                return readbase == 'A' || readbase == 'C' || readbase == 'G';
+            case 'H':
+                return readbase == 'A' || readbase == 'C' || readbase == 'T';
+            case 'D':
+                return readbase == 'A' || readbase == 'G' || readbase == 'T';
+            case 'B':
+                return readbase == 'C' || readbase == 'G' || readbase == 'T';
+
+            default:
+                return refbase == readbase;
+        }
+    }
+
     private Color getShadedColor(byte qual, Color color, PreferenceManager prefs) {
         float alpha = 0;
         int minQ = prefs.getAsInt(PreferenceManager.SAM_BASE_QUALITY_MIN);
@@ -687,7 +750,7 @@ public class AlignmentRenderer implements FeatureRenderer {
         if (lb == null) lb = "null";
         PEStats peStats = renderOptions.peStats.get(lb);
 
-        Color c = grey1;
+        Color c = alignment.getDefaultColor();
         switch (renderOptions.colorOption) {
             case INSERT_SIZE:
                 boolean isPairedAlignment = alignment instanceof PairedAlignment;
@@ -770,7 +833,7 @@ public class AlignmentRenderer implements FeatureRenderer {
                 }
         }
 
-        if (alignment.getMappingQuality() == 0) {
+        if (alignment.getMappingQuality() == 0 && renderOptions.flagZeroQualityAlignments) {
             // Maping Q = 0
             float alpha = 0.15f;
             c.getColorComponents(rbgBuffer);
