@@ -46,8 +46,8 @@ public class ReadMate {
         return chr + ":" + start + " (" + (isNegativeStrand() ? "-" : "+") + ")";
     }
 
-    public String getLocus() {
-        return chr + ":" + start;
+    public int getStart() {
+        return start;
     }
 
     /**
