@@ -1,19 +1,19 @@
 /*
- * Copyright (c) 2007-2010 by The Broad Institute, Inc. and the Massachusetts Institute of Technology.
- * All Rights Reserved.
+ * Copyright (c) 2007-2011 by The Broad Institute of MIT and Harvard.  All Rights Reserved.
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL), Version 2.1 which
- * is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
+ * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
  *
- * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR WARRANTIES OF
- * ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING, WITHOUT LIMITATION, WARRANTIES
- * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT
- * OR OTHER DEFECTS, WHETHER OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR
- * RESPECTIVE TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES OF
- * ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES, ECONOMIC
- * DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER THE BROAD OR MIT SHALL
- * BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT SHALL KNOW OF THE POSSIBILITY OF THE
- * FOREGOING.
+ * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR
+ * WARRANTES OF ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING,
+ * WITHOUT LIMITATION, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
+ * PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT OR OTHER DEFECTS, WHETHER
+ * OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR RESPECTIVE
+ * TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES
+ * OF ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES,
+ * ECONOMIC DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER
+ * THE BROAD OR MIT SHALL BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT
+ * SHALL KNOW OF THE POSSIBILITY OF THE FOREGOING.
  */
 package org.broad.igv.sam;
 
@@ -23,13 +23,16 @@ import net.sf.samtools.SAMFileHeader;
 import net.sf.samtools.SAMReadGroupRecord;
 import net.sf.samtools.SAMRecord;
 import org.apache.log4j.Logger;
+import org.broad.igv.Globals;
 import org.broad.igv.PreferenceManager;
-import org.broad.igv.feature.Genome;
+import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.feature.LocusScore;
 import org.broad.igv.feature.Strand;
-import org.broad.igv.session.ViewContext;
 import org.broad.igv.track.WindowFunction;
+import org.broad.igv.ui.IGV;
+import org.broad.igv.util.ColorUtilities;
 
+import java.awt.*;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
@@ -74,6 +77,10 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
     boolean secondRead = false;
     private String mateSequence = null;
     private String pairOrientation = "";
+    private Color defaultColor = AlignmentRenderer.grey1;
+    private String readGroup;
+    private String library;
+    private String sample;
 
     /**
      * Constructs ...
@@ -87,7 +94,7 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
 
         String refName = record.getReferenceName();
 
-        Genome genome = ViewContext.getInstance().getGenome();
+        Genome genome = Globals.isHeadless() ? null : IGV.getInstance().getGenomeManager().getCurrentGenome();
         this.chr = genome == null ? refName : genome.getChromosomeAlias(refName);
 
 
@@ -111,6 +118,30 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
         setPairOrientation(record);
         setFirstReadStrand(record);
         createAlignmentBlocks(record.getCigarString(), record.getReadBases(), record.getBaseQualities());
+
+        SAMFileHeader header = record.getHeader();
+        if (header != null) {
+            readGroup = (String) record.getAttribute("RG");
+            if (readGroup != null) {
+                SAMReadGroupRecord rgRec = header.getReadGroup(readGroup);
+                if (rgRec != null) {
+                    String platform = rgRec.getPlatform();
+                    sample = rgRec.getSample();
+                    library = rgRec.getLibrary();
+
+                }
+            }
+        }
+
+        Object colorTag = record.getAttribute("YC");
+        if (colorTag != null) {
+            try {
+                defaultColor = ColorUtilities.stringToColor(colorTag.toString());
+            } catch (Exception e) {
+                log.error("Error interpreting color tag: " + colorTag, e);
+                defaultColor = AlignmentRenderer.grey1;
+            }
+        }
     }
 
     private void setFirstReadStrand(SAMRecord record) {
@@ -222,7 +253,7 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
 
     void createAlignmentBlocks(String cigarString, byte[] readBases, byte[] readBaseQualities) {
 
-        boolean showSoftClipped = PreferenceManager.getInstance().getSAMPreferences().isShowSoftClipped();
+        boolean showSoftClipped = PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SAM_SHOW_SOFT_CLIPPED);
 
 
         int nInsertions = 0;
@@ -237,6 +268,8 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
             return;
         }
 
+
+        // Create list of cigar operators
         boolean firstOperator = true;
         int softClippedBaseCount = 0;
         int nGaps = 0;
@@ -246,8 +279,12 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
             if (Character.isDigit(next)) {
                 buffer.append(next);
             } else {
-                int nBases = Integer.parseInt(buffer.toString());
                 char op = next;
+                if (op == HARD_CLIP) {
+                    buffer = new StringBuffer(4);
+                    continue;  // Just skip hardclips
+                }
+                int nBases = Integer.parseInt(buffer.toString());
                 if (operatorIsMatch(showSoftClipped, op)) {
                     if (operatorIsMatch(showSoftClipped, prevOp)) {
                         nGaps++;   // Consecutive Ms
@@ -275,99 +312,114 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
 
         alignmentBlocks = new AlignmentBlock[nBlocks];
         insertions = new AlignmentBlock[nInsertions];
-        if (nGaps > 0)
-
-        {
+        if (nGaps > 0) {
             gapTypes = new char[nGaps];
         }
 
-        // Adjust start and fill new arrays
-        if(showSoftClipped) {
+        // Adjust start to include soft clipped bases a
+        if (showSoftClipped) {
             start -= softClippedBaseCount;
         }
         int fromIdx = showSoftClipped ? 0 : softClippedBaseCount;
         int blockStart = start;
 
+        // Create blocks
         int blockIdx = 0;
         int insertionIdx = 0;
         int gapIdx = 0;
         prevOp = 0;
         for (CigarOperator op : operators) {
-            if (operatorIsMatch(showSoftClipped, op.operator)) {
+            try {
 
-                byte[] blockBases = new byte[op.nBases];
-                byte[] blockQualities = new byte[op.nBases];
-                //Default value
-                Arrays.fill(blockQualities, (byte) 126);
-
-                // TODO -- represent missing sequence ("*") explicitly rather.
-                if (readBases == null || readBases.length == 0) {
-                    Arrays.fill(blockBases, (byte) '=');
-                } else {
-                    System.arraycopy(readBases, fromIdx, blockBases, 0, op.nBases);
+                if (op.operator == HARD_CLIP) {
+                    continue;
                 }
+                if (operatorIsMatch(showSoftClipped, op.operator)) {
 
-                if (readBaseQualities == null || readBaseQualities.length == 0) {
+                    byte[] blockBases = new byte[op.nBases];
+                    byte[] blockQualities = new byte[op.nBases];
+
+
+                    //Default value
                     Arrays.fill(blockQualities, (byte) 126);
-                } else {
-                    System.arraycopy(readBaseQualities, fromIdx, blockQualities, 0, op.nBases);
-                }
 
-                AlignmentBlock block = new AlignmentBlock(blockStart, blockBases, blockQualities);
-                if(op.operator == SOFT_CLIP) {
-                    block.setSoftClipped(true);
-                }
-                alignmentBlocks[blockIdx++] = block;
+                    int nBasesAvailable = readBases.length - fromIdx;
 
-                fromIdx += op.nBases;
-                blockStart += op.nBases;
+                    // TODO -- represent missing sequence ("*") explicitly for efficiency.
+                    if (readBases == null || readBases.length == 0) {
+                        Arrays.fill(blockBases, (byte) '=');
+                    } else if (nBasesAvailable < op.nBases) {
+                        Arrays.fill(blockBases, (byte) '?');
+                    } else {
+                        System.arraycopy(readBases, fromIdx, blockBases, 0, op.nBases);
 
-                if (operatorIsMatch(showSoftClipped, prevOp)) {
+                    }
+
+                    nBasesAvailable = readBaseQualities.length - fromIdx;
+                    if (readBaseQualities == null || readBaseQualities.length == 0 || nBasesAvailable < op.nBases) {
+                        Arrays.fill(blockQualities, (byte) 126);
+                    } else {
+                        System.arraycopy(readBaseQualities, fromIdx, blockQualities, 0, op.nBases);
+                    }
+
+                    AlignmentBlock block = new AlignmentBlock(blockStart, blockBases, blockQualities);
+                    if (op.operator == SOFT_CLIP) {
+                        block.setSoftClipped(true);
+                    }
+                    alignmentBlocks[blockIdx++] = block;
+
+                    fromIdx += op.nBases;
+                    blockStart += op.nBases;
+
+                    if (operatorIsMatch(showSoftClipped, prevOp)) {
+                        gapTypes[gapIdx++] = ZERO_GAP;
+                    }
+
+                } else if (op.operator == DELETION || op.operator == SKIPPED_REGION) {
+                    blockStart += op.nBases;
+                    gapTypes[gapIdx++] = op.operator;
+                } else if (op.operator == INSERTION) {
+
+                    // This gap is between blocks split by insertion.   It is posA zero
+                    // length gap but must be accounted for.
                     gapTypes[gapIdx++] = ZERO_GAP;
+
+                    byte[] blockBases = new byte[op.nBases];
+                    byte[] blockQualities = new byte[op.nBases];
+
+                    if (readBases == null || readBases.length == 0) {
+                        Arrays.fill(blockBases, (byte) '=');
+                    } else {
+                        System.arraycopy(readBases, fromIdx, blockBases, 0, op.nBases);
+                    }
+
+                    if (readBaseQualities == null || readBaseQualities.length == 0) {
+                        Arrays.fill(blockQualities, (byte) 126);
+                    } else {
+                        System.arraycopy(readBaseQualities, fromIdx, blockQualities, 0, op.nBases);
+                    }
+
+                    insertions[insertionIdx++] = new AlignmentBlock(blockStart, blockBases, blockQualities);
+
+
+                    fromIdx += op.nBases;
+
                 }
-
-            } else if (op.operator == DELETION || op.operator == SKIPPED_REGION) {
-                blockStart += op.nBases;
-                gapTypes[gapIdx++] = op.operator;
-            } else if (op.operator == INSERTION) {
-
-                // This gap is between blocks split by insertion.   It is posA zero
-                // length gap but must be accounted for.
-                gapTypes[gapIdx++] = ZERO_GAP;
-
-                byte[] blockBases = new byte[op.nBases];
-                byte[] blockQualities = new byte[op.nBases];
-
-                if (readBases == null || readBases.length == 0) {
-                    Arrays.fill(blockBases, (byte) '=');
-                } else {
-                    System.arraycopy(readBases, fromIdx, blockBases, 0, op.nBases);
-                }
-
-                if (readBaseQualities == null || readBaseQualities.length == 0) {
-                    Arrays.fill(blockQualities, (byte) 126);
-                } else {
-                    System.arraycopy(readBaseQualities, fromIdx, blockQualities, 0, op.nBases);
-                }
-
-                insertions[insertionIdx++] = new AlignmentBlock(blockStart, blockBases, blockQualities);
-
-                fromIdx += op.nBases;
-
+            } catch (Exception e) {
+                e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
             }
             prevOp = op.operator;
         }
 
         // Check for soft clipping at end
-        if(showSoftClipped && operators.size() > 0 ) {
-            CigarOperator last = operators.get(operators.size()-1);
-            if(last.operator == SOFT_CLIP) {
+        if (showSoftClipped && operators.size() > 0) {
+            CigarOperator last = operators.get(operators.size() - 1);
+            if (last.operator == SOFT_CLIP) {
                 end += last.nBases;
             }
         }
 
 
-
     }
 
     private boolean operatorIsMatch(boolean showSoftClipped, char operator) {
@@ -473,28 +525,15 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
     }
 
     public String getSample() {
-
-        SAMFileHeader header = record.getHeader();
-        if (header != null) {
-            String rg = (String) record.getAttribute("RG");
-            if (rg != null) {
-                SAMReadGroupRecord rgRec = header.getReadGroup(rg);
-                if (rgRec != null) {
-                    return rgRec.getSample();
-                }
-            }
-        }
-        return null;
+        return sample;
     }
 
     public String getReadGroup() {
+        return readGroup;
+    }
 
-        SAMFileHeader header = record.getHeader();
-        if (header != null) {
-            String readGroup = (String) record.getAttribute("RG");
-            return (String) record.getAttribute("RG");
-        }
-        return null;
+    public String getLibrary() {
+        return library;
     }
 
     @Override
@@ -515,6 +554,11 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
         return record.getAttribute(key);
     }
 
+
+    public String getClipboardString(double location) {
+        return getValueStringImpl(location, false);
+    }
+
     /**
      * Return info string for popup text and to copy to clipboard
      *
@@ -523,7 +567,12 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
      * @return
      */
     public String getValueString(double position, WindowFunction windowFunction) {
-        StringBuffer buf = new StringBuffer(super.getValueString(position, windowFunction));
+        return getValueStringImpl(position, true);
+    }
+
+    String getValueStringImpl(double position, boolean truncate) {
+
+        StringBuffer buf = new StringBuffer(super.getValueString(position, null));
 
         if (isPaired()) {
             if (record.getFirstOfPairFlag()) {
@@ -545,7 +594,12 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
         if (attributes != null && !attributes.isEmpty()) {
 
             for (SAMRecord.SAMTagAndValue tag : attributes) {
-                buf.append("<br>" + tag.tag + " = " + tag.value);
+                String tagValue = tag.value.toString();
+                if(tagValue.length() > 50 && truncate) {
+                   tagValue = tagValue.substring(0, 50) + "...";
+                }
+
+                buf.append("<br>" + tag.tag + " = " + tagValue);
             }
             buf.append("<br>-------------------");
         }
@@ -555,7 +609,6 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
             buf.append("<br>-------------------");
         }
         return buf.toString();
-
     }
 
     public boolean isFirstInPair() {
@@ -579,6 +632,10 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
         return record.getReadFailsVendorQualityCheckFlag();
     }
 
+    public Color getDefaultColor() {
+        return defaultColor;
+    }
+
     static class CigarOperator {
 
         int nBases;
