@@ -1,19 +1,19 @@
 /*
- * Copyright (c) 2007-2010 by The Broad Institute, Inc. and the Massachusetts Institute of Technology.
- * All Rights Reserved.
+ * Copyright (c) 2007-2011 by The Broad Institute of MIT and Harvard.  All Rights Reserved.
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL), Version 2.1 which
- * is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
+ * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
  *
- * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR WARRANTIES OF
- * ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING, WITHOUT LIMITATION, WARRANTIES
- * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT
- * OR OTHER DEFECTS, WHETHER OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR
- * RESPECTIVE TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES OF
- * ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES, ECONOMIC
- * DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER THE BROAD OR MIT SHALL
- * BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT SHALL KNOW OF THE POSSIBILITY OF THE
- * FOREGOING.
+ * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR
+ * WARRANTES OF ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING,
+ * WITHOUT LIMITATION, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
+ * PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT OR OTHER DEFECTS, WHETHER
+ * OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR RESPECTIVE
+ * TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES
+ * OF ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES,
+ * ECONOMIC DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER
+ * THE BROAD OR MIT SHALL BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT
+ * SHALL KNOW OF THE POSSIBILITY OF THE FOREGOING.
  */
 
 package org.broad.igv.sam.reader;
@@ -22,17 +22,18 @@ import net.sf.samtools.SAMFileHeader;
 import net.sf.samtools.SAMFileReader;
 import net.sf.samtools.SAMRecord;
 import net.sf.samtools.SAMSequenceRecord;
-import net.sf.samtools.util.CloseableIterator;
+import net.sf.samtools.util.*;
 import org.apache.log4j.Logger;
+import org.broad.igv.Globals;
 import org.broad.igv.exceptions.DataLoadException;
 import org.broad.igv.sam.Alignment;
-import org.broad.igv.ui.UIConstants;
 import org.broad.igv.ui.util.MessageUtils;
-import org.broad.igv.util.IGVHttpUtils;
-import org.broad.igv.util.SeekableStreamFactory;
+import org.broad.igv.util.*;
+import org.broad.igv.util.HttpUtils;
+import org.broad.igv.util.stream.SeekablePicardFtpStream;
+import org.broad.igv.util.stream.SeekablePicardHTTPStream;
 
 import java.io.*;
-import java.net.MalformedURLException;
 import java.net.URL;
 import java.util.*;
 
@@ -54,18 +55,31 @@ public class BAMHttpQueryReader implements AlignmentQueryReader {
     File indexFile;
     SAMFileReader reader;
 
-    public BAMHttpQueryReader(URL url) {
-        this.url = url;
-        indexFile = getIndexFile(url);
+    public BAMHttpQueryReader(ResourceLocator locator, boolean requireIndex) throws IOException {
+        this.url = new URL(locator.getPath());
+        if (requireIndex) {
+            indexFile = getIndexFile(url, locator.getIndexPath());
+            if(indexFile == null) {
+                throw new RuntimeException("Could not load index file for file: " + url.getPath());
+            }
+            SeekableStream ss = new SeekableBufferedStream(getSeekableStream(url));
+            reader = new SAMFileReader(ss, indexFile, false);
+        } else {
+            InputStream is = HttpUtils.getInstance().openConnectionStream(url);
+            reader = new SAMFileReader(new BufferedInputStream(is));
+        }
+
     }
 
     public void close() throws IOException {
-        //To change body of implemented methods use File | Settings | File Templates.
+        if (reader != null) {
+            reader.close();
+        }
     }
 
     public SAMFileHeader getHeader() {
         if (header == null) {
-            loadHeader();
+            header = reader.getFileHeader();
         }
         return header;
     }
@@ -90,10 +104,11 @@ public class BAMHttpQueryReader implements AlignmentQueryReader {
         return seqNames;
     }
 
+
     public CloseableIterator<Alignment> iterator() {
         try {
             if (reader == null) {
-                InputStream is = url.openStream();
+                InputStream is = HttpUtils.getInstance().openConnectionStream(url);
                 reader = new SAMFileReader(new BufferedInputStream(is));
             }
             return new WrappedIterator(reader.iterator());
@@ -106,161 +121,95 @@ public class BAMHttpQueryReader implements AlignmentQueryReader {
     }
 
     public CloseableIterator<Alignment> query(String sequence, int start, int end, boolean contained) {
-        if (reader == null) {
-            reader = new SAMFileReader(url, indexFile, false);
+        try {
+            if (reader == null) {
+                SeekableStream ss = new SeekableBufferedStream(getSeekableStream(url));
+                reader = new SAMFileReader(ss, indexFile, false);
+            }
+            CloseableIterator<SAMRecord> iter = reader.query(sequence, start, end, contained);
+            return new WrappedIterator(iter);
+        } catch (IOException e) {
+            log.error("Error opening SAM reader", e);
+            throw new RuntimeException("Error opening SAM reader", e);
         }
-        log.debug("Query " + sequence + ":" + start + "-" + end);
-        CloseableIterator<SAMRecord> iter = reader.query(sequence, start, end, contained);
-        return new WrappedIterator(iter);
     }
 
-
-    private void loadHeader() {
-
-        InputStream is = null;
-        SAMFileReader reader = null;
-        try {
-            Map<String, String> props = new HashMap();
-            String byteRange = "bytes=0-1000000";
-            props.put("Range", byteRange);
-
-            is = SeekableStreamFactory.getStreamFor(url.toString()); //  IGVHttpUtils.openConnectionStream(url);
-            BufferedInputStream bis = new BufferedInputStream(is);
-            reader = new SAMFileReader(bis);
-            header = reader.getFileHeader();
-
-        }
-        catch (IOException e) {
-            e.printStackTrace();
-        }
-        finally {
-            try {
-                if (is != null) {
-                    is.close();
-                }
-                if (reader != null) {
-                    reader.close();
-                }
-
-            }
-            catch (Exception e) {
-
+    private SeekableStream getSeekableStream(URL url) throws IOException {
+        String protocol = url.getProtocol().toLowerCase();
+        SeekableStream is = null;
+        if (protocol.equals("http") || protocol.equals("https")) {
+            boolean useByteRange = HttpUtils.getInstance().useByteRange(url);
+            if (useByteRange) {              
+                is = new SeekablePicardHTTPStream(url);
+            } else {
+                throw new RuntimeException("Byte-range requests are disabled.  HTTP and FTP access to BAM files require byte-range support.");
             }
+        } else if (protocol.equals("ftp")) {
+            is = new SeekablePicardFtpStream(url);
+        } else {
+            throw new RuntimeException("Unknown protocol: " + protocol);
         }
+        return is;
     }
 
 
     // TODO -- revisit caching scehme,  do something for ftp loads
 
-    File getIndexFile(URL bamURL) {
+    File getIndexFile(URL url, String indexPath) throws IOException {
 
-        try {
-            String bamURLString = bamURL.toString();
-            String urlString = bamURLString + ".bai";
-            URL indexURL = new URL(urlString);
-            String eTag = null;
-            Properties eTagCache = getTagCache();
+        String urlString = url.toString();
 
-            // TODO -- ftp
-            if (urlString.toLowerCase().startsWith("http:") || urlString.toLowerCase().startsWith("https:")) {
-                eTag = IGVHttpUtils.getETag(indexURL);
+        // Create a filename unique for this url;
+        String idxFilename = getTmpIndexFilename(urlString);
 
-
-                // Try other naming convention
-                if (eTag == null) {
-                    // Try other index convention
-                    String baseName = bamURLString.substring(0, bamURLString.length() - 4);
-                    indexURL = new URL(baseName + ".bai");
-
-                    urlString = bamURL.toString().replace(".bam", ".bai");
-                    indexURL = new URL(urlString);
-                    eTag = IGVHttpUtils.getETag(indexURL);
-                }
-            }
-
-
-            // Create a filename unique for this url;
-            String idxFilename = getCachedIndexFilename(bamURLString);
-
-            if (eTag != null) {
-                File indexFile = new File(this.getCacheDirectory(), idxFilename);
-                if (indexFile.exists()) {
-                    String cachedETag = eTagCache.getProperty(urlString);
-                    if (eTag == null || cachedETag == null || !eTag.equals(cachedETag)) {
-                        indexFile.delete();
-                        eTagCache.remove(urlString);
-                        writeCachedProperties(eTagCache, "etags");
-                    }
-                }
-            }
-
-            indexFile = new File(this.getCacheDirectory(), idxFilename);
-            if (!indexFile.exists()) {
-                loadIndexFile(bamURL.toString(), indexFile);
-                if (eTag != null) {
-                    eTagCache.put(urlString, eTag);
-                    writeCachedProperties(eTagCache, "etags");
-                } else {
-                    indexFile.deleteOnExit();
-                }
-            }
-            return indexFile;
-        } catch (MalformedURLException e) {
-            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
-            return null;
+        indexFile = new File(this.getCacheDirectory(), idxFilename);
+        if (indexFile.exists()) {
+            indexFile.delete();
         }
+        loadIndexFile(urlString, indexPath, indexFile);
+        indexFile.deleteOnExit();
+
+        return indexFile;
+
     }
 
-    private String getCachedIndexFilename(String bamURL) {
-
-        Properties lookup = getIndexCache();
-        String indexName = lookup.getProperty(bamURL);
-        if (indexName == null) {
-            int tmp = bamURL.lastIndexOf("/");
-            String prefix = tmp > 0 ? bamURL.substring(tmp + 1) : "index_";
-            indexName = prefix + System.currentTimeMillis() + ".bai";
-            lookup.put(bamURL, indexName);
-            writeCachedProperties(lookup, "index");
-        }
-
+    private String getTmpIndexFilename(String bamURL) {
+        int tmp = bamURL.lastIndexOf("/");
+        String prefix = tmp > 0 ? bamURL.substring(tmp + 1) : "index_";
+        String indexName = prefix + System.currentTimeMillis() + ".bai";
         return indexName;
     }
 
-    private void loadIndexFile(String bamURL, File indexFile) {
+    private void loadIndexFile(String path, String indexPath, File indexFile) throws IOException {
         InputStream is = null;
         OutputStream os = null;
 
         try {
-            URL indexURL = new URL(bamURL + ".bai");
+            String idx = (indexPath != null && indexPath.length() > 0) ? indexPath : path + ".bai";
+            URL indexURL = new URL(idx);
             os = new FileOutputStream(indexFile);
             try {
-                is = indexURL.openStream();
-
+                is = HttpUtils.getInstance().openConnectionStream(indexURL);
             }
             catch (FileNotFoundException e) {
                 // Try other index convention
-                String baseName = bamURL.substring(0, bamURL.length() - 4);
+                String baseName = path.substring(0, path.length() - 4);
                 indexURL = new URL(baseName + ".bai");
 
                 try {
-                    is = indexURL.openStream();
+                    is = org.broad.igv.util.HttpUtils.getInstance().openConnectionStream(indexURL);
                 }
                 catch (FileNotFoundException e1) {
-                    MessageUtils.showMessage("Index file not found for file: " + bamURL);
-                    throw new DataLoadException("Index file not found for file: " + bamURL, bamURL);
+                    MessageUtils.showMessage("Index file not found for file: " + path);
+                    throw new DataLoadException("Index file not found for file: " + path, path);
                 }
             }
-            byte[] buf = new byte[4 * 1024]; // 4K buffer
+            byte[] buf = new byte[512000];
             int bytesRead;
             while ((bytesRead = is.read(buf)) != -1) {
                 os.write(buf, 0, bytesRead);
             }
 
-        }
-        catch (IOException e) {
-            MessageUtils.showMessage("Error loading index file: " + indexFile.getAbsolutePath());
-            log.error("Error downloading index file ", e);
-
         }
         finally {
             if (is != null) {
@@ -287,7 +236,7 @@ public class BAMHttpQueryReader implements AlignmentQueryReader {
 
     static synchronized File getCacheDirectory() {
         if (cacheDirectory == null) {
-            File defaultDir = new File(UIConstants.DEFAULT_IGV_DIRECTORY);
+            File defaultDir = Globals.getIgvDirectory();
             if (defaultDir.exists()) {
                 cacheDirectory = new File(defaultDir, "bam");
                 if (!cacheDirectory.exists()) {
