@@ -23,16 +23,16 @@
 package org.broad.igv.sam.reader;
 
 import net.sf.samtools.*;
-import net.sf.samtools.util.AsciiLineReader;
+import net.sf.samtools.util.BufferedLineReader;
 import net.sf.samtools.util.CloseableIterator;
 import net.sf.samtools.util.LineReader;
 import org.apache.log4j.Logger;
 import org.broad.igv.sam.Alignment;
 import org.broad.igv.sam.SamAlignment;
-import org.broad.igv.util.IGVHttpClientUtils;
-import org.broad.igv.util.IGVHttpUtils;
+import org.broad.igv.util.HttpUtils;
 import org.broad.igv.util.ResourceLocator;
 
+import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.net.URL;
@@ -70,7 +70,7 @@ public class BAMRemoteQueryReader implements AlignmentQueryReader {
         try {
             URL url = new URL(serverURL + "?method=samQuery&samFile=" + file + "&chr=" +
                     chr + "&start=" + start + "&end=" + end + "&contained=" + contained);
-            InputStream is = IGVHttpClientUtils.openConnectionStream(url);
+            InputStream is = HttpUtils.getInstance().openConnectionStream(url);
             return new RemoteQueryIterator(new GZIPInputStream(is, 8192));
 
         } catch (IOException ex) {
@@ -108,11 +108,11 @@ public class BAMRemoteQueryReader implements AlignmentQueryReader {
         InputStream is = null;
         try {
             URL url = new URL(serverURL + "?method=samHeader&samFile=" + file);
-            is = IGVHttpClientUtils.openConnectionStream(url);
+            is = HttpUtils.getInstance().openConnectionStream(url);
 
-            LineReader reader = new AsciiLineReader(is);
-            SAMTextHeaderCodec code = new SAMTextHeaderCodec();
-            header = code.decode(reader, null);
+            LineReader reader =  new BufferedLineReader(is);
+            SAMTextHeaderCodec codec = new SAMTextHeaderCodec();
+            header = codec.decode(reader, null);
 
         } catch (IOException ex) {
             log.error("Error opening file", ex);
