@@ -1,19 +1,19 @@
 /*
- * Copyright (c) 2007-2010 by The Broad Institute, Inc. and the Massachusetts Institute of Technology.
- * All Rights Reserved.
+ * Copyright (c) 2007-2011 by The Broad Institute of MIT and Harvard.  All Rights Reserved.
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL), Version 2.1 which
- * is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
+ * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
  *
- * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR WARRANTIES OF
- * ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING, WITHOUT LIMITATION, WARRANTIES
- * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT
- * OR OTHER DEFECTS, WHETHER OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR
- * RESPECTIVE TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES OF
- * ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES, ECONOMIC
- * DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER THE BROAD OR MIT SHALL
- * BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT SHALL KNOW OF THE POSSIBILITY OF THE
- * FOREGOING.
+ * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR
+ * WARRANTES OF ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING,
+ * WITHOUT LIMITATION, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
+ * PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT OR OTHER DEFECTS, WHETHER
+ * OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR RESPECTIVE
+ * TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES
+ * OF ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES,
+ * ECONOMIC DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER
+ * THE BROAD OR MIT SHALL BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT
+ * SHALL KNOW OF THE POSSIBILITY OF THE FOREGOING.
  */
 
 /*
@@ -23,7 +23,8 @@
 package org.broad.igv.sam.reader;
 
 import net.sf.samtools.SAMFileHeader;
-import net.sf.samtools.util.AsciiLineReader;
+import org.broad.igv.exceptions.DataLoadException;
+import org.broad.tribble.readers.AsciiLineReader;
 import net.sf.samtools.util.CloseableIterator;
 import org.apache.log4j.Logger;
 import org.broad.igv.sam.Alignment;
@@ -45,12 +46,17 @@ public class GeraldQueryReader implements AlignmentQueryReader {
     private static Logger log = Logger.getLogger(GeraldQueryReader.class);
     static int MAX_READ_LENGTH = 100;
     static int maxTileCount = 20;
-    File alignmentFile;
+    String alignmentFile;
     FeatureIndex featureIndex;
     FileInputStream is;
     AlignmentParser parser;
 
-    public GeraldQueryReader(File alignmentFile) {
+
+    public GeraldQueryReader(String alignmentFile) {
+        this(alignmentFile, true);
+    }
+
+    public GeraldQueryReader(String alignmentFile, boolean requireIndex) {
         this.alignmentFile = alignmentFile;
         parser = getParserFor(alignmentFile);
         try {
@@ -58,17 +64,17 @@ public class GeraldQueryReader implements AlignmentQueryReader {
         } catch (FileNotFoundException fileNotFoundException) {
             fileNotFoundException.printStackTrace();
         }
-    }
-
-    public GeraldQueryReader(File samFile, File indexFile) {
-        this.alignmentFile = samFile;
-        if (indexFile.exists()) {
-            featureIndex = new FeatureIndex(indexFile);
+        if (requireIndex) {
+            featureIndex = SamUtils.getIndexFor(alignmentFile);
+            if (featureIndex == null) {
+                throw new DataLoadException("Could not locate index file.", alignmentFile);
+            }
         }
     }
 
-    private static AlignmentParser getParserFor(File file) {
-        String fn = file.getName().toLowerCase();
+    // 
+
+    private static AlignmentParser getParserFor(String fn) {
         if (fn.endsWith(".aligned") || (fn.endsWith(".aligned.txt"))) {
             return new DotAlignedParser();
         } else if (fn.endsWith(".bedz") || fn.endsWith(".bed")) {
@@ -166,7 +172,12 @@ public class GeraldQueryReader implements AlignmentQueryReader {
         }
 
         private Alignment readNextRecord() {
-            currentRecord = parser.readNextRecord(reader);
+            try {
+                currentRecord = parser.readNextRecord(reader);
+            } catch (IOException e) {
+                log.error("Error reading Gerald record", e);
+                return null;
+            }
             return currentRecord;
         }
 
