@@ -18,6 +18,7 @@
 package org.broad.igv.session;
 
 import org.apache.log4j.Logger;
+import org.broad.igv.Globals;
 import org.broad.igv.feature.RegionOfInterest;
 import org.broad.igv.lists.GeneList;
 import org.broad.igv.lists.GeneListManager;
@@ -71,9 +72,10 @@ public class SessionReader {
      * Map of track id -> track.  It is important to maintin the order in which tracks are added, thus
      * the use of LinkedHashMap.
      */
-    Map<String, List<Track>> trackDictionary = new LinkedHashMap();
+    Map<String, List<Track>> trackDictionary = Collections.synchronizedMap(new LinkedHashMap());
     private Track geneTrack = null;
     private Track seqTrack = null;
+    private boolean hasTrackElments;
 
 
     static {
@@ -110,7 +112,9 @@ public class SessionReader {
         PROPERTY("Property"),
         GENE_LIST("GeneList"),
         HIDDEN_ATTRIBUTES("HiddenAttributes"),
+        VISIBLE_ATTRIBUTES("VisibleAttributes"),
         ATTRIBUTE("Attribute"),
+        VISIBLE_ATTRIBUTE("VisibleAttribute"),
         FRAME("Frame");
 
         private String name;
@@ -262,6 +266,9 @@ public class SessionReader {
             throw new RuntimeException(e);
         }
 
+        NodeList tracks = document.getElementsByTagName("Track");
+        hasTrackElments = tracks.getLength() > 0;
+
         HashMap additionalInformation = new HashMap();
         additionalInformation.put(INPUT_FILE_KEY, sessionName);
 
@@ -304,7 +311,20 @@ public class SessionReader {
 
         Element element = (Element) node;
 
-        IGV.getInstance().selectGenomeFromList(getAttribute(element, SessionAttribute.GENOME.getText()));
+        // Load the genome, which can be an ID, or a path or URL to a .genome or indexed fasta file.
+        String genome = getAttribute(element, SessionAttribute.GENOME.getText());
+        if (genome != null && genome.length() > 0) {
+            if (IGV.getInstance().getGenomeIds().contains(genome)) {
+                IGV.getInstance().selectGenomeFromList(genome);
+            } else if (ParsingUtils.pathExists(genome)) {
+                try {
+                    IGV.getInstance().loadGenome(genome, null);
+                } catch (IOException e) {
+                    throw new RuntimeException("Error loading genome: " + genome);
+                }
+            }
+        }
+
 
         session.setLocus(getAttribute(element, SessionAttribute.LOCUS.getText()));
         session.setGroupTracksBy(getAttribute(element, SessionAttribute.GROUP_TRACKS_BY.getText()));
@@ -314,8 +334,7 @@ public class SessionReader {
             try {
                 Boolean b = Boolean.parseBoolean(removeEmptyTracks);
                 session.setRemoveEmptyPanels(b);
-            }
-            catch (Exception e) {
+            } catch (Exception e) {
                 log.error("Error parsing removeEmptyTracks string: " + removeEmptyTracks, e);
             }
         }
@@ -323,8 +342,7 @@ public class SessionReader {
         String versionString = getAttribute(element, SessionAttribute.VERSION.getText());
         try {
             version = Integer.parseInt(versionString);
-        }
-        catch (NumberFormatException e) {
+        } catch (NumberFormatException e) {
             log.error("Non integer version number in session file: " + versionString);
         }
         session.setVersion(version);
@@ -383,13 +401,11 @@ public class SessionReader {
 
         String nodeName = element.getNodeName();
 
-        if (nodeName.equalsIgnoreCase(SessionElement.FILES.getText())) {
-            processFiles(session, (Element) element, additionalInformation);
-        } else if (nodeName.equalsIgnoreCase(SessionElement.DATA_FILE.getText())) {
-            processDataFile(session, (Element) element, additionalInformation);
-        } else if (nodeName.equalsIgnoreCase(SessionElement.RESOURCES.getText())) {
+        if (nodeName.equalsIgnoreCase(SessionElement.RESOURCES.getText()) ||
+                nodeName.equalsIgnoreCase(SessionElement.FILES.getText())) {
             processResources(session, (Element) element, additionalInformation);
-        } else if (nodeName.equalsIgnoreCase(SessionElement.RESOURCE.getText())) {
+        } else if (nodeName.equalsIgnoreCase(SessionElement.RESOURCE.getText()) ||
+                nodeName.equalsIgnoreCase(SessionElement.DATA_FILE.getText())) {
             processResource(session, (Element) element, additionalInformation);
         } else if (nodeName.equalsIgnoreCase(SessionElement.REGIONS.getText())) {
             processRegions(session, (Element) element, additionalInformation);
@@ -415,22 +431,13 @@ public class SessionReader {
             processPanelLayout(session, (Element) element, additionalInformation);
         } else if (nodeName.equalsIgnoreCase(SessionElement.HIDDEN_ATTRIBUTES.getText())) {
             processHiddenAttributes(session, (Element) element, additionalInformation);
+        } else if (nodeName.equalsIgnoreCase(SessionElement.VISIBLE_ATTRIBUTES.getText())) {
+            processVisibleAttributes(session, (Element) element, additionalInformation);
         }
 
     }
 
-
-    /**
-     * Process the Files element.
-     * <p/>
-     * The RELATIVE_PATH attribute specifies whether file paths are relative
-     * or absolute.
-     *
-     * @param session
-     * @param element
-     */
-    private void processFiles(Session session, Element element, HashMap additionalInformation) {
-
+    private void processResources(Session session, Element element, HashMap additionalInformation) {
         dataFiles = new ArrayList();
         missingDataFiles = new ArrayList();
         NodeList elements = element.getChildNodes();
@@ -462,79 +469,91 @@ public class SessionReader {
         }
         if (dataFiles.size() > 0) {
 
-            for (ResourceLocator locator : dataFiles) {
+            final List<String> errors = new ArrayList<String>();
 
-                List<Track> tracks = igv.getTrackManager().load(locator);
-
-                for (Track track : tracks) {
-
-                    String id = track.getId();
-                    List<Track> trackList = trackDictionary.get(id);
-                    if (trackList == null) {
-                        trackList = new ArrayList();
-                        trackDictionary.put(id, trackList);
+            // Load files concurrently -- TODO, put a limit on # of threads?
+            List<Thread> threads = new ArrayList(dataFiles.size());
+            long t0 = System.currentTimeMillis();
+            int i = 0;
 
+            List<Runnable> synchronousLoads = new ArrayList<Runnable>();
+            for (final ResourceLocator locator : dataFiles) {
+                Runnable runnable = new Runnable() {
+                    public void run() {
+                        List<Track> tracks = null;
+                        try {
+                            final TrackManager tm = igv.getTrackManager();
+                            if (tm == null) log.info("TrackManager is null!");
+                            tracks = tm.load(locator);
+                            for (Track track : tracks) {
+                                if (track == null) log.info("Null track for resource " + locator.getPath());
+                                String id = track.getId();
+                                if (id == null) log.info("Null track id for resource " + locator.getPath());
+                                List<Track> trackList = trackDictionary.get(id);
+                                if (trackList == null) {
+                                    trackList = new ArrayList();
+                                    trackDictionary.put(id, trackList);
+                                }
+                                trackList.add(track);
+                            }
+                        } catch (Exception e) {
+                            log.error("Error loading resource " + locator.getPath(), e);
+                            String ms = "<b>" + locator.getPath() + "</b><br>&nbs;p&nbsp;" + e.toString() + "<br>";
+                            errors.add(ms);
+                        }
                     }
-                    trackList.add(track);
+                };
+
+                boolean isAlignment = locator.getPath().endsWith(".bam") || locator.getPath().endsWith(".entries") ||
+                        locator.getPath().endsWith(".sam");
+
+
+               // Run synchronously if in batch mode or if there are no "track" elments, or if this is an alignment file
+                if (isAlignment || Globals.isBatch() || !hasTrackElments) {
+                    synchronousLoads.add(runnable);
+                } else {
+                    Thread t = new Thread(runnable);
+                    threads.add(t);
+                    t.start();
                 }
+                i++;
 
             }
+
+            // Wait for all threads to complete
+            for (Thread t : threads) {
+                try {
+                    t.join();
+                } catch (InterruptedException ignore) {
+                }
+            }
+
+            // Now load data that must be loaded synchronously
+            for(Runnable runnable : synchronousLoads) {
+                runnable.run();
+            }
+
+            long dt = System.currentTimeMillis() - t0;
+            log.info("Total load time = " + dt);
+
+            if (errors.size() > 0) {
+                StringBuffer buf = new StringBuffer();
+                buf.append("<html>Errors were encountered loading the session:<br>");
+                for (String msg : errors) {
+                    buf.append(msg);
+                }
+                MessageUtils.showMessage(buf.toString());
+            }
+
         }
         dataFiles = null;
     }
 
-    /**
-     * //TODO -- I think this method can be removed
-     *
-     * @param session
-     * @param element
-     * @Deprecated
-     * @Deprectated -- user processResource
-     * Process the data file element.  If relativePaths == true treat the
-     * file path as relative to the session file path.  If false
-     */
-
-    private void processDataFile(Session session, Element element, HashMap additionalInformation) {
-
-        ResourceLocator resourceLocator = null;
-        String serverURL = getAttribute(element, SessionAttribute.SERVER_URL.getText());
-        String filePath = getAttribute(element, SessionAttribute.NAME.getText());
-
-        // e.g. DAS
-        String resourceType = getAttribute(element, SessionAttribute.RESOURCE_TYPE.getText());
-
-        // If file is local
-        if ((serverURL == null || serverURL.trim().equals("")) &&
-                !(IGVHttpClientUtils.isURL(filePath.toLowerCase()))) {
-            String relPathValue = getAttribute(element, SessionAttribute.RELATIVE_PATH.getText());
-            boolean relativePaths = ((relPathValue != null) && relPathValue.equalsIgnoreCase("true"));
-            File parent = (relativePaths ? new File(session.getPath()).getParentFile() : null);
-            File file = new File(parent, filePath);
-            resourceLocator = new ResourceLocator(file.getAbsolutePath());
-        } else {    // ...else must be from Server
-            resourceLocator = new ResourceLocator(serverURL, filePath);
-        }
-
-        if (resourceType != null) {
-            resourceLocator.setType(resourceType);
-        }
-
-        if (resourceLocator.exists()) {
-            dataFiles.add(resourceLocator);
-        } else {
-            missingDataFiles.add(resourceLocator);
-        }
-
-        NodeList elements = element.getChildNodes();
-        process(session, elements, additionalInformation);
-    }
-
-    private void processResources(Session session, Element element, HashMap additionalInformation) {
-        processFiles(session, element, additionalInformation);
-    }
-
     private void processResource(Session session, Element element, HashMap additionalInformation) {
 
+        String nodeName = element.getNodeName();
+        boolean oldSession = nodeName.equals(SessionElement.DATA_FILE.getText());
+
         String label = getAttribute(element, SessionAttribute.LABEL.getText());
         String name = getAttribute(element, SessionAttribute.NAME.getText());
         String sampleId = getAttribute(element, SessionAttribute.SAMPLE_ID.getText());
@@ -547,8 +566,19 @@ public class SessionReader {
         String relPathValue = getAttribute(element, SessionAttribute.RELATIVE_PATH.getText());
         boolean relativePaths = ((relPathValue != null) && relPathValue.equalsIgnoreCase("true"));
         String serverURL = getAttribute(element, SessionAttribute.SERVER_URL.getText());
+
+        // Older sessions used the "name" attribute for the path.
         String path = getAttribute(element, SessionAttribute.PATH.getText());
 
+        if (oldSession && name != null) {
+            path = name;
+            int idx = name.lastIndexOf("/");
+            if (idx > 0 && idx + 1 < name.length()) {
+                name = name.substring(idx + 1);
+            }
+        }
+
+
         ResourceLocator resourceLocator = new ResourceLocator(serverURL, path);
         if (relativePaths) {
             if (FileUtils.isRemote(session.getPath())) {
@@ -604,11 +634,7 @@ public class SessionReader {
             }
         }
 
-        if (resourceLocator.exists()) {
-            dataFiles.add(resourceLocator);
-        } else {
-            missingDataFiles.add(resourceLocator);
-        }
+        dataFiles.add(resourceLocator);
 
         NodeList elements = element.getChildNodes();
         process(session, elements, additionalInformation);
@@ -653,6 +679,36 @@ public class SessionReader {
         }
     }
 
+
+    /**
+     * For backward compatibility
+     *
+     * @param session
+     * @param element
+     * @param additionalInformation
+     */
+    private void processVisibleAttributes(Session session, Element element, HashMap additionalInformation) {
+
+//        session.clearRegionsOfInterest();
+        NodeList elements = element.getChildNodes();
+        if (elements.getLength() > 0) {
+            Set<String> visibleAttributes = new HashSet();
+            for (int i = 0; i < elements.getLength(); i++) {
+                Node childNode = elements.item(i);
+                if (childNode.getNodeName().equals(SessionReader.SessionElement.VISIBLE_ATTRIBUTE.getText())) {
+                    visibleAttributes.add(((Element) childNode).getAttribute(SessionReader.SessionAttribute.NAME.getText()));
+                }
+            }
+
+            final List<String> attributeNames = AttributeManager.getInstance().getAttributeNames();
+            Set<String> hiddenAttributes = new HashSet<String>(attributeNames);
+            hiddenAttributes.removeAll(visibleAttributes);
+            session.setHiddenAttributes(hiddenAttributes);
+
+        }
+    }
+
+
     private void processGeneList(Session session, Element element, HashMap additionalInformation) {
 
         String name = getAttribute(element, SessionAttribute.NAME.getText());
@@ -800,8 +856,7 @@ public class SessionReader {
                         divs[j] = Double.parseDouble(tokens[j]);
                     }
                     session.setDividerFractions(divs);
-                }
-                catch (NumberFormatException e) {
+                } catch (NumberFormatException e) {
                     log.error("Error parsing divider locations", e);
                 }
             }
@@ -999,3 +1054,4 @@ public class SessionReader {
 
 
 }
+
