@@ -30,7 +30,7 @@ import org.broad.igv.sam.AlignmentBlock;
 import org.broad.igv.sam.ReadMate;
 import org.broad.igv.sam.reader.AlignmentQueryReader;
 import org.broad.igv.sam.reader.MergedAlignmentReader;
-import org.broad.igv.sam.reader.SamQueryReaderFactory;
+import org.broad.igv.sam.reader.AlignmentReaderFactory;
 import org.broad.igv.tools.parsers.DataConsumer;
 import org.broad.igv.ui.filefilters.AlignmentFileFilter;
 import org.broad.igv.util.FileUtils;
@@ -128,6 +128,7 @@ public class CoverageCounter {
                 } else if (opt.startsWith("m=")) {
                     String[] tmp = opt.split("=");
                     minMappingQuality = Integer.parseInt(tmp[1]);
+                    System.out.println("Minimum mapping quality = " + minMappingQuality);
                 } else if (opt.startsWith("t=")) {
                     String[] tmp = opt.split("=");
                     countThreshold = Integer.parseInt(tmp[1]);
@@ -443,7 +444,7 @@ public class CoverageCounter {
             String[] tokens = alignmentFile.split(",");
             List<AlignmentQueryReader> readers = new ArrayList(tokens.length);
             for (String f : tokens) {
-                readers.add(SamQueryReaderFactory.getReader(f, b));
+                readers.add(AlignmentReaderFactory.getReader(f, b));
             }
             return new MergedAlignmentReader(readers);
         } else {
@@ -452,12 +453,12 @@ public class CoverageCounter {
                 if (f.isDirectory()) {
                     List<AlignmentQueryReader> readers = new ArrayList();
                     for (File file : f.listFiles(new AlignmentFileFilter())) {
-                        readers.add(SamQueryReaderFactory.getReader(file.getAbsolutePath(), b));
+                        readers.add(AlignmentReaderFactory.getReader(file.getAbsolutePath(), b));
                     }
                     return new MergedAlignmentReader(readers);
                 }
             }
-            return SamQueryReaderFactory.getReader(alignmentFile, b);
+            return AlignmentReaderFactory.getReader(alignmentFile, b);
         }
 
     }
@@ -673,7 +674,7 @@ public class CoverageCounter {
             this.start = start;
             this.end = end;
             baseCount = new int[end - start];
-            //ref = SequenceManager.readSequence(genome.getId(), chr, start, end);
+            //ref = SequenceHelper.readSequence(genome.getId(), chr, start, end);
         }
 
 
