@@ -1,25 +1,24 @@
 /*
- * Copyright (c) 2007-2010 by The Broad Institute, Inc. and the Massachusetts Institute of Technology.
- * All Rights Reserved.
+ * Copyright (c) 2007-2011 by The Broad Institute of MIT and Harvard.  All Rights Reserved.
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL), Version 2.1 which
- * is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
+ * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
  *
- * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR WARRANTIES OF
- * ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING, WITHOUT LIMITATION, WARRANTIES
- * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT
- * OR OTHER DEFECTS, WHETHER OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR
- * RESPECTIVE TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES OF
- * ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES, ECONOMIC
- * DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER THE BROAD OR MIT SHALL
- * BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT SHALL KNOW OF THE POSSIBILITY OF THE
- * FOREGOING.
+ * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR
+ * WARRANTES OF ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING,
+ * WITHOUT LIMITATION, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
+ * PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT OR OTHER DEFECTS, WHETHER
+ * OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR RESPECTIVE
+ * TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES
+ * OF ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES,
+ * ECONOMIC DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER
+ * THE BROAD OR MIT SHALL BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT
+ * SHALL KNOW OF THE POSSIBILITY OF THE FOREGOING.
  */
 package org.broad.igv.tools;
 
 import javax.swing.border.*;
 
-import com.jidesoft.utils.SwingWorker;
 import org.broad.igv.track.WindowFunction;
 
 import javax.swing.*;
@@ -44,8 +43,11 @@ public class IgvToolsGui extends JDialog {
     PrintStream systemOutStream;
     PrintStream systemErrStream;
 
+    IgvTools igvTools;
+
     public IgvToolsGui() {
 
+        this.igvTools = new IgvTools();
         initComponents();
         initUI();
         updateUI();
@@ -111,7 +113,7 @@ public class IgvToolsGui extends JDialog {
             public void actionPerformed(ActionEvent e) {
                 try {
                     File chosenFile = chooseFile();
-                    tempField.setText(chosenFile.getAbsolutePath());
+                    tmpDirectoryField.setText(chosenFile.getAbsolutePath());
                     updateUI();
                 } catch (NullPointerException npe) {
                 }
@@ -137,8 +139,8 @@ public class IgvToolsGui extends JDialog {
         }
 
         zoomCombo.setSelectedIndex(IgvTools.MAX_ZOOM);
-        windowField.setText(String.valueOf(IgvTools.WINDOW_SIZE));
-        recordField.setText(String.valueOf(IgvTools.MAX_RECORDS_IN_RAM));
+        windowSizeField.setText(String.valueOf(IgvTools.WINDOW_SIZE));
+        maxRecordsField.setText(String.valueOf(IgvTools.MAX_RECORDS_IN_RAM));
         redirectSystemStreams();
     }
 
@@ -200,16 +202,16 @@ public class IgvToolsGui extends JDialog {
 
             zoomCombo.setEnabled(true);
             zoomLabel.setEnabled(true);
-            recordField.setEnabled(false);
-            recordLabel.setEnabled(false);
+            maxRecordsField.setEnabled(false);
+            maxRecordsLabel.setEnabled(false);
             probeField.setEnabled(false);
             probeButton.setEnabled(false);
             probeLabel.setEnabled(false);
-            tempLabel.setEnabled(false);
-            tempField.setEnabled(false);
+            tmpDirectoryLabel.setEnabled(false);
+            tmpDirectoryField.setEnabled(false);
             tempButton.setEnabled(false);
-            windowLabel.setEnabled(true);
-            windowField.setEnabled(true);
+            windowSizeLabel.setEnabled(true);
+            windowSizeField.setEnabled(true);
             enableWindowFunctions();
 
         } else if (tool.equals(SORT)) {
@@ -223,16 +225,16 @@ public class IgvToolsGui extends JDialog {
             genomeLabel.setEnabled(false);
             zoomCombo.setEnabled(false);
             zoomLabel.setEnabled(false);
-            recordField.setEnabled(true);
-            recordLabel.setEnabled(true);
+            maxRecordsField.setEnabled(true);
+            maxRecordsLabel.setEnabled(true);
             probeField.setEnabled(false);
             probeButton.setEnabled(false);
             probeLabel.setEnabled(false);
-            tempLabel.setEnabled(true);
-            tempField.setEnabled(true);
+            tmpDirectoryLabel.setEnabled(true);
+            tmpDirectoryField.setEnabled(true);
             tempButton.setEnabled(true);
-            windowLabel.setEnabled(false);
-            windowField.setEnabled(false);
+            windowSizeLabel.setEnabled(false);
+            windowSizeField.setEnabled(false);
             disableWindowFunctions();
 
         } else if (tool.equals(INDEX)) {
@@ -246,16 +248,16 @@ public class IgvToolsGui extends JDialog {
             genomeLabel.setEnabled(false);
             zoomCombo.setEnabled(false);
             zoomLabel.setEnabled(false);
-            recordField.setEnabled(false);
-            recordLabel.setEnabled(false);
+            maxRecordsField.setEnabled(false);
+            maxRecordsLabel.setEnabled(false);
             probeField.setEnabled(false);
             probeButton.setEnabled(false);
             probeLabel.setEnabled(false);
-            tempLabel.setEnabled(false);
-            tempField.setEnabled(false);
+            tmpDirectoryLabel.setEnabled(false);
+            tmpDirectoryField.setEnabled(false);
             tempButton.setEnabled(false);
-            windowLabel.setEnabled(false);
-            windowField.setEnabled(false);
+            windowSizeLabel.setEnabled(false);
+            windowSizeField.setEnabled(false);
             disableWindowFunctions();
 
         } else if (tool.equals(TILE)) {
@@ -273,16 +275,16 @@ public class IgvToolsGui extends JDialog {
 
             zoomCombo.setEnabled(true);
             zoomLabel.setEnabled(true);
-            recordField.setEnabled(false);
-            recordLabel.setEnabled(false);
+            maxRecordsField.setEnabled(true);
+            maxRecordsLabel.setEnabled(true);
             probeField.setEnabled(true);
             probeButton.setEnabled(true);
             probeLabel.setEnabled(true);
-            tempLabel.setEnabled(false);
-            tempField.setEnabled(false);
+            tmpDirectoryLabel.setEnabled(true);
+            tmpDirectoryField.setEnabled(true);
             tempButton.setEnabled(false);
-            windowLabel.setEnabled(false);
-            windowField.setEnabled(false);
+            windowSizeLabel.setEnabled(false);
+            windowSizeField.setEnabled(false);
             enableWindowFunctions();
         }
     }
@@ -377,10 +379,10 @@ public class IgvToolsGui extends JDialog {
             protected Object doInBackground() {
                 try {
                     setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
-                    String maxRecordText = recordField.getText();
+                    String maxRecordText = maxRecordsField.getText();
                     int maxRecords = (maxRecordText != null && maxRecordText.length() > 0) ?
                             Integer.parseInt(maxRecordText) : IgvTools.MAX_RECORDS_IN_RAM;
-                    IgvTools.doSort(inputField.getText(), outputField.getText(), tempField.getText(), maxRecords);
+                    igvTools.doSort(inputField.getText(), outputField.getText(), tmpDirectoryField.getText(), maxRecords);
                 } catch (Exception e) {
                     showMessage("Error: " + e.getMessage());
                 }
@@ -418,7 +420,7 @@ public class IgvToolsGui extends JDialog {
                     int maxZoomValue = Integer.parseInt(zoomCombo.getSelectedItem().toString());
                     Collection<WindowFunction> wfs = getWindowFunctions();
 
-                    String windowSizeText = windowField.getText();
+                    String windowSizeText = windowSizeField.getText();
                     int windowSize = (windowSizeText != null && windowSizeText.length() > 0) ?
                             Integer.parseInt(windowSizeText) : IgvTools.WINDOW_SIZE;
 
@@ -426,7 +428,7 @@ public class IgvToolsGui extends JDialog {
                     int strandOption = -1;
 
                     runButton.setEnabled(false);
-                    IgvTools.doCount(ifile, ofile, genomeId, maxZoomValue, wfs, windowSize, extFactor, strandOption);
+                    igvTools.doCount(ifile, ofile, genomeId, maxZoomValue, wfs, windowSize, extFactor, null, null);
                 } catch (Exception e) {
                     showMessage("Error: " + e.getMessage());
                 }
@@ -460,7 +462,7 @@ public class IgvToolsGui extends JDialog {
                     String probeFile = probeField.getText();
 
                     runButton.setEnabled(false);
-                    IgvTools.doTile(ifile, ofile, probeFile, genomeId, maxZoomValue, wfs);
+                    igvTools.toTDF(ifile, ofile, probeFile, genomeId, maxZoomValue, wfs, null, IgvTools.MAX_RECORDS_IN_RAM);
                 } catch (Exception e) {
                     showMessage("Error: " + e.getMessage());
                 }
@@ -493,7 +495,7 @@ public class IgvToolsGui extends JDialog {
                     int binSize = IgvTools.LINEAR_BIN_SIZE;
 
                     runButton.setEnabled(false);
-                    IgvTools.doIndex(ifile, indexType, binSize);
+                    igvTools.doIndex(ifile, indexType, binSize);
                 } catch (Exception e) {
                     showMessage("Error: " + e.getMessage());
                 }
@@ -580,7 +582,7 @@ public class IgvToolsGui extends JDialog {
         if (genomeId != null) {
             mainWindow.genomeField.setText(genomeId);
             mainWindow.genomeField.setEnabled(false);
-            mainWindow.genomeField.setToolTipText("<html>To change the genome id close this window and <br>use the pulldown on the IGV main screen.");
+            mainWindow.genomeField.setToolTipText("<html>To change the genome id close this window and <br>use the pulldown on the IGV batch screen.");
             mainWindow.genomeButton.setEnabled(false);
             mainWindow.genomeSelectionDisabled = true;
         }
@@ -602,7 +604,7 @@ public class IgvToolsGui extends JDialog {
     }
 
     private void setDefaultOutputText() {
-        if (outputField.getText().length() == 0 && inputField.getText().length() > 0) {
+        if (inputField.getText().length() > 0) {
             String cmd = toolCombo.getSelectedItem().toString().toLowerCase();
             if (cmd.equals("count") || cmd.equals("tile")) {
                 outputField.setText(inputField.getText() + ".tdf");
@@ -610,13 +612,20 @@ public class IgvToolsGui extends JDialog {
                 String input = inputField.getText();
                 int ext = input.lastIndexOf(".");
                 if (ext > 0) {
-                    String output = input.substring(0, ext) + ".sorted." + input.substring(ext);
+                    String output = input.substring(0, ext) + ".sorted" + input.substring(ext);
                     outputField.setText(output);
                 }
+            } else if(cmd.equals("index")) {
+                outputField.setText("");
             }
+
         }
     }
 
+    private void toolComboActionPerformed(ActionEvent e) {
+        setDefaultOutputText();
+    }
+
 
     private void initComponents() {
         // JFormDesigner - Component initialization - DO NOT MODIFY  //GEN-BEGIN:initComponents
@@ -650,14 +659,14 @@ public class IgvToolsGui extends JDialog {
         probeField = new JTextField();
         probeButton = new JButton();
         zoomCombo = new JComboBox();
-        windowLabel = new JLabel();
-        windowField = new JTextField();
+        windowSizeLabel = new JLabel();
+        windowSizeField = new JTextField();
         sortPanel = new JPanel();
-        tempLabel = new JLabel();
-        recordLabel = new JLabel();
+        tmpDirectoryLabel = new JLabel();
+        maxRecordsLabel = new JLabel();
         tempButton = new JButton();
-        tempField = new JTextField();
-        recordField = new JTextField();
+        tmpDirectoryField = new JTextField();
+        maxRecordsField = new JTextField();
         buttonPanel = new JPanel();
         runButton = new JButton();
         closeButton = new JButton();
@@ -675,6 +684,13 @@ public class IgvToolsGui extends JDialog {
             //======== requiredPanel ========
             {
                 requiredPanel.setLayout(new GridBagLayout());
+
+                //---- toolCombo ----
+                toolCombo.addActionListener(new ActionListener() {
+                    public void actionPerformed(ActionEvent e) {
+                        toolComboActionPerformed(e);
+                    }
+                });
                 requiredPanel.add(toolCombo, new GridBagConstraints(2, 1, 1, 1, 1.0, 1.0,
                     GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL,
                     new Insets(0, 0, 0, 0), 0, 0));
@@ -841,13 +857,13 @@ public class IgvToolsGui extends JDialog {
                     GridBagConstraints.WEST, GridBagConstraints.NONE,
                     new Insets(0, 0, 0, 0), 0, 0));
 
-                //---- windowLabel ----
-                windowLabel.setToolTipText("The window size over which coverage computed when using the count command.  Defaults to 25 bp.");
-                windowLabel.setText("Window Size");
-                tilePanel.add(windowLabel, new GridBagConstraints(1, 4, 1, 1, 0.0, 0.0,
+                //---- windowSizeLabel ----
+                windowSizeLabel.setToolTipText("The window size over which coverage computed when using the count command.  Defaults to 25 bp.");
+                windowSizeLabel.setText("Window Size");
+                tilePanel.add(windowSizeLabel, new GridBagConstraints(1, 4, 1, 1, 0.0, 0.0,
                     GridBagConstraints.WEST, GridBagConstraints.NONE,
                     new Insets(0, 0, 0, 0), 0, 0));
-                tilePanel.add(windowField, new GridBagConstraints(2, 4, 1, 1, 1.0, 0.0,
+                tilePanel.add(windowSizeField, new GridBagConstraints(2, 4, 1, 1, 1.0, 0.0,
                     GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL,
                     new Insets(0, 0, 0, 0), 0, 0));
             }
@@ -860,17 +876,17 @@ public class IgvToolsGui extends JDialog {
                 sortPanel.setBorder(new TitledBorder(null, "Sort Options", TitledBorder.LEADING, TitledBorder.TOP));
                 sortPanel.setLayout(new GridBagLayout());
 
-                //---- tempLabel ----
-                tempLabel.setToolTipText("<html>Specify a temporary working directory.  For large input files this directory will be used to <br>store intermediate results of the sort. The default is the users temp directory.");
-                tempLabel.setText("Temp Directory");
-                sortPanel.add(tempLabel, new GridBagConstraints(1, 1, 1, 1, 0.0, 1.0,
+                //---- tmpDirectoryLabel ----
+                tmpDirectoryLabel.setToolTipText("<html>Specify a temporary working directory.  For large input files this directory will be used to <br>store intermediate results of the sort. The default is the users temp directory.");
+                tmpDirectoryLabel.setText("Temp Directory");
+                sortPanel.add(tmpDirectoryLabel, new GridBagConstraints(1, 1, 1, 1, 0.0, 1.0,
                     GridBagConstraints.WEST, GridBagConstraints.NONE,
                     new Insets(0, 0, 0, 0), 0, 0));
 
-                //---- recordLabel ----
-                recordLabel.setToolTipText("<html>The maximum number of records to keep in memory during the sort.  The default value is <br>500000.  Increase this number if you receive \"too many open files\" errors.   Decrease it if you <br>experience \"out of memory\" errors.");
-                recordLabel.setText("Max Records");
-                sortPanel.add(recordLabel, new GridBagConstraints(1, 2, 1, 1, 0.0, 1.0,
+                //---- maxRecordsLabel ----
+                maxRecordsLabel.setToolTipText("<html>The maximum number of records to keep in memory during the sort.  The default value is <br>500000.  Increase this number if you receive \"too many open files\" errors.   Decrease it if you <br>experience \"out of memory\" errors.");
+                maxRecordsLabel.setText("Max Records");
+                sortPanel.add(maxRecordsLabel, new GridBagConstraints(1, 2, 1, 1, 0.0, 1.0,
                     GridBagConstraints.WEST, GridBagConstraints.NONE,
                     new Insets(0, 0, 0, 0), 0, 0));
 
@@ -879,10 +895,10 @@ public class IgvToolsGui extends JDialog {
                 sortPanel.add(tempButton, new GridBagConstraints(4, 1, 1, 1, 0.0, 1.0,
                     GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL,
                     new Insets(0, 0, 0, 0), 0, 0));
-                sortPanel.add(tempField, new GridBagConstraints(3, 1, 1, 1, 1.0, 1.0,
+                sortPanel.add(tmpDirectoryField, new GridBagConstraints(3, 1, 1, 1, 1.0, 1.0,
                     GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL,
                     new Insets(0, 0, 0, 0), 0, 0));
-                sortPanel.add(recordField, new GridBagConstraints(3, 2, 1, 1, 1.0, 1.0,
+                sortPanel.add(maxRecordsField, new GridBagConstraints(3, 2, 1, 1, 1.0, 1.0,
                     GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL,
                     new Insets(0, 0, 0, 0), 0, 0));
             }
@@ -983,14 +999,14 @@ public class IgvToolsGui extends JDialog {
     private JTextField probeField;
     private JButton probeButton;
     private JComboBox zoomCombo;
-    private JLabel windowLabel;
-    private JTextField windowField;
+    private JLabel windowSizeLabel;
+    private JTextField windowSizeField;
     private JPanel sortPanel;
-    private JLabel tempLabel;
-    private JLabel recordLabel;
+    private JLabel tmpDirectoryLabel;
+    private JLabel maxRecordsLabel;
     private JButton tempButton;
-    private JTextField tempField;
-    private JTextField recordField;
+    private JTextField tmpDirectoryField;
+    private JTextField maxRecordsField;
     private JPanel buttonPanel;
     private JButton runButton;
     private JButton closeButton;
