@@ -30,7 +30,9 @@ import org.broad.igv.session.SessionReader;
 import org.broad.igv.ui.FontManager;
 import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.UIConstants;
+import org.broad.igv.ui.panel.AttributeHeaderPanel;
 import org.broad.igv.ui.panel.IGVPopupMenu;
+import org.broad.igv.ui.panel.MouseableRegion;
 import org.broad.igv.ui.panel.ReferenceFrame;
 import org.broad.igv.util.ResourceLocator;
 import org.broad.tribble.Feature;
@@ -200,14 +202,6 @@ public abstract class AbstractTrack implements Track {
     }
 
 
-    public String getSampleId() {
-        if (sampleId != null) {
-            return sampleId;
-        } else {
-            return getName();
-        }
-    }
-
     public void setSampleId(String sampleId) {
         this.sampleId = sampleId;
     }
@@ -237,6 +231,27 @@ public abstract class AbstractTrack implements Track {
     }
 
 
+    public void renderAttributes(Graphics2D graphics, Rectangle trackRectangle, Rectangle visibleRect,
+                                 List<String> names, List<MouseableRegion> mouseRegions) {
+
+        int x = trackRectangle.x;
+
+        for (String name : names) {
+
+            String key = name.toUpperCase();
+            String attributeValue = getAttributeValue(key);
+            if (attributeValue != null) {
+                Rectangle rect = new Rectangle(x, trackRectangle.y, AttributeHeaderPanel.ATTRIBUTE_COLUMN_WIDTH,
+                        trackRectangle.height);
+                graphics.setColor(AttributeManager.getInstance().getColor(key, attributeValue));
+                graphics.fill(rect);
+                mouseRegions.add(new MouseableRegion(rect, key, attributeValue));
+            }
+            x += AttributeHeaderPanel.ATTRIBUTE_COLUMN_WIDTH + AttributeHeaderPanel.COLUMN_BORDER_WIDTH;
+        }
+    }
+
+
     private Rectangle getDisplayableRect(Rectangle trackRectangle, Rectangle visibleRect) {
         Rectangle rect = null;
         if (visibleRect != null) {
@@ -262,10 +277,6 @@ public abstract class AbstractTrack implements Track {
     public void overlay(RenderContext context, Rectangle rect) {
     }
 
-    public void chromosomeChanged(String chrName) {
-        // Nothing to do by default
-    }
-
 
     public Color getColor() {
         return posColor;
@@ -421,12 +432,8 @@ public abstract class AbstractTrack implements Track {
         return (height < 0) ? getDefaultHeight() : height;
     }
 
-    public int getPreferredHeight() {
-        return preferredHeight;
-    }
-
     public boolean hasDataRange() {
-        return dataRange != null;
+        return  dataRange != null;
     }
 
     public DataRange getDataRange() {
@@ -484,6 +491,13 @@ public abstract class AbstractTrack implements Track {
     }
 
 
+    /**
+     * Set some properties of this track,  usually from a "track line" specification.
+     *
+     * TODO -- keep the properties object, rather than copy all the values.
+     *
+     * @param properties
+     */
     public void setProperties(TrackProperties properties) {
         this.itemRGB = properties.isItemRGB();
         this.useScore = properties.isUseScore();
@@ -577,7 +591,7 @@ public abstract class AbstractTrack implements Track {
     /**
      * @return the top
      */
-    public int getTop() {
+    public int getY() {
         return top;
     }
 
@@ -588,7 +602,7 @@ public abstract class AbstractTrack implements Track {
     /**
      * @param top the top to set
      */
-    public void setTop(int top) {
+    public void setY(int top) {
         this.top = top;
     }
 
@@ -630,6 +644,13 @@ public abstract class AbstractTrack implements Track {
         return Color.getHSBColor(rgb[0], rgb[1], rgb[2]);
     }
 
+    /**
+     * Return the current state of this object as map of key-value pairs.  Used to store session state.
+     *
+     * // TODO -- this whole scheme could probably be more elegantly handled with annotations.
+     *
+     * @return
+     */
 
     public Map<String, String> getPersistentState() {
 
@@ -713,8 +734,8 @@ public abstract class AbstractTrack implements Track {
 
         String isVisible = attributes.get(SessionReader.SessionAttribute.VISIBLE.getText());
         String height = attributes.get(SessionReader.SessionAttribute.HEIGHT.getText());
-        String color = attributes.get(SessionReader.SessionAttribute.COLOR.getText());
-        String altColor = attributes.get(SessionReader.SessionAttribute.ALT_COLOR.getText());
+        String colorString = attributes.get(SessionReader.SessionAttribute.COLOR.getText());
+        String altColorString = attributes.get(SessionReader.SessionAttribute.ALT_COLOR.getText());
         String rendererType = attributes.get(SessionReader.SessionAttribute.RENDERER.getText());
         String windowFunction = attributes.get(SessionReader.SessionAttribute.WINDOW_FUNCTION.getText());
         String scale = attributes.get(SessionReader.SessionAttribute.SCALE.getText());
@@ -777,15 +798,27 @@ public abstract class AbstractTrack implements Track {
         }
 
         // Set color
-        if (color != null) {
+        if (colorString != null) {
             try {
-                String[] rgb = color.split(",");
+                String[] rgb = colorString.split(",");
                 int red = Integer.parseInt(rgb[0]);
                 int green = Integer.parseInt(rgb[1]);
                 int blue = Integer.parseInt(rgb[2]);
-                setColor(new Color(red, green, blue));
+                posColor = new Color(red, green, blue);
             } catch (NumberFormatException e) {
-                log.error("Error restoring color: " + color);
+                log.error("Error restoring color: " + colorString);
+            }
+        }
+
+        if (altColorString != null) {
+            try {
+                String[] rgb = altColorString.split(",");
+                int red = Integer.parseInt(rgb[0]);
+                int green = Integer.parseInt(rgb[1]);
+                int blue = Integer.parseInt(rgb[2]);
+                altColor=  new Color(red, green, blue);
+            } catch (NumberFormatException e) {
+                log.error("Error restoring color: " + colorString);
             }
         }
 
@@ -957,11 +990,17 @@ public abstract class AbstractTrack implements Track {
         this.displayMode = mode;
     }
 
-    //----------------------------------------------------------------------------
-    // Methods below are required for the Track interface, but aren't
-    // meaningful here.  Obviously some refactoring is in order to reduce
-    // the number of required methods.
 
+    /**
+     * Return a value string for the tooltip window at the given location, or null to signal there is no value
+     * at that location
+     *
+     * @param chr
+     * @param position
+     * @param y
+     * @param frame
+     * @return
+     */
     public String getValueStringAt(String chr, double position, int y, ReferenceFrame frame) {
         return null;
     }
@@ -1006,4 +1045,5 @@ public abstract class AbstractTrack implements Track {
     public float getYLine() {
         return yLine;
     }
+
 }
