@@ -19,7 +19,7 @@ package org.broad.igv.track;
 
 import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
-import org.broad.igv.PreferenceManager;
+import org.broad.igv.bigwig.BigWigDataSource;
 import org.broad.igv.feature.*;
 import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.ui.IGV;
@@ -28,6 +28,7 @@ import org.broad.igv.ui.panel.ReferenceFrame;
 import org.broad.igv.renderer.*;
 import org.broad.igv.ui.util.MessageUtils;
 import org.broad.igv.util.*;
+import org.broad.igv.variant.VariantTrack;
 import org.broad.tribble.Feature;
 import org.broad.tribble.TribbleException;
 
@@ -91,6 +92,8 @@ public class FeatureTrack extends AbstractTrack {
 
     private static boolean drawBorder = true;
 
+    private boolean alternateExonColor = false;
+
     /**
      * Does not initialize with the featuresource
      *
@@ -102,12 +105,26 @@ public class FeatureTrack extends AbstractTrack {
         setSortable(false);
     }
 
+    /**
+     * Constructor with no ResourceLocator.  Note:  tracks using this constructor will not be recorded in the
+     * "Resources" section of session files.
+     *
+     * @param id
+     * @param name
+     * @param source
+     */
     public FeatureTrack(String id, String name, FeatureSource source) {
         super(id, name);
         init(source);
         setSortable(false);
     }
 
+    public FeatureTrack(ResourceLocator locator, String id, String name, FeatureSource source) {
+        super(locator, id, name);
+        init(source);
+        setSortable(false);
+     }
+
 
     public FeatureTrack(ResourceLocator locator, FeatureSource source) {
         super(locator);
@@ -185,6 +202,7 @@ public class FeatureTrack extends AbstractTrack {
         if (trackProperties.getFeatureVisibilityWindow() >= 0) {
             setVisibilityWindow(trackProperties.getFeatureVisibilityWindow());
         }
+        alternateExonColor = trackProperties.isAlternateExonColor();
 
     }
 
@@ -258,7 +276,7 @@ public class FeatureTrack extends AbstractTrack {
 
             List<Feature> allFeatures = getAllFeatureAt(chr, position, y, frame);
             if (allFeatures == null) {
-                return "";
+                return null;
             }
 
             StringBuffer buf = new StringBuffer();
@@ -282,13 +300,12 @@ public class FeatureTrack extends AbstractTrack {
                 }
                 n++;
             }
-            if (!firstFeature) buf.append("<br>--------------<br>");
 
             return buf.toString();
         } else {
             int zoom = Math.max(0, frame.getZoom());
-            if(source == null) {
-                return "";
+            if (source == null) {
+                return null;
             }
             List<LocusScore> scores = source.getCoverageScores(chr, (int) position - 10, (int) position + 10, zoom);
 
@@ -299,7 +316,7 @@ public class FeatureTrack extends AbstractTrack {
                 double bpPerPixel = frame.getScale();
                 int minWidth = (int) (2 * bpPerPixel);    /* * */
                 LocusScore score = (LocusScore) FeatureUtils.getFeatureAt(position, minWidth, scores);
-                return score == null ? "" : "Mean count: " + score.getScore();
+                return score == null ? null : "Mean count: " + score.getScore();
             }
 
         }
@@ -489,9 +506,9 @@ public class FeatureTrack extends AbstractTrack {
             //if nothing already selected, select this feature
             if (selectedFeature == null)
                 selectedFeature = igvFeature;
-            //If something already selected, then if it's the same as this feature, deselect, otherwise, select
-            //this feature.
-            //todo: contains() might not do everything I want it to.
+                //If something already selected, then if it's the same as this feature, deselect, otherwise, select
+                //this feature.
+                //todo: contains() might not do everything I want it to.
             else if (igvFeature.contains(selectedFeature) && (selectedFeature.contains(igvFeature)))
                 selectedFeature = null;
             else selectedFeature = igvFeature;
@@ -547,7 +564,7 @@ public class FeatureTrack extends AbstractTrack {
     public void setDisplayMode(DisplayMode mode) {
         // Explicity setting the display mode overrides the automatic switch
         lastFeatureMode = null;
-        super.setDisplayMode(mode);    //To change body of overridden methods use File | Settings | File Templates.
+        super.setDisplayMode(mode);    
     }
 
     public void render(RenderContext context, Rectangle rect) {
@@ -565,8 +582,11 @@ public class FeatureTrack extends AbstractTrack {
             renderFeatures(context, renderRect);
         } else {
             if (getDisplayMode() != DisplayMode.COLLAPSED) {
-                lastFeatureMode = getDisplayMode();
-                super.setDisplayMode(DisplayMode.COLLAPSED);
+                // An ugly hack, but we want to prevent this for vcf tracks
+                if (!(this instanceof VariantTrack)) {
+                    lastFeatureMode = getDisplayMode();
+                    super.setDisplayMode(DisplayMode.COLLAPSED);
+                }
             }
             renderCoverage(context, renderRect);
         }
@@ -586,10 +606,10 @@ public class FeatureTrack extends AbstractTrack {
     }
 
     protected void renderCoverage(RenderContext context, Rectangle inputRect) {
-        if(source == null) {
+        if (source == null) {
             return;
         }
-        
+
         List<LocusScore> scores = source.getCoverageScores(context.getChr(), (int) context.getOrigin(),
                 (int) context.getEndLocation(), context.getZoom());
         if (scores == null) {
@@ -687,8 +707,7 @@ public class FeatureTrack extends AbstractTrack {
                         levelRects.add(new Rectangle(rect));
                         getRenderer().render(row.features, context, rect, this);
                         if (selectedFeatureRowIndex == i) {
-                            Graphics2D fontGraphics =
-                                    (Graphics2D) context.getGraphic2DForColor(SELECTED_FEATURE_ROW_COLOR);
+                            Graphics2D fontGraphics = context.getGraphic2DForColor(SELECTED_FEATURE_ROW_COLOR);
                             fontGraphics.fillRect(rect.x, rect.y, rect.width, rect.height);
                         }
                         rect.y += h;
@@ -905,5 +924,9 @@ public class FeatureTrack extends AbstractTrack {
     public static void setDrawBorder(boolean drawBorder) {
         FeatureTrack.drawBorder = drawBorder;
     }
+
+    public boolean isAlternateExonColor() {
+        return alternateExonColor;
+    }
 }
 
