@@ -24,23 +24,23 @@ import org.broad.igv.bbfile.BBFileReader;
 import org.broad.igv.bigwig.BigWigDataSource;
 import org.broad.igv.das.DASFeatureSource;
 import org.broad.igv.data.*;
+import org.broad.igv.data.db.SampleInfoSQLReader;
+import org.broad.igv.data.db.SegmentedSQLReader;
 import org.broad.igv.data.expression.GCTDataset;
 import org.broad.igv.data.expression.GCTDatasetParser;
 import org.broad.igv.data.rnai.RNAIDataSource;
 import org.broad.igv.data.rnai.RNAIGCTDatasetParser;
 import org.broad.igv.data.rnai.RNAIGeneScoreParser;
 import org.broad.igv.data.rnai.RNAIHairpinParser;
-import org.broad.igv.data.seg.FreqData;
-import org.broad.igv.data.seg.SegmentedAsciiDataSet;
-import org.broad.igv.data.seg.SegmentedBinaryDataSet;
-import org.broad.igv.data.seg.SegmentedDataSource;
+import org.broad.igv.data.seg.*;
 import org.broad.igv.exceptions.DataLoadException;
 import org.broad.igv.feature.*;
 import org.broad.igv.feature.dranger.DRangerParser;
 import org.broad.igv.feature.genome.Genome;
-import org.broad.igv.feature.tribble.FeatureFileHeader;
+import org.broad.igv.feature.tribble.*;
 import org.broad.igv.goby.GobyAlignmentQueryReader;
 import org.broad.igv.goby.GobyCountArchiveDataSource;
+import org.broad.igv.gs.GSUtils;
 import org.broad.igv.gwas.GWASData;
 import org.broad.igv.gwas.GWASParser;
 import org.broad.igv.gwas.GWASTrack;
@@ -61,16 +61,17 @@ import org.broad.igv.tdf.TDFReader;
 import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.util.ConfirmDialog;
 import org.broad.igv.ui.util.MessageUtils;
-import org.broad.igv.util.IGVHttpClientUtils;
+import org.broad.igv.util.HttpUtils;
 import org.broad.igv.util.ParsingUtils;
 import org.broad.igv.util.ResourceLocator;
-import org.broad.igv.vcf.PedigreeUtils;
-import org.broad.igv.vcf.VCFTrack;
+import org.broad.igv.variant.VariantTrack;
+import org.broad.igv.variant.util.PedigreeUtils;
+import org.broad.tribble.util.SeekableBufferedStream;
 import org.broad.tribble.util.SeekableStream;
 import org.broad.tribble.util.SeekableStreamFactory;
+import org.broadinstitute.sting.utils.codecs.vcf.VCFHeader;
 
 import java.io.File;
-import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.net.MalformedURLException;
 import java.net.URL;
@@ -98,17 +99,25 @@ public class TrackLoader {
     public List<Track> load(ResourceLocator locator, IGV igv) {
 
         this.igv = igv;
-        Genome genome = igv.getGenomeManager().getCurrentGenome();
+        Genome genome = igv == null ? null : igv.getGenomeManager().getCurrentGenome();
 
         final String path = locator.getPath();
         try {
             String typeString = locator.getType();
             if (typeString == null) {
 
-                // Genome space hack
-                if ((path.contains("?dataFormat") || path.contains("%3Fdataformat")) &&
-                        (path.contains("dataformat/gct") || path.contains("dataformat%2Fgct"))) {
-                    typeString = ".gct";
+                // Genome space hack -- check for explicit type converter
+                //https://dmtest.genomespace.org:8444/datamanager/files/users/SAGDemo/Step1/TF.data.tab
+                //   ?dataformat=http://www.genomespace.org/datamanager/dataformat/gct/0.0.0
+                if ((path.startsWith("http://") || path.startsWith("https://")) && GSUtils.isGenomeSpace(new URL(path)) && path.contains("?dataformat")) {
+                    if (path.contains("dataformat/gct")) {
+                        typeString = ".gct";
+                    } else if (path.contains("dataformat/bed")) {
+                        typeString = ".bed";
+                    } else if (path.contains("dataformat/cn")) {
+                        typeString = ".cn";
+                    }
+
                 } else {
                     typeString = path.toLowerCase();
                     if (!typeString.endsWith("_sorted.txt") &&
@@ -125,19 +134,14 @@ public class TrackLoader {
                         " load the associated gzipped file, which should have an extension of '.gz'");
             }
 
-            //TODO Why is this not inside of isIndexed?
-            //dhmay seconding this question -- this appears to be taken care of already in isIndexed()
-            // Check for index
-            boolean hasIndex = false;
-            if (locator.isLocal()) {
-                File indexFile = new File(path + ".sai");
-                hasIndex = indexFile.exists();
-            }
-
             //This list will hold all new tracks created for this locator
             List<Track> newTracks = new ArrayList<Track>();
 
-            if (typeString.endsWith(".gmt")) {
+            // TODO -- hack for testing/development of database support.  Test DB only has segmented files
+            String serverURL = locator.getServerURL();
+            if (serverURL != null && serverURL.startsWith("jdbc:")) {
+                this.loadFromDatabase(locator, newTracks, genome);
+            } else if (typeString.endsWith(".gmt")) {
                 loadGMT(locator);
             } else if (typeString.equals("das")) {
                 loadDASResource(locator, newTracks);
@@ -153,7 +157,7 @@ public class TrackLoader {
             } else if (typeString.endsWith("samplepathmap")) {
                 VariantListManager.loadSamplePathMap(locator);
             } else if (typeString.endsWith("h5") || typeString.endsWith("hbin")) {
-                loadH5File(locator, newTracks, genome);
+                throw new DataLoadException("HDF5 files are no longer supported", locator.getPath());
             } else if (typeString.endsWith(".rnai.gct")) {
                 loadRnaiGctFile(locator, newTracks, genome);
             } else if (typeString.endsWith(".gct") || typeString.endsWith("res") || typeString.endsWith("tab")) {
@@ -161,8 +165,6 @@ public class TrackLoader {
             } else if (typeString.endsWith(".cn") || typeString.endsWith(".xcn") || typeString.endsWith(".snp") ||
                     typeString.endsWith(".igv") || typeString.endsWith(".loh")) {
                 loadIGVFile(locator, newTracks, genome);
-            } else if (typeString.endsWith(".mut")) {
-                loadMutFile(locator, newTracks, genome);
             } else if (typeString.endsWith(".cbs") || typeString.endsWith(".seg") ||
                     typeString.endsWith("glad") || typeString.endsWith("birdseye_canary_calls")) {
                 loadSegFile(locator, newTracks, genome);
@@ -186,7 +188,7 @@ public class TrackLoader {
                     typeString.endsWith(".aligned") || typeString.endsWith(".sai") ||
                     typeString.endsWith(".bai")) {
                 loadAlignmentsTrack(locator, newTracks, genome);
-            } else if (typeString.endsWith(".bedz") || (typeString.endsWith(".bed") && hasIndex)) {
+            } else if (typeString.endsWith(".bedz")) {
                 loadIndexdBedFile(locator, newTracks, genome);
             } else if (typeString.endsWith(".omega")) {
                 loadOmegaTrack(locator, newTracks, genome);
@@ -212,13 +214,17 @@ public class TrackLoader {
                 //TODO AbstractFeatureParser.getInstanceFor() is called twice.  Wasteful
             } else if (AbstractFeatureParser.getInstanceFor(locator, genome) != null) {
                 loadFeatureFile(locator, newTracks, genome);
-            } else if (MutationParser.isMutationAnnotationFile(locator)) {
+            } else if (typeString.endsWith(".mut")) { //  MutationParser.isMutationAnnotationFile(locator)) {
                 this.loadMutFile(locator, newTracks, genome);
             } else if (WiggleParser.isWiggle(locator)) {
                 loadWigFile(locator, newTracks, genome);
-            } else if (path.toLowerCase().contains(".maf")) {
-                loadMAFTrack(locator, newTracks);
-            } else if (path.toLowerCase().contains(".peak.cfg")) {
+            } else if (typeString.endsWith(".maf") || typeString.endsWith(".maf.annotated")) {
+                if (MutationParser.isMutationAnnotationFile(locator)) {
+                    loadMutFile(locator, newTracks, genome);
+                } else {
+                    loadMAFTrack(locator, newTracks);
+                }
+            } else if (path.toLowerCase().contains(".peak.bin")) {
                 loadPeakTrack(locator, newTracks, genome);
             } else if ("mage-tab".equals(locator.getType()) || GCTDatasetParser.parsableMAGE_TAB(locator)) {
                 locator.setDescription("MAGE_TAB");
@@ -226,8 +232,6 @@ public class TrackLoader {
             } else if (typeString.endsWith(".logistic") || typeString.endsWith(".linear") || typeString.endsWith(".assoc") ||
                     typeString.endsWith(".qassoc") || typeString.endsWith(".gwas")) {
                 loadGWASFile(locator, newTracks);
-            } else if (GCTDatasetParser.isGCT(path)) {
-                loadGctFile(locator, newTracks, genome);
             } else if (GobyAlignmentQueryReader.supportsFileType(path)) {
                 loadAlignmentsTrack(locator, newTracks, genome);
             } else if (AttributeManager.isSampleInfoFile(locator)) {
@@ -290,7 +294,22 @@ public class TrackLoader {
 
         if (typeString.endsWith("vcf") || typeString.endsWith("vcf.gz")) {
 
-            VCFTrack t = new VCFTrack(locator, src);
+            VCFHeader header = (VCFHeader) src.getHeader();
+
+            // Test if the input VCF file contains methylation rate data:
+
+            // This is determined by testing for the presence of two sample format fields: MR and GB, used in the
+            // rendering of methylation rate.
+            // MR is the methylation rate on a scale of 0 to 100% and GB is the number of bases that pass
+            // filter for the position. GB is needed to avoid displaying positions for which limited coverage
+            // prevents reliable estimation of methylation rate.
+            boolean enableMethylationRateSupport = (header.getFormatHeaderLine("MR") != null &&
+                    header.getFormatHeaderLine("GB") != null);
+
+            List<String> allSamples = new ArrayList(header.getGenotypeSamples());
+
+            VariantTrack t = new VariantTrack(locator, src, allSamples, enableMethylationRateSupport);
+
             // VCF tracks handle their own margin
             t.setMargin(0);
             newTracks.add(t);
@@ -630,7 +649,7 @@ public class TrackLoader {
             String trackId = multiTrack ? path + "_" + heading : path;
             String trackName = multiTrack ? heading : name;
 
-            Genome currentGenome = IGV.getInstance().getGenomeManager().getCurrentGenome();
+
             DatasetDataSource dataSource = new DatasetDataSource(trackId, ds, genome);
 
             DataSourceTrack track = new DataSourceTrack(locator, trackId, trackName, dataSource, genome);
@@ -712,7 +731,7 @@ public class TrackLoader {
         String trackId = locator.getPath();
 
         String path = locator.getPath();
-        SeekableStream ss = SeekableStreamFactory.getStreamFor(path);
+        SeekableStream ss = new SeekableBufferedStream(SeekableStreamFactory.getStreamFor(path), 64000);
         BBFileReader reader = new BBFileReader(path, ss);
         BigWigDataSource bigwigSource = new BigWigDataSource(reader, genome);
 
@@ -720,7 +739,7 @@ public class TrackLoader {
             DataSourceTrack track = new DataSourceTrack(locator, trackId, trackName, bigwigSource, genome);
             newTracks.add(track);
         } else if (reader.isBigBedFile()) {
-            FeatureTrack track = new FeatureTrack(trackId, trackName, bigwigSource);
+            FeatureTrack track = new FeatureTrack(locator, trackId, trackName, bigwigSource);
             newTracks.add(track);
         } else {
             throw new RuntimeException("Unknown BIGWIG type: " + locator.getPath());
@@ -906,8 +925,8 @@ public class TrackLoader {
             }
             if (covPath != null) {
                 try {
-                    if ((new File(covPath)).exists() || (IGVHttpClientUtils.isURL(covPath) &&
-                            IGVHttpClientUtils.resourceAvailable(new URL(covPath)))) {
+                    if ((new File(covPath)).exists() || (HttpUtils.getInstance().isURL(covPath) &&
+                            HttpUtils.getInstance().resourceAvailable(new URL(covPath)))) {
                         TDFReader reader = TDFReader.getReader(covPath);
                         TDFDataSource ds = new TDFDataSource(reader, 0, alignmentTrack.getName() + " coverage", genome);
                         covTrack.setDataSource(ds);
@@ -987,6 +1006,44 @@ public class TrackLoader {
         }
     }
 
+
+    private void loadFromDatabase(ResourceLocator locator, List<Track> newTracks, Genome genome) {
+
+        if (".seg".equals(locator.getType())) {
+
+            SegmentedAsciiDataSet ds = (new SegmentedSQLReader()).load(locator, genome);
+
+            String path = locator.getPath();
+            TrackProperties props = ds.getTrackProperties();
+
+            // The "freq" track.  TODO - make this optional
+            if (ds.getSampleNames().size() > 1) {
+                FreqData fd = new FreqData(ds, genome);
+                String freqTrackId = path;
+                String freqTrackName = (new File(path)).getName();
+                CNFreqTrack freqTrack = new CNFreqTrack(locator, freqTrackId, freqTrackName, fd);
+                newTracks.add(freqTrack);
+            }
+
+            for (String trackName : ds.getDataHeadings()) {
+                String trackId = path + "_" + trackName;
+                SegmentedDataSource dataSource = new SegmentedDataSource(trackName, ds);
+                DataSourceTrack track = new DataSourceTrack(locator, trackId, trackName, dataSource, genome);
+                track.setRendererClass(HeatmapRenderer.class);
+                track.setTrackType(ds.getType());
+
+                if (props != null) {
+                    track.setProperties(props);
+                }
+
+                newTracks.add(track);
+            }
+        } else {
+            (new SampleInfoSQLReader()).load(locator);
+        }
+    }
+
+
     private void loadBinarySegFile(ResourceLocator locator, List<Track> newTracks, Genome genome) {
 
         SegmentedBinaryDataSet ds = new SegmentedBinaryDataSet(locator);
@@ -1011,52 +1068,6 @@ public class TrackLoader {
     }
 
 
-    /**
-     * Load the data from an HDF5 file and add resulting tracks to the supplied TrackGroup.
-     * Error messages are appended to the MessageCollection
-     *
-     * @param locator
-     */
-    private void loadH5File(ResourceLocator locator, List<Track> newTracks, Genome genome) {
-
-        TrackSet trackSet = null;
-
-        // TODO -- temporary until "name" property is added to locator
-        // TODO -- "label" has been added, how does that affect this?
-
-        String fName = locator.getTrackName();
-
-        HDFDataManager dataManager = HDFDataManagerFactory.getDataManager(locator);
-        TrackProperties trackProperties = dataManager.getTrackProperties();
-        String[] trackNames = dataManager.getTrackNames();
-
-        List<Track> tracks = new ArrayList();
-
-        for (int trackNumber = 0; trackNumber < trackNames.length; trackNumber++) {
-            String name = trackNames.length == 1 ? fName : trackNames[trackNumber];
-
-            Track track = null;
-            try {
-                track = new HDFDataTrack(dataManager, locator, name, trackNumber, genome);
-            } catch (FileNotFoundException fe) {
-                throw new RuntimeException(fe);
-            }
-            if (trackProperties != null) {
-                track.setProperties(trackProperties);
-            }
-
-            tracks.add(track);
-        }
-
-        trackSet = new TrackSet(tracks);
-
-        if (trackSet.isEmpty()) {
-            throw new RuntimeException("No data found in file");
-        }
-
-        newTracks.addAll(trackSet.getTracks());
-    }
-
     private void loadDASResource(ResourceLocator locator, List<Track> currentTracks) {
 
         //TODO Connect and get all the attributes of the DAS server, and run the appropriate load statements
@@ -1106,7 +1117,13 @@ public class TrackLoader {
 
 
     public static boolean isIndexed(String path) {
-        // genome space hack -- genome space files are never indexed (at least not yet)
+
+        // Checking for the index is expensive over HTTP.  First see if this is an indexable format by fetching the codec
+        if (!isIndexable(path)) {
+            return false;
+        }
+
+        // genome space files are never indexed (at least not yet)
         if (path.contains("genomespace.org")) {
             return false;
         }
@@ -1114,8 +1131,8 @@ public class TrackLoader {
         String indexExtension = path.endsWith("gz") ? ".tbi" : ".idx";
         String indexPath = path + indexExtension;
         try {
-            if (IGVHttpClientUtils.isURL(path)) {
-                return IGVHttpClientUtils.resourceAvailable(new URL(indexPath));
+            if (HttpUtils.getInstance().isURL(path)) {
+                return HttpUtils.getInstance().resourceAvailable(new URL(indexPath));
             } else {
                 File f = new File(path + indexExtension);
                 return f.exists();
@@ -1126,4 +1143,24 @@ public class TrackLoader {
         }
 
     }
+
+
+    /**
+     * Return true if a file represented by "path" is indexable.  This method is an optimization, we could just look
+     * for the index but that is expensive to do for remote resources.  All tribble indexable extensions should be
+     * listed here.
+     *
+     * @param path
+     * @return
+     */
+    private static boolean isIndexable(String path) {
+        String fn = path.toLowerCase();
+        if (fn.endsWith(".gz")) {
+            int l = fn.length() - 3;
+            fn = fn.substring(0, l);
+        }
+
+        return fn.endsWith(".vcf4") || fn.endsWith(".vcf") || fn.endsWith(".bed") || fn.endsWith(".repmask") ||
+                fn.endsWith(".gff3") || fn.endsWith(".gff") || fn.endsWith(".psl") || fn.endsWith(".pslx");
+    }
 }
