@@ -35,7 +35,7 @@ import org.broad.igv.ui.util.MessageUtils;
 import org.broad.igv.util.LongRunningTask;
 import org.broad.igv.util.NamedRunnable;
 import org.broad.igv.util.ResourceLocator;
-import org.broad.igv.vcf.VCFTrack;
+import org.broad.igv.variant.VariantTrack;
 import org.broad.tribble.readers.AsciiLineReader;
 
 import java.awt.*;
@@ -144,7 +144,7 @@ public class TrackManager {
     }
 
     public void reset() {
-        groupByAttribute = "";
+        groupByAttribute = null;
         TrackPanelScrollPane tsp = trackPanelScrollPanes.get(DATA_PANEL_NAME);
         if (tsp != null) {
             tsp.getTrackPanel().reset();
@@ -244,10 +244,13 @@ public class TrackManager {
         //Set<TrackPanel> changedPanels = new HashSet();
 
         log.info("Loading" + locators.size() + " resources.");
-        MessageCollection messages = new MessageCollection();
+        final MessageCollection messages = new MessageCollection();
 
 
-        for (ResourceLocator locator : locators) {
+        // Load files concurrently -- TODO, put a limit on # of threads?
+        List<Thread> threads = new ArrayList<Thread>(locators.size());
+
+        for (final ResourceLocator locator : locators) {
 
             // If its a local file, check explicitly for existence (rather than rely on exception)
             if (locator.isLocal()) {
@@ -258,36 +261,50 @@ public class TrackManager {
                 }
             }
 
-            try {
-                List<Track> tracks = load(locator);
-                if (tracks.size() > 0) {
-                    String path = locator.getPath();
+            Runnable runnable = new Runnable() {
+                public void run() {
+                    try {
+                        List<Track> tracks = load(locator);
+                        if (tracks.size() > 0) {
+                            String path = locator.getPath();
 
-                    // Get an appropriate panel.  If its a VCF file create a new panel if the number of genotypes
-                    // is greater than 10
-                    TrackPanel panel = getPanelFor(locator);
-                    if (path.endsWith(".vcf") || path.endsWith(".vcf.gz") ||
-                            path.endsWith(".vcf4") || path.endsWith(".vcf4.gz")) {
-                        Track t = tracks.get(0);
-                        if (t instanceof VCFTrack && ((VCFTrack) t).getAllSamples().size() > 10) {
-                            String newPanelName = "Panel" + System.currentTimeMillis();
-                            panel = igv.addDataPanel(newPanelName).getTrackPanel();
+                            // Get an appropriate panel.  If its a VCF file create a new panel if the number of genotypes
+                            // is greater than 10
+                            TrackPanel panel = getPanelFor(locator);
+                            if (path.endsWith(".vcf") || path.endsWith(".vcf.gz") ||
+                                    path.endsWith(".vcf4") || path.endsWith(".vcf4.gz")) {
+                                Track t = tracks.get(0);
+                                if (t instanceof VariantTrack && ((VariantTrack) t).getAllSamples().size() > 10) {
+                                    String newPanelName = "Panel" + System.currentTimeMillis();
+                                    panel = igv.addDataPanel(newPanelName).getTrackPanel();
+                                }
+                            }
+                            panel.addTracks(tracks);
                         }
+                    } catch (Throwable e) {
+                        log.error("Error loading tracks", e);
+                        messages.append(e.getMessage());
                     }
-                    panel.addTracks(tracks);
                 }
-            } catch (Throwable e) {
-                log.error("Error loading tracks", e);
-                messages.append(e.getMessage());
+            };
+
+            //Thread thread = new Thread(runnable);
+            //thread.start();
+            //threads.add(thread);
+            runnable.run();
+        }
+
+        // Wait for all threads to complete
+        for (Thread t : threads) {
+            try {
+                t.join();
+            } catch (InterruptedException ignore) {
             }
         }
 
         groupTracksByAttribute();
         resetOverlayTracks();
 
-        //TODO Throw the message window higher up. There should be a throw when you are using the UI,
-        // not when you are connecting through Socket
-
         if (!messages.isEmpty()) {
             for (String message : messages.getMessages()) {
                 MessageUtils.showMessage(message);
@@ -391,7 +408,7 @@ public class TrackManager {
             for (Track track : getAllTracks(false)) {
                 if (track != null) {
                     if (track.getTrackType() == TrackType.MUTATION) {
-                        track.setOverlayed(displayOverlays  && overlaidTracks.contains(track));
+                        track.setOverlayed(displayOverlays && overlaidTracks.contains(track));
                     }
                 }
             }
@@ -438,6 +455,7 @@ public class TrackManager {
         for (Track t : getAllTracks(true)) {
             if (t != null)
                 t.setSelected(false);
+
         }
 
     }
@@ -686,52 +704,39 @@ public class TrackManager {
     }
 
     /**
-     * Method description
-     *
+     * @param reader        a reader for the gene (annotation) file.
      * @param genome
+     * @param geneFileName
+     * @param geneTrackName
      */
-    public void createGeneTrack(Genome genome) {
+    public void createGeneTrack(Genome genome, AsciiLineReader reader, String geneFileName, String geneTrackName,
+                                String annotationURL) {
 
+        FeatureDB.clearFeatures();
         FeatureTrack geneFeatureTrack = null;
-        String genomeId = genome.getId();
-        GenomeDescriptor genomeDescriptor = IGV.getInstance().getGenomeManager().getGenomeDescriptor(genomeId);
-        AsciiLineReader reader = getGeneReader(genomeDescriptor);
+
         if (reader != null) {
-            try {
+            FeatureParser parser = AbstractFeatureParser.getInstanceFor(new ResourceLocator(geneFileName), genome);
+            if (parser == null) {
+                MessageUtils.showMessage("ERROR: Unrecognized annotation file format: " + geneFileName +
+                        "<br>Annotations for genome: " + genome.getId() + " will not be loaded.");
+            } else {
+                List<org.broad.tribble.Feature> genes = parser.loadFeatures(reader);
+                String name = geneTrackName;
+                if (name == null) name = "Genes";
 
-                String geneFilename = genomeDescriptor.getGeneFileName();
-                FeatureParser parser = AbstractFeatureParser.getInstanceFor(new ResourceLocator(geneFilename), genome);
-                if (parser == null) {
-                    MessageUtils.showMessage("ERROR: Unrecognized annotation file format: " + geneFilename +
-                            "<br>Annotations for genome: " + genomeId + " will not be loaded.");
-                } else {
-                    List<org.broad.tribble.Feature> genes = parser.loadFeatures(reader);
-                    String name = genomeDescriptor.getGeneTrackName();
-                    if (name == null) name = "Genes";
-
-                    String id = genome.getId() + "_genes";
-                    geneFeatureTrack = new FeatureTrack(id, name, new FeatureCollectionSource(genes, genome));
-                    geneFeatureTrack.setMinimumHeight(5);
-                    geneFeatureTrack.setHeight(35);
-                    geneFeatureTrack.setPreferredHeight(35);
-                    geneFeatureTrack.setRendererClass(IGVFeatureRenderer.class);
-                    geneFeatureTrack.setColor(Color.BLUE.darker());
-                    TrackProperties props = parser.getTrackProperties();
-                    if (props != null) {
-                        geneFeatureTrack.setProperties(parser.getTrackProperties());
-                    }
-                    geneFeatureTrack.setUrl(genome.getAnnotationURL());
+                String id = genome.getId() + "_genes";
+                geneFeatureTrack = new FeatureTrack(id, name, new FeatureCollectionSource(genes, genome));
+                geneFeatureTrack.setMinimumHeight(5);
+                geneFeatureTrack.setHeight(35);
+                geneFeatureTrack.setPreferredHeight(35);
+                geneFeatureTrack.setRendererClass(IGVFeatureRenderer.class);
+                geneFeatureTrack.setColor(Color.BLUE.darker());
+                TrackProperties props = parser.getTrackProperties();
+                if (props != null) {
+                    geneFeatureTrack.setProperties(parser.getTrackProperties());
                 }
-
-            } catch (Exception e) {
-                log.error("Error loading geneManager", e);
-            }
-            finally {
-
-                if (reader != null) {
-                    reader.close();
-                }
-
+                geneFeatureTrack.setUrl(annotationURL);
             }
         }
 
@@ -790,23 +795,13 @@ public class TrackManager {
 
     public static AsciiLineReader getGeneReader(GenomeDescriptor genomeDescriptor) {
 
-        InputStream is = null;
         try {
 
             InputStream inputStream = genomeDescriptor.getGeneStream();
             if (inputStream == null) {
                 return null;
             }
-
-            AsciiLineReader reader = null;
-            if (genomeDescriptor.isGeneFileGZipFormat()) {
-                is = new GZIPInputStream(inputStream);
-                reader = new AsciiLineReader(is);
-            } else {
-                is = new BufferedInputStream(inputStream);
-                reader = new AsciiLineReader(is);
-            }
-
+            AsciiLineReader reader = new AsciiLineReader(inputStream);
             return reader;
         } catch (IOException ex) {
             log.warn("Error loading the genome!", ex);
