@@ -31,9 +31,7 @@ import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
 import org.broad.igv.PreferenceManager;
 import org.broad.igv.feature.*;
-import org.broad.igv.feature.genome.GenomeBuilderDialog;
-import org.broad.igv.feature.genome.GenomeManager.GenomeListItem;
-import org.broad.igv.feature.genome.GenomeManager;
+import org.broad.igv.feature.genome.*;
 import org.broad.igv.lists.GeneList;
 import org.broad.igv.lists.GeneListManager;
 import org.broad.igv.batch.BatchRunner;
@@ -61,6 +59,7 @@ import static org.broad.igv.ui.util.UIUtilities.getFileChooser;
 import org.broad.igv.ui.filefilters.AlignmentFileFilter;
 
 import org.broad.igv.util.*;
+import org.broad.tribble.util.SeekableFileStream;
 
 import javax.swing.*;
 import javax.swing.filechooser.FileFilter;
@@ -90,6 +89,8 @@ public class IGV {
     private IGVContentPane contentPane;
     private IGVMenuBar menuBar;
 
+    private StatusWindow statusWindow;
+
     // Glass panes
     Component glassPane;
     GhostGlassPane dNdGlassPane;
@@ -110,7 +111,6 @@ public class IGV {
     // FileChooser Dialogs
     private FileChooserDialog trackFileChooser;
     private FileChooser snapshotFileChooser;
-    private FileChooser genomeImportFileChooser;
 
 
     // Misc state
@@ -200,7 +200,7 @@ public class IGV {
 
             @Override
             public void windowActivated(WindowEvent windowEvent) {
-               ToolTipManager.sharedInstance().setEnabled(true);
+                ToolTipManager.sharedInstance().setEnabled(true);
             }
 
             @Override
@@ -210,7 +210,6 @@ public class IGV {
         });
 
 
-
         session = new Session(null);
         trackManager = new TrackManager(this);
 
@@ -421,18 +420,53 @@ public class IGV {
         repaintDataAndHeaderPanels(true);
     }
 
+    /**
+     * Repaint the header and data panels.
+     * <p/>
+     * Note:  If running in Batch mode a monitor is used to force synchrnous painting.  This is neccessary as the
+     * paint() command triggers loading of data.  If allowed to proceed asynchronously the "snapshot" batch command
+     * might execute before the data from a previous command has loaded.
+     *
+     * @param updateCommandBar
+     */
     public void repaintDataAndHeaderPanels(boolean updateCommandBar) {
-        rootPane.repaint();
+        if (Globals.isBatch()) {
+            if (SwingUtilities.isEventDispatchThread()) {
+                rootPane.paintImmediately(rootPane.getBounds());
+            } else {
+                synchronized (this) {
+                    Runnable r = new Runnable() {
+                        public void run() {
+                            synchronized (IGV.this) {
+                                rootPane.paintImmediately(rootPane.getBounds());
+                                IGV.this.notify();
+                            }
+                        }
+                    };
+                    UIUtilities.invokeOnEventThread(r);
+                    try {
+                        // Wait a maximum of 5 minutes
+                        this.wait(5 * 60 * 1000);
+                    } catch (InterruptedException e) {
+                        // Just continue
+                    }
+                }
+            }
+        } else {
+            rootPane.repaint();
+        }
         if (updateCommandBar) {
             contentPane.updateCurrentCoordinates();
         }
     }
 
+    /**
+     * Repaint the data panels.  Deprecated, but kept for backwards compatibility.
+     *
+     * @deprecated
+     */
     public void repaintDataPanels() {
-        for (TrackPanelScrollPane tsv : trackManager.getTrackPanelScrollPanes()) {
-            tsv.getDataPanel().repaint();
-        }
-
+        repaintDataAndHeaderPanels(false);
     }
 
     public void repaintNamePanels() {
@@ -493,11 +527,12 @@ public class IGV {
                     fastaFileName, chrAliasFile, relativeSequenceLocation, genomeDisplayName,
                     genomeId, genomeFileName, monitor, seqLocationOverride);
 
-            enableRemoveGenomes();
-
-            contentPane.getCommandBar().addToUserDefinedGenomeItemList(genomeListItem);
-            contentPane.getCommandBar().selectGenomeFromListWithNoImport(genomeListItem.getId());
+            if (genomeListItem != null) {
+                enableRemoveGenomes();
 
+                contentPane.getCommandBar().addToUserDefinedGenomeItemList(genomeListItem);
+                contentPane.getCommandBar().selectGenomeFromListWithNoImport(genomeListItem.getId());
+            }
             if (monitor != null) {
                 monitor.fireProgressChange(100);
             }
@@ -554,137 +589,63 @@ public class IGV {
      * @return
      */
 
-    public GenomeListItem doLoadGenome(ProgressMonitor monitor) {
+    public void doLoadGenome(ProgressMonitor monitor) {
 
         ProgressBar bar = null;
-        GenomeListItem genomeListItem = null;
-        boolean doImport = true;
-        while (doImport) {
-
-            doImport = false;
-            File file = null;
-            CursorToken token = WaitCursorManager.showWaitCursor();
-            try {
-                File importDirectory =
-                        PreferenceManager.getInstance().getLastGenomeImportDirectory();
-                if (importDirectory == null) {
-                    PreferenceManager.getInstance().setLastGenomeImportDirectory(Globals.getUserDirectory());
-                }
-
-                FileFilter[] fileFilters = {new SnapshotUtilities.GenomeArchiveFileFilter()};
-
-                genomeImportFileChooser = getFileChooser(importDirectory, null, fileFilters);
-                genomeImportFileChooser.setDialogTitle("Load Genome");
-                genomeImportFileChooser.addPropertyChangeListener(
-                        new PropertyChangeListener() {
-
-                            public void propertyChange(PropertyChangeEvent e) {
-
-                                File oldFile = null;
-                                String property = e.getPropertyName();
-                                if (JFileChooser.SELECTED_FILE_CHANGED_PROPERTY.equals(property)) {
-                                    oldFile = (File) e.getOldValue();
-                                    genomeImportFileChooser.setPreviousFile(oldFile);
-                                } else if (JFileChooser.FILE_FILTER_CHANGED_PROPERTY.equals(property)) {
-
-                                    if (e.getOldValue() instanceof SnapshotUtilities.GenomeArchiveFileFilter &&
-                                            e.getNewValue() instanceof SnapshotUtilities.GenomeArchiveFileFilter) {
-
-                                        SnapshotUtilities.GenomeArchiveFileFilter newFilter =
-                                                (SnapshotUtilities.GenomeArchiveFileFilter) e.getNewValue();
-
-                                        File currentDirectory = genomeImportFileChooser.getCurrentDirectory();
-                                        File previousFile = genomeImportFileChooser.getPreviousFile();
-                                        if (previousFile != null) {
-
-                                            File file = null;
-                                            if (currentDirectory != null) {
-                                                file = new File(currentDirectory, previousFile.getName());
-                                            } else {
-                                                file = previousFile;
-                                            }
-
-                                            final File selectedFile = Utilities.changeFileExtension(
-                                                    file, newFilter.getExtension());
-
-                                            UIUtilities.invokeOnEventThread(new Runnable() {
-
-                                                public void run() {
-                                                    genomeImportFileChooser.setSelectedFile(selectedFile);
-                                                    genomeImportFileChooser.validate();
-                                                }
-                                            });
-                                        }
-
-                                    }
-                                }
-                            }
-                        });
-
-                // Display the dialog
-                genomeImportFileChooser.showOpenDialog(mainFrame);
-                file = genomeImportFileChooser.getSelectedFile();
-
-                // If a file selection was made
-                if (file != null) {
-                    if (monitor != null) {
-                        bar = ProgressBar.showProgressDialog(mainFrame, "Loading Genome...", monitor, false);
-                    }
-
-                    File directory = genomeImportFileChooser.getCurrentDirectory();
-                    if (directory != null) {
-                        PreferenceManager.getInstance().setLastGenomeImportDirectory(directory);
-                    }
-
-                    try {
-
-                        // Import the genome
-
-                        if (log.isDebugEnabled()) {
-                            log.debug("Call loadGenome");
-                        }
-                        genomeListItem = IGV.getInstance().getGenomeManager().loadGenome(file.getAbsolutePath(), true, monitor);
-                        contentPane.getCommandBar().addToUserDefinedGenomeItemList(genomeListItem);
-                        contentPane.getCommandBar().selectGenomeFromListWithNoImport(genomeListItem.getId());
-
-
-                        if (monitor != null) {
-                            monitor.fireProgressChange(100);
-                        }
-
-                        if (bar != null) {
-                            bar.close();
-                        }
-
-                    } catch (Exception e) {
-                        log.fatal("Could not import genome!", e);
-                    } finally {
-                    }
-                }
-            } catch (Exception e) {
-
-                String genomePath = "";
-                if (file != null) {
-                    genomePath = file.getAbsolutePath();
-                }
-
-                log.error("Failed to load genome: " + genomePath, e);
-                int option =
-                        JOptionPane.showConfirmDialog(mainFrame, "Failed to load the current genome " +
-                                genomePath + "\n" + "Would you like to load another?",
-                                "Load Genome Failure", JOptionPane.OK_CANCEL_OPTION);
-
-                if (option == JOptionPane.OK_OPTION) {
-                    doImport = true;
-                }
-
-            } finally {
-                WaitCursorManager.removeWaitCursor(token);
+        File file = null;
+        CursorToken token = WaitCursorManager.showWaitCursor();
+        try {
+            File importDirectory = PreferenceManager.getInstance().getLastGenomeImportDirectory();
+            if (importDirectory == null) {
+                PreferenceManager.getInstance().setLastGenomeImportDirectory(Globals.getUserDirectory());
             }
 
+            // Display the dialog
+            file = FileDialogUtils.chooseFile("Load Genome", importDirectory, FileDialog.LOAD);
+
+            // If a file selection was made
+            if (file != null) {
+                if (monitor != null) {
+                    bar = ProgressBar.showProgressDialog(mainFrame, "Loading Genome...", monitor, false);
+                }
+
+                loadGenome(file.getAbsolutePath(), monitor);
+
+            }
+        } catch (Exception e) {
+            MessageUtils.showMessage("<html>Error loading: " + file.getAbsolutePath() + "<br>" + e.getMessage());
+            log.error("Error loading: " + file.getAbsolutePath(), e);
+        } finally {
+            WaitCursorManager.removeWaitCursor(token);
+            if (monitor != null) {
+                monitor.fireProgressChange(100);
+            }
+
+            if (bar != null) {
+                bar.close();
+            }
         }
 
-        return genomeListItem;
+    }
+
+    public void loadGenome(String path, ProgressMonitor monitor) throws IOException {
+
+        File file = new File(path);
+        if (file.exists()) {
+            File directory = file.getParentFile();
+            PreferenceManager.getInstance().setLastGenomeImportDirectory(directory);
+        }
+
+        Genome genome = getGenomeManager().loadGenome(path, monitor);
+        final String name = genome.getDisplayName();
+        final String id = genome.getId();
+
+        GenomeListItem genomeListItem = new GenomeListItem(name, path, id, true);
+        getGenomeManager().addUserDefineGenomeItem(genomeListItem);
+
+        contentPane.getCommandBar().addToUserDefinedGenomeItemList(genomeListItem);
+        contentPane.getCommandBar().selectGenomeFromListWithNoImport(genomeListItem.getId());
+
     }
 
 
@@ -695,105 +656,91 @@ public class IGV {
 
     /**
      * Load a collection of tracks in a background thread.
+     * <p/>
+     * Note: Most of the code here is to adjust the scrollbars and split pane after loading
      *
      * @param locators
      */
     public void loadTracks(final Collection<ResourceLocator> locators) {
-        loadTracks(locators, false);
-    }
-
-
-    /**
-     * Load tracks corresponding to a collection of resource locations.
-     * Note: Most of the code here is to adjust the scrollbars and split pane after loading
-     * // TODO -- why is this in the batch frame (as opposed to TrackManager for example)?
-     *
-     * @param locators
-     */
-    public void loadTracks(final Collection<ResourceLocator> locators, boolean doInBackground) {
 
         contentPane.getStatusBar().setMessage("Loading ...");
 
         log.debug("Run loadTracks");
 
-        CursorToken token = null;
 
-        try {
-            token = WaitCursorManager.showWaitCursor();
-            if (locators != null && !locators.isEmpty()) {
+        if (locators != null && !locators.isEmpty()) {
 
-                // get current track count per panel.  Needed to detect which panels
-                // changed.  Also record panel sizes
-                final HashMap<TrackPanelScrollPane, Integer> trackCountMap = new HashMap();
-                final HashMap<TrackPanelScrollPane, Integer> panelSizeMap = new HashMap();
-                final Collection<TrackPanelScrollPane> scrollPanes = trackManager.getTrackPanelScrollPanes();
-                for (TrackPanelScrollPane sp : scrollPanes) {
-                    trackCountMap.put(sp, sp.getDataPanel().getAllTracks().size());
-                    panelSizeMap.put(sp, sp.getDataPanel().getHeight());
-                }
+            // NOTE:  this work CANNOT be done on the dispatch thread, it will potentially cause deadlock if
+            // dialogs are opened or other Swing tasks are done.
 
-                getTrackManager().loadResources(locators);
+            NamedRunnable runnable = new NamedRunnable() {
+                public void run() {
+                    // get current track count per panel.  Needed to detect which panels
+                    // changed.  Also record panel sizes
+                    final HashMap<TrackPanelScrollPane, Integer> trackCountMap = new HashMap();
+                    final HashMap<TrackPanelScrollPane, Integer> panelSizeMap = new HashMap();
+                    final Collection<TrackPanelScrollPane> scrollPanes = trackManager.getTrackPanelScrollPanes();
+                    for (TrackPanelScrollPane sp : scrollPanes) {
+                        trackCountMap.put(sp, sp.getDataPanel().getAllTracks().size());
+                        panelSizeMap.put(sp, sp.getDataPanel().getHeight());
+                    }
 
-                double totalHeight = 0;
-                for (TrackPanelScrollPane sp : scrollPanes) {
-                    if (trackCountMap.containsKey(sp)) {
-                        int prevTrackCount = trackCountMap.get(sp).intValue();
-                        if (prevTrackCount != sp.getDataPanel().getAllTracks().size()) {
-                            int scrollPosition = panelSizeMap.get(sp);
-                            if (prevTrackCount != 0 && sp.getVerticalScrollBar().isShowing()) {
-                                sp.getVerticalScrollBar().setMaximum(sp.getDataPanel().getHeight());
-                                sp.getVerticalScrollBar().setValue(scrollPosition);
+                    getTrackManager().loadResources(locators);
+
+                    double totalHeight = 0;
+                    for (TrackPanelScrollPane sp : scrollPanes) {
+                        if (trackCountMap.containsKey(sp)) {
+                            int prevTrackCount = trackCountMap.get(sp).intValue();
+                            if (prevTrackCount != sp.getDataPanel().getAllTracks().size()) {
+                                int scrollPosition = panelSizeMap.get(sp);
+                                if (prevTrackCount != 0 && sp.getVerticalScrollBar().isShowing()) {
+                                    sp.getVerticalScrollBar().setMaximum(sp.getDataPanel().getHeight());
+                                    sp.getVerticalScrollBar().setValue(scrollPosition);
+                                }
                             }
                         }
+                        // Give a maximum "weight" of 300 pixels to each panel.  If there are no tracks, give zero
+                        if (sp.getTrackPanel().getTracks().size() > 0)
+                            totalHeight += Math.min(300, sp.getTrackPanel().getPreferredPanelHeight());
                     }
-                    // Give a maximum "weight" of 300 pixels to each panel.  If there are no tracks, give zero
-                    if (sp.getTrackPanel().getTracks().size() > 0)
-                        totalHeight += Math.min(300, sp.getTrackPanel().getPreferredPanelHeight());
-                }
 
-                // Adjust dividers for data panel.  The data panel divider can be
-                // zero if there are no data tracks loaded.
-                final JideSplitPane centerSplitPane = contentPane.getMainPanel().getCenterSplitPane();
-                int htotal = centerSplitPane.getHeight();
-                int y = 0;
-                int i = 0;
-                for (Component c : centerSplitPane.getComponents()) {
-                    if (c instanceof TrackPanelScrollPane) {
-                        final TrackPanel trackPanel = ((TrackPanelScrollPane) c).getTrackPanel();
-                        if (trackPanel.getTracks().size() > 0) {
-                            int panelWeight = Math.min(300, trackPanel.getPreferredPanelHeight());
-                            int dh = (int) ((panelWeight / totalHeight) * htotal);
-                            y += dh;
+                    // Adjust dividers for data panel.  The data panel divider can be
+                    // zero if there are no data tracks loaded.
+                    final JideSplitPane centerSplitPane = contentPane.getMainPanel().getCenterSplitPane();
+                    int htotal = centerSplitPane.getHeight();
+                    int y = 0;
+                    int i = 0;
+                    for (Component c : centerSplitPane.getComponents()) {
+                        if (c instanceof TrackPanelScrollPane) {
+                            final TrackPanel trackPanel = ((TrackPanelScrollPane) c).getTrackPanel();
+                            if (trackPanel.getTracks().size() > 0) {
+                                int panelWeight = Math.min(300, trackPanel.getPreferredPanelHeight());
+                                int dh = (int) ((panelWeight / totalHeight) * htotal);
+                                y += dh;
+                            }
+                            centerSplitPane.setDividerLocation(i, y);
+                            i++;
                         }
-                        centerSplitPane.setDividerLocation(i, y);
-                        i++;
                     }
+
+                    SwingUtilities.invokeLater(new Runnable() {
+                        public void run() {
+                            contentPane.getMainPanel().doLayout();
+                            contentPane.getStatusBar().setMessage("");
+                        }
+                    });
+
+                    System.out.println("Exit load");
                 }
 
-                SwingUtilities.invokeLater(new Runnable() {
-                    public void run() {
-                        contentPane.getMainPanel().doLayout();
-
-
-                    }
-                });
-            }
-        } catch (Exception e) {
-            if (!(e instanceof ConcurrentModificationException)) {
-                if (e.getMessage() != null && e.getMessage().length() > 8) {
-                    MessageUtils.showMessage(e.getMessage());
-                } else {
-                    log.error(e);
-                    MessageUtils.showMessage("An error occurred while loading tracks. " +
-                            "Please check the logs for details.");
+                public String getName() {
+                    return "Load Tracks";
                 }
-            }
-        } finally {
-            showLoadedTrackCount();
-            if (token != null) {
-                WaitCursorManager.removeWaitCursor(token);
-            }
+            };
+
+            LongRunningTask.submit(runnable);
         }
+
         log.debug("Finish loadTracks");
 
     }
@@ -937,7 +884,8 @@ public class IGV {
             }
             PreferenceManager.getInstance().remove(PreferenceManager.RECENT_SESSION_KEY);
             PreferenceManager.getInstance().setRecentSessions(recentSessions);
-            IGVHttpClientUtils.shutdown();
+            HttpUtils.getInstance().shutdown();
+            CommandListener.halt();
         }
 
 
@@ -1030,8 +978,7 @@ public class IGV {
             log.error("Error creating exporting image ", e);
             MessageUtils.showMessage(("Error creating the image file: " + defaultFile + "<br> "
                     + e.getMessage()));
-        }
-        finally {
+        } finally {
             WaitCursorManager.removeWaitCursor(token);
             resetStatusMessage();
         }
@@ -1159,8 +1106,7 @@ public class IGV {
             // Draw hand image in middle
             g = handImage.createGraphics();
             g.drawImage(IconFactory.getInstance().getIcon(IconFactory.IconID.FIST).getImage(), 0, 0, null);
-            fistCursor =
-                    mainFrame.getToolkit().createCustomCursor(handImage, new Point(8, 6), "Move");
+            fistCursor = mainFrame.getToolkit().createCustomCursor(handImage, new Point(8, 6), "Move");
         }
 
     }
@@ -1210,6 +1156,8 @@ public class IGV {
 
         AttributeManager.getInstance().clearAllAttributes();
 
+        SeekableFileStream.closeAllInstances();
+
         session = new Session(sessionName);
 
         contentPane.getMainPanel().resetPanels();
@@ -1247,7 +1195,8 @@ public class IGV {
 
         } catch (Exception e) {
             String message = "Failure while resetting preferences!";
-            MessageUtils.showAndLogErrorMessage(mainFrame, message, log, e);
+            log.error(message, e);
+            MessageUtils.showMessage(message + ": " + e.getMessage());
         }
 
     }
@@ -1320,41 +1269,14 @@ public class IGV {
     final public void doRestoreSession(final File sessionFile,
                                        final String locus) {
 
-        String filePath = "";
-        if (sessionFile != null) {
-
-            log.debug("Run doRestoreSession");
-
-            InputStream inputStream = null;
-            CursorToken token = WaitCursorManager.showWaitCursor();
-            try {
-                inputStream = new BufferedInputStream(new FileInputStream(sessionFile));
-                doRestoreSession(inputStream, sessionFile.getAbsolutePath(), locus, false);
-
-                String sessionFilePath = sessionFile.getAbsolutePath();
-                if (!getRecentSessionList().contains(sessionFilePath)) {
-                    getRecentSessionList().addFirst(sessionFilePath);
-                }
-
-            } catch (Exception e) {
-                String message = "Failed to load session! : " + sessionFile.getAbsolutePath();
-                MessageUtils.showAndLogErrorMessage(mainFrame, message, log, e);
-            } finally {
-                WaitCursorManager.removeWaitCursor(token);
-                if (inputStream != null) {
-                    try {
-                        inputStream.close();
-                    } catch (IOException iOException) {
-                        log.error("Error closing session stream", iOException);
-                    }
-                }
-            }
-            log.debug("Finish doRestoreSession");
+        if (sessionFile.exists()) {
 
+            doRestoreSession(sessionFile.getAbsolutePath(), locus, false);
 
         } else {
-            String message = "Session file does not exist! : " + filePath;
-            MessageUtils.showAndLogErrorMessage(mainFrame, message, log);
+            String message = "Session file does not exist! : " + sessionFile.getAbsolutePath();
+            log.error(message);
+            MessageUtils.showMessage(message);
         }
 
     }
@@ -1363,71 +1285,85 @@ public class IGV {
     final public void doRestoreSession(final URL sessionURL,
                                        final String locus) throws Exception {
 
-        log.debug("Enter doRestoreSession: " + sessionURL + " " + locus);
-
-        InputStream inputStream = null;
-        try {
-            inputStream = new BufferedInputStream(sessionURL.openStream());
-            doRestoreSession(inputStream, URLDecoder.decode(sessionURL.toExternalForm(), "UTF-8"), locus, false);
-        } finally {
-
-            if (inputStream != null) {
-                try {
-                    inputStream.close();
-                } catch (IOException iOException) {
-                    log.error("Error closing session stream", iOException);
-                }
-            }
-        }
-
-        log.debug("Exit doRestoreSession");
+        doRestoreSession(URLDecoder.decode(sessionURL.toExternalForm(), "UTF-8"), locus, false);
 
     }
 
-    final public void doRestoreSession(final InputStream inputStream,
-                                       final String sessionPath,
+    final public void doRestoreSession(final String sessionPath,
                                        final String locus,
-                                       boolean merge) {
+                                       final boolean merge) {
 
-        try {
-            setStatusBarMessage("Opening session...");
+        NamedRunnable runnable = new NamedRunnable() {
+            public void run() {
 
-            if (!merge) {
-                createNewSession(sessionPath);
+                InputStream inputStream = null;
+                try {
+
+                    if (!merge) {
+                        // Do this first, it closes all open SeekableFileStreams.
+                        createNewSession(sessionPath);
+                    }
+
+                    setStatusBarMessage("Opening session...");
+                    inputStream = ParsingUtils.openInputStream(new ResourceLocator(sessionPath));
+
+                    final SessionReader sessionReader = new SessionReader(IGV.this);
+
+                    sessionReader.loadSession(inputStream, session, sessionPath);
+
+                    String searchText = locus == null ? session.getLocus() : locus;
+
+                    // NOTE: Nothing to do if chr == all
+                    if (!FrameManager.isGeneListMode() && searchText != null &&
+                            !searchText.equals(Globals.CHR_ALL) && searchText.trim().length() > 0) {
+                        goToLocus(searchText);
+                    }
+
+
+                    mainFrame.setTitle(UIConstants.APPLICATION_NAME + " - Session: " + sessionPath);
+                    LRUCache.clearCaches();
+
+
+                    double[] dividerFractions = session.getDividerFractions();
+                    if (dividerFractions != null) {
+                        contentPane.getMainPanel().setDividerFractions(dividerFractions);
+                    }
+                    session.clearDividerLocations();
+
+                    //If there's a RegionNavigatorDialog, kill it.
+                    //this could be done through the Observer that RND uses, I suppose.  Not sure that's cleaner
+                    RegionNavigatorDialog.destroyActiveInstance();
+
+                    if (!getRecentSessionList().contains(sessionPath)) {
+                        getRecentSessionList().addFirst(sessionPath);
+                    }
+
+
+                    doRefresh();
+                } catch (Exception e) {
+                    String message = "Failed to load session! : " + sessionPath;
+                    log.error(message, e);
+                    MessageUtils.showMessage(message + ": " + e.getMessage());
+
+                } finally {
+                    if (inputStream != null) {
+                        try {
+                            inputStream.close();
+                        } catch (IOException iOException) {
+                            log.error("Error closing session stream", iOException);
+                        }
+                        resetStatusMessage();
+                    }
+                }
             }
 
-            final SessionReader sessionReader = new SessionReader(this);
-
-            sessionReader.loadSession(inputStream, session, sessionPath);
-
-            String searchText = locus == null ? session.getLocus() : locus;
-
-            // NOTE: Nothing to do if chr == all
-            if (!FrameManager.isGeneListMode() && searchText != null &&
-                    !searchText.equals(Globals.CHR_ALL) && searchText.trim().length() > 0) {
-                goToLocus(searchText);
+            public String getName() {
+                return "Restore session: " + sessionPath;
             }
+        };
 
+        LongRunningTask.submit(runnable);
 
-            mainFrame.setTitle(UIConstants.APPLICATION_NAME + " - Session: " + sessionPath);
-            LRUCache.clearCaches();
-
-
-            double[] dividerFractions = session.getDividerFractions();
-            if (dividerFractions != null) {
-                contentPane.getMainPanel().setDividerFractions(dividerFractions);
-            }
-            session.clearDividerLocations();
-
-            //If there's a RegionNavigatorDialog, kill it.
-            //this could be done through the Observer that RND uses, I suppose.  Not sure that's cleaner
-            RegionNavigatorDialog.destroyActiveInstance();
-
-            doRefresh();
-        } finally {
-
-            resetStatusMessage();
-        }
 
     }
 
@@ -1544,25 +1480,25 @@ public class IGV {
         return contentPane != null && contentPane.getCommandBar().isSuppressTooltip();
     }
 
-    public void startUp(final String[] args) {
+    public void openStatusWindow() {
+        if (statusWindow == null) {
+            statusWindow = new StatusWindow();
+        }
+        statusWindow.setVisible(true);
+    }
+
+    public void setStatusWindowText(String text) {
+        if (statusWindow != null && statusWindow.isVisible()) {
+            statusWindow.updateText(text);
+        }
+    }
+
+    public void startUp(Main.IGVArgs igvArgs) {
 
         if (log.isDebugEnabled()) {
             log.debug("startUp");
         }
 
-        Main.IGVArgs igvArgs = new Main.IGVArgs(args);
-
-        // Optional arguments
-        if (igvArgs.getPropertyFile() != null) {
-        }
-        if (igvArgs.getDataServerURL() != null) {
-            PreferenceManager.getInstance().overrideDataServerURL(igvArgs.getDataServerURL());
-        }
-        if (igvArgs.getGenomeServerURL() != null) {
-            PreferenceManager.getInstance().overrideGenomeServerURL(igvArgs.getGenomeServerURL());
-        }
-
-
         SwingWorker worker = new StartupWorker(igvArgs);
         worker.execute();
     }
@@ -1571,7 +1507,6 @@ public class IGV {
         return startupComplete;
     }
 
-
     /**
      * Swing worker class to startup IGV
      */
@@ -1605,16 +1540,16 @@ public class IGV {
             } catch (NoRouteToHostException ex) {
                 JOptionPane.showMessageDialog(mainFrame, "Network error initializing genome list: " + ex.getMessage());
                 log.error("Network error initializing genome list: ", ex);
-            }
-            finally {
+            } finally {
                 monitor.fireProgressChange(50);
                 closeWindow(progressBar);
             }
 
+            final PreferenceManager preferenceManager = PreferenceManager.getInstance();
             if (igvArgs.getGenomeId() != null) {
                 selectGenomeFromList(igvArgs.getGenomeId());
             } else if (igvArgs.getSessionFile() == null) {
-                String genomeId = PreferenceManager.getInstance().getDefaultGenome();
+                String genomeId = preferenceManager.getDefaultGenome();
                 contentPane.getCommandBar().selectGenomeFromList(genomeId);
             }
 
@@ -1637,7 +1572,7 @@ public class IGV {
 
 
                     if (igvArgs.getSessionFile() != null) {
-                        if (IGVHttpClientUtils.isURL(igvArgs.getSessionFile())) {
+                        if (HttpUtils.getInstance().isURL(igvArgs.getSessionFile())) {
                             URL url = new URL(igvArgs.getSessionFile());
                             doRestoreSession(url, igvArgs.getLocusString());
                         } else {
@@ -1652,7 +1587,13 @@ public class IGV {
                         String indexFile = igvArgs.getIndexFile();
                         List<ResourceLocator> locators = new ArrayList();
                         for (String p : tokens) {
+                            if (FileUtils.isRemote(p)) {
+                                p = URLDecoder.decode(p);
+                            }
                             ResourceLocator rl = new ResourceLocator(p);
+                            if (igvArgs.getName() != null) {
+                                rl.setName(igvArgs.getName());
+                            }
                             rl.setIndexPath(indexFile);
                             locators.add(rl);
                         }
@@ -1666,7 +1607,7 @@ public class IGV {
                     log.error("Error loading session: " + tmp, ex);
 
                     // Session load failed, load default genome
-                    String genomeId = PreferenceManager.getInstance().getDefaultGenome();
+                    String genomeId = preferenceManager.getDefaultGenome();
                     contentPane.getCommandBar().selectGenomeFromList(genomeId);
 
                 }
@@ -1683,17 +1624,18 @@ public class IGV {
             session.recordHistory();
 
             // Start up a port listener.  Port # can be overriden with "-p" command line switch
-            boolean portEnabled = PreferenceManager.getInstance().getAsBoolean(PreferenceManager.PORT_ENABLED);
+            boolean portEnabled = preferenceManager.getAsBoolean(PreferenceManager.PORT_ENABLED);
             String portString = igvArgs.getPort();
             if (portEnabled || portString != null) {
                 // Command listner thread
-                int port = PreferenceManager.getInstance().getAsInt(PreferenceManager.PORT_NUMBER);
+                int port = preferenceManager.getAsInt(PreferenceManager.PORT_NUMBER);
                 if (portString != null) {
                     port = Integer.parseInt(portString);
                 }
                 CommandListener.start(port);
             }
 
+
             startupComplete = true;
 
             UIUtilities.invokeOnEventThread(new Runnable() {
