@@ -33,7 +33,7 @@ import org.broad.igv.feature.Chromosome;
 import org.broad.igv.feature.Cytoband;
 import org.broad.igv.feature.FeatureDB;
 import org.broad.igv.feature.genome.Genome;
-import org.broad.igv.feature.genome.GenomeManager.GenomeListItem;
+import org.broad.igv.feature.genome.GenomeListItem;
 import org.broad.igv.feature.genome.GenomeServerException;
 import org.broad.igv.session.History;
 import org.broad.igv.ui.action.FitDataToWindowMenuAction;
@@ -53,6 +53,7 @@ import java.awt.*;
 import java.awt.event.*;
 import java.awt.geom.Rectangle2D;
 import java.io.FileNotFoundException;
+import java.io.IOException;
 import java.net.NoRouteToHostException;
 import java.util.*;
 import java.util.List;
@@ -188,8 +189,10 @@ public class IGVCommandBar extends javax.swing.JPanel {
                         try {
                             monitor.fireProgressChange(50);
 
-                            igv.getGenomeManager().loadGenome(genomeListItem.getLocation(), genomeListItem.isUserDefined(), null);
-                            updateGenome(genomeListItem.getId());
+
+                            Genome genome = igv.getGenomeManager().loadGenome(genomeListItem.getLocation(), null);
+
+                            updateGenome(genome);
                             monitor.fireProgressChange(25);
 
                             if (!isGenomeCached(genomeListItem.getId())) {
@@ -212,7 +215,7 @@ public class IGVCommandBar extends javax.swing.JPanel {
                             JOptionPane.showMessageDialog(
                                     IGV.getMainFrame(),
                                     UIConstants.CANNOT_ACCESS_SERVER_GENOME_LIST);
-                        } catch (FileNotFoundException e) {
+                        } catch (IOException e) {
                             if (bar != null) {
                                 bar.close();
                             }
@@ -220,7 +223,7 @@ public class IGVCommandBar extends javax.swing.JPanel {
                             int choice =
                                     JOptionPane.showConfirmDialog(
                                             IGV.getMainFrame(), "The genome file [" + e.getMessage() +
-                                                    "] could not be located. Would you like to remove the selected entry?",
+                                            "] could not be read. Would you like to remove the selected entry?",
                                             "", JOptionPane.OK_CANCEL_OPTION);
 
                             if (choice == JOptionPane.OK_OPTION) {
@@ -424,14 +427,14 @@ public class IGVCommandBar extends javax.swing.JPanel {
 
     public void setGeneListMode(boolean geneListMode) {
 
-        genomeComboBox.setEnabled(!geneListMode);
-        locationPanel.setEnabled(!geneListMode);
+         genomeComboBox.setEnabled(!geneListMode);
+//        locationPanel.setEnabled(!geneListMode);
         chromosomeComboBox.setEnabled(!geneListMode);
-        searchTextField.setEnabled(!geneListMode);
-        goButton.setEnabled(!geneListMode);
-        zoomControl.setEnabled(!geneListMode);
-        homeButton.setEnabled(!geneListMode);
-        roiToggleButton.setEnabled(!geneListMode);
+//        searchTextField.setEnabled(!geneListMode);
+//        goButton.setEnabled(!geneListMode);
+//        zoomControl.setEnabled(!geneListMode);
+//        homeButton.setEnabled(true);
+//        roiToggleButton.setEnabled(!geneListMode);
     }
 
 
@@ -638,20 +641,17 @@ public class IGVCommandBar extends javax.swing.JPanel {
 
     }
 
-    public void updateGenome(String id) {
+    public void updateGenome(Genome genome) {
 
-        FeatureDB.clearFeatures();
-
-        // TODO -- this is all rather circular
-        Genome genome = IGV.getInstance().getGenomeManager().getCurrentGenome();
-
-        IGV.getInstance().getTrackManager().createGeneTrack(genome);
 
         FrameManager.getDefaultFrame().invalidateLocationScale();
 
         for (Chromosome chr : genome.getChromosomes()) {
-            for (Cytoband cyto : chr.getCytobands()) {
-                FeatureDB.addFeature(cyto.getLongName(), cyto);
+            final List<Cytoband> cytobands = chr.getCytobands();
+            if (cytobands != null) {
+                for (Cytoband cyto : cytobands) {
+                    FeatureDB.addFeature(cyto.getLongName(), cyto);
+                }
             }
         }
         updateChromosomeDropdown();
@@ -692,10 +692,6 @@ public class IGVCommandBar extends javax.swing.JPanel {
             list.add(UIConstants.GENOME_LIST_SEPARATOR);
         }
 
-        if (list.isEmpty()) {
-            list.add(IGV.getInstance().getGenomeManager().getDefaultGenomeListItem());
-        }
-
         return new DefaultComboBoxModel(list.toArray());
     }
 
@@ -778,7 +774,7 @@ public class IGVCommandBar extends javax.swing.JPanel {
         locationPanel.add(Box.createHorizontalStrut(5), JideBoxLayout.FIX);
 
         searchTextField = new SearchTextField();
-        searchTextField.setToolTipText("Enter a gene of locus, e.f. EGFR,   chr1,   or chr1:100,000-200,000");
+        searchTextField.setToolTipText("Enter a gene or locus, e.f. EGFR,   chr1,   or chr1:100,000-200,000");
         searchTextField.setMaximumSize(new java.awt.Dimension(250, 15));
         searchTextField.setMinimumSize(new java.awt.Dimension(100, 28));
         searchTextField.setPreferredSize(new java.awt.Dimension(230, 28));
