@@ -20,6 +20,9 @@ package org.broad.igv.ui;
 
 import org.apache.log4j.Logger;
 import org.broad.igv.PreferenceManager;
+import org.broad.igv.gs.GSOpenSessionMenuAction;
+import org.broad.igv.gs.GSSaveSessionMenuAction;
+import org.broad.igv.gs.GSUtils;
 import org.broad.igv.lists.GeneListManagerUI;
 import org.broad.igv.lists.VariantListManager;
 import org.broad.igv.tools.IgvToolsGui;
@@ -75,9 +78,9 @@ public class IGVMenuBar extends JMenuBar {
         menus.add(createFileMenu());
         menus.add(createViewMenu());
         menus.add(createTracksMenu());
-
+        menus.add(createGenomeSpaceMenu());
         extrasMenu = createExtrasMenu();
-        extrasMenu.setVisible(false);
+        //extrasMenu.setVisible(false);
         menus.add(extrasMenu);
 
         menus.add(createHelpMenu());
@@ -112,6 +115,11 @@ public class IGVMenuBar extends JMenuBar {
         menuAction = new LoadFromURLMenuAction(LoadFromURLMenuAction.LOAD_FROM_DAS, KeyEvent.VK_D, IGV.getInstance());
         menuItems.add(MenuAndToolbarUtils.createMenuItem(menuAction));
 
+        if(PreferenceManager.getInstance().getAsBoolean(PreferenceManager.DB_ENABLED)) {
+            menuAction = new LoadFromDatabaseAction("Load from Database...", 0, IGV.getInstance());
+            menuItems.add(MenuAndToolbarUtils.createMenuItem(menuAction));
+        }
+
         menuItems.add(new JSeparator());
 
         // Session menu items
@@ -430,8 +438,7 @@ public class IGVMenuBar extends JMenuBar {
                         if (w <= 0 || w == 1000) throw new NumberFormatException();
                         PreferenceManager.getInstance().put(PreferenceManager.NAME_PANEL_WIDTH, newValue);
                         mainPanel.setNamePanelWidth(w);
-                    }
-                    catch (NumberFormatException ex) {
+                    } catch (NumberFormatException ex) {
                         MessageUtils.showMessage("Error: value must be a positive integer < 1000.");
                     }
                 }
@@ -470,6 +477,21 @@ public class IGVMenuBar extends JMenuBar {
         menuAction.setToolTipText(SELECT_DISPLAYABLE_ATTRIBUTES_TOOLTIP);
         menuItems.add(MenuAndToolbarUtils.createMenuItem(menuAction));
 
+        menuAction = new MenuAction("Show Header Panel", null, KeyEvent.VK_A) {
+            @Override
+            public void actionPerformed(ActionEvent e) {
+
+                JCheckBoxMenuItem menuItem = (JCheckBoxMenuItem) e.getSource();
+                if (menuItem.isSelected()) {
+                    IGV.getInstance().getMainPanel().restoreHeader();
+                } else {
+                    IGV.getInstance().getMainPanel().removeHeader();
+                }
+                IGV.getInstance().doRefresh();
+            }
+        };
+        menuItems.add(MenuAndToolbarUtils.createMenuItem(menuAction, true));
+
         menuItems.add(new JSeparator());
         menuAction =
                 new MenuAction("Reorder Panels...", null, KeyEvent.VK_S) {
@@ -618,6 +640,37 @@ menuAction =
         return MenuAndToolbarUtils.createMenu(menuItems, toolMenuAction);
     }
 
+    private JMenu createGenomeSpaceMenu() {
+
+        JMenu menu = new JMenu("GenomeSpace");
+
+        MenuAction menuAction = null;
+        menuAction = new LoadFromGSMenuAction("Load from GenomeSpace...", KeyEvent.VK_U, IGV.getInstance());
+        menu.add(MenuAndToolbarUtils.createMenuItem(menuAction));
+
+        menu.addSeparator();
+
+        menuAction = new GSSaveSessionMenuAction("Save session to GenomeSpace...", IGV.getInstance());
+        menu.add(MenuAndToolbarUtils.createMenuItem(menuAction));
+
+        menuAction = new GSOpenSessionMenuAction("Load session from GenomeSpace...", IGV.getInstance());
+        menu.add(MenuAndToolbarUtils.createMenuItem(menuAction));
+
+        menu.add(new JSeparator());
+        menuAction = new MenuAction("Logout") {
+            @Override
+            public void actionPerformed(ActionEvent e) {
+                GSUtils.logout();
+            }
+        };
+        menu.add(MenuAndToolbarUtils.createMenuItem(menuAction));
+
+        menu.setVisible(PreferenceManager.getInstance().getAsBoolean(PreferenceManager.GENOME_SPACE_ENABLE));
+
+
+        return menu;
+    }
+
     private JMenu createExtrasMenu() {
 
         List<JComponent> menuItems = new ArrayList<JComponent>();
@@ -803,7 +856,7 @@ menuAction =
 
             // Hide and close the application
             IGV.getMainFrame().setVisible(false);
-            IGV.getMainFrame().dispose(); 
+            IGV.getMainFrame().dispose();
 
         } finally {
             System.exit(0);
