@@ -1,19 +1,19 @@
 /*
- * Copyright (c) 2007-2010 by The Broad Institute, Inc. and the Massachusetts Institute of Technology.
- * All Rights Reserved.
+ * Copyright (c) 2007-2011 by The Broad Institute of MIT and Harvard.  All Rights Reserved.
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL), Version 2.1 which
- * is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
+ * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
  *
- * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR WARRANTIES OF
- * ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING, WITHOUT LIMITATION, WARRANTIES
- * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT
- * OR OTHER DEFECTS, WHETHER OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR
- * RESPECTIVE TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES OF
- * ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES, ECONOMIC
- * DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER THE BROAD OR MIT SHALL
- * BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT SHALL KNOW OF THE POSSIBILITY OF THE
- * FOREGOING.
+ * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR
+ * WARRANTES OF ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING,
+ * WITHOUT LIMITATION, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
+ * PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT OR OTHER DEFECTS, WHETHER
+ * OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR RESPECTIVE
+ * TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES
+ * OF ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES,
+ * ECONOMIC DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER
+ * THE BROAD OR MIT SHALL BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT
+ * SHALL KNOW OF THE POSSIBILITY OF THE FOREGOING.
  */
 
 /*
@@ -23,10 +23,11 @@
 package org.broad.igv.ui.action;
 
 import org.apache.log4j.Logger;
+import org.broad.igv.Globals;
 import org.broad.igv.PreferenceManager;
-import org.broad.igv.ui.IGVMainFrame;
-import org.broad.igv.ui.RegionOfInterest;
-import org.broad.igv.ui.UIConstants;
+import org.broad.igv.feature.RegionOfInterest;
+import org.broad.igv.ui.IGV;
+import org.broad.igv.ui.panel.RegionNavigatorDialog;
 import org.broad.igv.ui.util.FileChooser;
 import org.broad.igv.ui.util.MessageUtils;
 
@@ -44,7 +45,7 @@ public class RegionsBaseMenuAction extends MenuAction {
 
     static Logger log = Logger.getLogger(RegionsBaseMenuAction.class);
 
-    IGVMainFrame mainFrame;
+    IGV mainFrame;
 
     protected enum Direction {
 
@@ -59,9 +60,17 @@ public class RegionsBaseMenuAction extends MenuAction {
     }
 
     public final void importExportRegionsOfInterest(Direction direction) {
+        //dhmay adding 20110505: There was an intermittent bug in which the regions list was not getting
+        //synched when the user made changes to the regions table in the region navigator dialog.  I'm addressing
+        //this with a change to RegionNavigatorDialog, but, due to the intermittent nature of the bug, I'm adding
+        //a catchall here, too.  This synchs everything from the nav dialog.
+        RegionNavigatorDialog navDialog = RegionNavigatorDialog.getActiveInstance();
+        if (navDialog != null)
+            navDialog.updateROIsFromRegionTable();
+
         File exportRegionDirectory = PreferenceManager.getInstance().getLastExportedRegionDirectory();
         if (exportRegionDirectory == null) {
-            exportRegionDirectory = new File(UIConstants.getDefaultUserDirectory());
+            exportRegionDirectory = Globals.getUserDirectory();
         }
 
         FileChooser exportedRegionFileChooser = new FileChooser(exportRegionDirectory);
@@ -99,18 +108,34 @@ public class RegionsBaseMenuAction extends MenuAction {
         }
         try {
             BufferedReader reader = null;
+            int coordConvention = 0;
+
             try {
                 reader = new BufferedReader(new FileReader(roiFile));
                 while (true) {
                     String dataRecord = reader.readLine();
                     if (dataRecord == null) {
                         return;
+                    } else if (dataRecord.startsWith("track")) {
+                        // Skip track line
+                        continue;
+                    } else if (dataRecord.startsWith("#coords")) {
+                        String[] tmp = dataRecord.split("=");
+                        if (tmp.length > 1) {
+                            try {
+                                coordConvention = Integer.parseInt(tmp[1]);
+                            } catch (NumberFormatException e) {
+                                log.error("Error parsing coordinate convention direction for file: " + roiFile);
+                            }
+                        }
                     }
                     String[] data = dataRecord.split("\t");
                     if (data.length >= 3) {
                         try {
                             String name = data.length > 3 ? data[3] : null;
-                            RegionOfInterest regionOfInterest = new RegionOfInterest(data[0], Integer.parseInt(data[1]), Integer.parseInt(data[2]), name);
+                            int start = Integer.parseInt(data[1]) - coordConvention;
+                            int end = Integer.parseInt(data[2]);
+                            RegionOfInterest regionOfInterest = new RegionOfInterest(data[0],start, end, name);
                             mainFrame.addRegionOfInterest(regionOfInterest);
                         } catch (NumberFormatException numberFormatException) {
                         }
@@ -134,9 +159,9 @@ public class RegionsBaseMenuAction extends MenuAction {
 
         // Display the dialog
         if (isSave) {
-            exportedRegionFileChooser.showSaveDialog(mainFrame);
+            exportedRegionFileChooser.showSaveDialog(mainFrame.getMainFrame());
         } else {
-            exportedRegionFileChooser.showOpenDialog(mainFrame);
+            exportedRegionFileChooser.showOpenDialog(mainFrame.getMainFrame());
         }
 
         mainFrame.resetStatusMessage();
@@ -158,7 +183,7 @@ public class RegionsBaseMenuAction extends MenuAction {
             return;
         }
         try {
-            Collection<RegionOfInterest> regions = IGVMainFrame.getInstance().getSession().getAllRegionsOfInterest();
+            Collection<RegionOfInterest> regions = IGV.getInstance().getSession().getAllRegionsOfInterest();
 
             if (regions == null || regions.isEmpty()) {
                 return;
@@ -190,8 +215,7 @@ public class RegionsBaseMenuAction extends MenuAction {
                     if (regionOfInterest.getDescription() != null) {
                         writer.print("\t");
                         writer.println(regionOfInterest.getDescription());
-                    }
-                    else {
+                    } else {
                         writer.println();
                     }
                 }
