@@ -1,19 +1,19 @@
 /*
- * Copyright (c) 2007-2010 by The Broad Institute, Inc. and the Massachusetts Institute of Technology.
- * All Rights Reserved.
+ * Copyright (c) 2007-2011 by The Broad Institute of MIT and Harvard.  All Rights Reserved.
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL), Version 2.1 which
- * is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
+ * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
  *
- * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR WARRANTIES OF
- * ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING, WITHOUT LIMITATION, WARRANTIES
- * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT
- * OR OTHER DEFECTS, WHETHER OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR
- * RESPECTIVE TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES OF
- * ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES, ECONOMIC
- * DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER THE BROAD OR MIT SHALL
- * BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT SHALL KNOW OF THE POSSIBILITY OF THE
- * FOREGOING.
+ * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR
+ * WARRANTES OF ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING,
+ * WITHOUT LIMITATION, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
+ * PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT OR OTHER DEFECTS, WHETHER
+ * OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR RESPECTIVE
+ * TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES
+ * OF ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES,
+ * ECONOMIC DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER
+ * THE BROAD OR MIT SHALL BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT
+ * SHALL KNOW OF THE POSSIBILITY OF THE FOREGOING.
  */
 /*
  * To change this template, choose Tools | Templates
@@ -26,13 +26,31 @@ package org.broad.igv.ui.action;
 import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
 import org.broad.igv.PreferenceManager;
-import org.broad.igv.feature.Chromosome;
-import org.broad.igv.feature.Feature;
-import org.broad.igv.feature.FeatureDB;
-import org.broad.igv.session.ViewContext;
-import org.broad.igv.ui.IGVMainFrame;
+import org.broad.igv.feature.*;
+import org.broad.igv.feature.genome.Genome;
+import org.broad.igv.feature.genome.GenomeManager;
+import org.broad.igv.lists.GeneList;
+import org.broad.igv.session.Session;
+import org.broad.igv.ui.panel.FrameManager;
+import org.broad.igv.ui.panel.ReferenceFrame;
+import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.util.MessageUtils;
 
+import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.List;
+
+/**
+ * A class for performing search actions.  The class takes a view context and
+ * search string as parameters.   The search string can be either
+ * (a) a feature (e.g. gene),  or
+ * (b) a locus string in the UCSC form,  e.g. chr1:100,000-200,000
+ * <p/>
+ * Note:  Currently the only recognized features are genes
+ *
+ * @author jrobinso
+ */
+
 /**
  * A class for performing search actions.  The class takes a view context and
  * search string as parameters.   The search string can be either
@@ -48,16 +66,18 @@ public class SearchCommand implements Command {
     private static Logger log = Logger.getLogger(SearchCommand.class);
 
     String searchString;
-    ViewContext viewContext;
+    ReferenceFrame referenceFrame;
     boolean recordHistory = true;
+    Genome genome;
 
-    public SearchCommand(ViewContext viewContext, String searchString) {
-        this.viewContext = viewContext;
+    public SearchCommand(ReferenceFrame referenceFrame, String searchString) {
+        this.referenceFrame = referenceFrame;
         this.searchString = searchString.trim();
+        genome = IGV.getInstance().getGenomeManager().getCurrentGenome();
     }
 
-    public SearchCommand(ViewContext viewContext, String searchString, boolean recordHistory) {
-        this(viewContext, searchString);
+    public SearchCommand(ReferenceFrame referenceFrame, String searchString, boolean recordHistory) {
+        this(referenceFrame, searchString);
         this.recordHistory = recordHistory;
     }
 
@@ -72,33 +92,86 @@ public class SearchCommand implements Command {
 
         // Space delimited?
         String[] tokens = searchString.split("\\s+");
-        if (tokens.length == 3) {
-            String chr = tokens[0];
-            int start = Integer.parseInt(tokens[1]) - 1; // Convert to UCSC convention
-            int end = Integer.parseInt(tokens[2]);
-            viewContext.jumpTo(chr, start, end);
-            success = true;
+        if (tokens.length >= 2) {
+            String chr = genome.getChromosomeAlias(tokens[0].trim());
+            try {
+                int start = Integer.parseInt(tokens[1].trim()) - 1; // Convert to UCSC convention
+                int end = start + 1;
+                if (tokens.length > 2) {
+                    end = Integer.parseInt(tokens[2].trim());
+                }
+
+                if(FrameManager.isGeneListMode()) {
+                    IGV.getInstance().getSession().setCurrentGeneList(null);
+                    IGV.getInstance().resetFrames();
+                }
+
+                if (recordHistory) {
+                    IGV.getInstance().getSession().getHistory().push(searchString, referenceFrame.getZoom());
+                }
+                referenceFrame.jumpTo(chr, start, end);
+                success = true;
+            } catch (NumberFormatException e) {
+                // Multiple tokens, On the fly gene list ?
+
+                List<String> loci = new ArrayList<String>(tokens.length);
+                for (String t : tokens) {
+                    Locus l = new Locus(t);
+                    if (l.isValid()) {
+                        loci.add(t);
+                    } else if (FeatureDB.getFeature(t) != null) {
+                        loci.add(t);
+                    }
+                }
+
+                if (loci.size() <= 1) {
+                    //MessageUtils.showMessage("Invalid search string: " + searchString);
+                    success = false;
+                } else {
+                    if (loci.size() != tokens.length) {
+                        MessageUtils.showMessage("Not all portions of the search string are recognized as genes or loci.");
+                    }
+                    GeneList geneList = new GeneList("", loci, false);
+                    IGV.getInstance().getSession().setCurrentGeneList(geneList);
+                    IGV.getInstance().resetFrames();
+                    success = true;
+
+                }
+
+            }
+
         }
 
         // Feature search
 
         else {
-            Feature feature = FeatureDB.getFeature(searchString.toUpperCase().trim());
-            if (feature != null) {
-                int start = Math.max(0, feature.getStart());
-                int end = feature.getEnd();
 
-                if (PreferenceManager.getInstance().getBooleanPreference(PreferenceManager.SEARCH_ZOOM, true)) {
-                    viewContext.jumpTo(feature.getChr(), start, end);
+            if(FrameManager.isGeneListMode()) {
+                IGV.getInstance().getSession().setCurrentGeneList(null);
+                IGV.getInstance().resetFrames();
+            }
+
+            NamedFeature feature = FeatureDB.getFeature(searchString.toUpperCase().trim());
+            if (feature != null) {
+                int flankingRegion = PreferenceManager.getInstance().getAsInt(PreferenceManager.FLANKING_REGION);
+                int start = Math.max(0, feature.getStart() - flankingRegion);
+                int end = feature.getEnd() + flankingRegion;
+
+                if (recordHistory) {
+                    IGV.getInstance().getSession().getHistory().push(searchString, referenceFrame.getZoom());
+                }
+                if (PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SEARCH_ZOOM)) {
+                    referenceFrame.jumpTo(feature.getChr(), start, end);
                 } else {
                     int center = (start + end) / 2;
-                    viewContext.centerOnLocation(feature.getChr(), center);
+                    referenceFrame.centerOnLocation(feature.getChr(), center);
                 }
 
                 if (log.isDebugEnabled()) {
                     log.debug("End search: " + searchString);
                 }
                 success = true;
+
             }
 
 
@@ -107,17 +180,21 @@ public class SearchCommand implements Command {
             else if (!searchString.contains("\"")) {
                 String chr = null;
                 int[] startEnd = null;
-                int colon = searchString.indexOf(":");
+                int colonIdx = searchString.lastIndexOf(":");
 
-                if (colon > 0) {
+                if (colonIdx > 0) {
 
                     // The chromosome is that portion of the search string up to the colon.
-                    chr = searchString.substring(0, colon);
-                    String posString = searchString.substring(colon).replace(":", "");
+                    chr = genome.getChromosomeAlias(searchString.substring(0, colonIdx));
+                    String posString = searchString.substring(colonIdx).replace(":", "");
                     startEnd = getStartEnd(posString);
 
                     if (startEnd != null) {
-                        viewContext.jumpTo(chr, startEnd[0], startEnd[1]);
+                        if (recordHistory) {
+                            IGV.getInstance().getSession().getHistory().push(searchString, referenceFrame.getZoom());
+                        }
+
+                        referenceFrame.jumpTo(chr, startEnd[0], startEnd[1]);
 
                         if (log.isDebugEnabled()) {
                             log.debug("End search: " + searchString);
@@ -133,7 +210,11 @@ public class SearchCommand implements Command {
                         // Presense of a dash indicates this is a locus string in the current chromosome
                         startEnd = getStartEnd(searchString);
                         if (startEnd != null) {
-                            viewContext.jumpTo(null, startEnd[0], startEnd[1]);
+                            if (recordHistory) {
+                                IGV.getInstance().getSession().getHistory().push(searchString, referenceFrame.getZoom());
+                            }
+
+                            referenceFrame.jumpTo(null, startEnd[0], startEnd[1]);
 
                             if (log.isDebugEnabled()) {
                                 log.debug("End search: " + searchString);
@@ -144,18 +225,21 @@ public class SearchCommand implements Command {
                     } else {
 
                         // No dash, this is either a chromosome or an unkown search string
-                        Chromosome chromosome = viewContext.getGenome().getChromosome(searchString);
-                        if (chromosome != null || searchString.startsWith(Globals.CHR_ALL)) {
-                            viewContext.setChromosomeName(searchString, true);
-                            IGVMainFrame.getInstance().repaintDataAndHeaderPanels();
-                            IGVMainFrame.getInstance().repaintStatusAndZoomSlider();
-                            
+                        chr = genome.getChromosomeAlias(searchString);
+                        Chromosome chromosome = genome.getChromosome(chr);
+                        if (chromosome != null || searchString.equals(Globals.CHR_ALL)) {
+                            if (recordHistory) {
+                                IGV.getInstance().getSession().getHistory().push(chr, referenceFrame.getZoom());
+                            }
+
+                            referenceFrame.setChromosomeName(chr, true);
+                            IGV.getInstance().repaintDataAndHeaderPanels();
+                            IGV.getInstance().repaintStatusAndZoomSlider();
 
                             if (log.isDebugEnabled()) {
                                 log.debug("End search: " + searchString);
                             }
                             success = true;
-                            ;
                         }
 
                     }
@@ -164,12 +248,8 @@ public class SearchCommand implements Command {
         }
 
 
-        if (success) {
-           if(recordHistory) {
-               viewContext.history.push(searchString);
-           }
-        } else {
-            if (!IGVMainFrame.getInstance().scrollToTrack(searchString.replaceAll("\"", ""))) {
+        if (!success) {
+            if (!IGV.getInstance().scrollToTrack(searchString.replaceAll("\"", ""))) {
                 showError("Cannot find feature or locus: " + searchString);
             }
         }
