@@ -57,17 +57,16 @@ public class DataPanel extends JComponent implements Paintable {
     private boolean isWaitingForToolTipText = false;
 
 
-
-
     // TODO move this to some central place
     final static private boolean IS_MAC = System.getProperty("os.name").toLowerCase().startsWith("mac");
 
     private DataPanelTool defaultTool;
     private DataPanelTool currentTool;
-    private Point tooltipTextPosition;
+    // private Point tooltipTextPosition;
     private ReferenceFrame frame;
     DataPanelContainer parent;
     private DataPanelPainter painter;
+    private String tooltipText = "";
 
 
     public DataPanel(ReferenceFrame frame, DataPanelContainer parent) {
@@ -81,6 +80,8 @@ public class DataPanel extends JComponent implements Paintable {
         setToolTipText("");
         painter = new DataPanelPainter();
         setBackground(PreferenceManager.getInstance().getAsColor(PreferenceManager.BACKGROUND_COLOR));
+
+        ToolTipManager.sharedInstance().registerComponent(this);
     }
 
 
@@ -106,7 +107,7 @@ public class DataPanel extends JComponent implements Paintable {
 
     @Override
     public void paintComponent(final Graphics g) {
-        
+
         super.paintComponent(g);
         RenderContext context = null;
         try {
@@ -140,10 +141,10 @@ public class DataPanel extends JComponent implements Paintable {
 
             int trackWidth = getWidth();
             int trackHeight = getHeight();
-            painter.paint(groups, context, trackWidth, trackHeight, getBackground(), damageRect);
 
-            // Compute mouse senstive regions
-            computeMousableRegions(groups);
+
+            computeMousableRegions(groups, trackWidth);
+            painter.paint(groups, context, trackWidth, trackHeight, getBackground(), damageRect);
 
 
             // If there is a partial ROI in progress draw it first
@@ -167,6 +168,43 @@ public class DataPanel extends JComponent implements Paintable {
         }
     }
 
+    /**
+     * TODO -- move this to a "layout" command, to layout tracks and assign positions
+     */
+    private void computeMousableRegions(Collection<TrackGroup> groups, int width) {
+
+        final List<MouseableRegion> mouseableRegions = parent.getMouseRegions();
+        mouseableRegions.clear();
+        int trackX = 0;
+        int trackY = 0;
+        for (Iterator<TrackGroup> groupIter = groups.iterator(); groupIter.hasNext(); ) {
+            TrackGroup group = groupIter.next();
+
+
+            if (group.isVisible()) {
+                if (groups.size() > 1) {
+                    trackY += UIConstants.groupGap;
+                }
+
+                List<Track> trackList = group.getTracks();
+                for (Track track : trackList) {
+                    if (track == null) continue;
+                    int trackHeight = track.getHeight();
+
+                    if (track.isVisible()) {
+                        Rectangle rect = new Rectangle(trackX, trackY, width, trackHeight);
+                        if (mouseableRegions != null) {
+                            mouseableRegions.add(new MouseableRegion(rect, track));
+                        }
+                        trackY += trackHeight;
+                    }
+                }
+
+            }
+        }
+
+    }
+
     /**
      * Paint method designed to paint to an offscreen image
      *
@@ -187,6 +225,8 @@ public class DataPanel extends JComponent implements Paintable {
             int height = rect.height;
             painter.paint(groups, context, width, height, getBackground(), rect);
 
+            drawAllRegions(g);
+
             super.paintBorder(g);
 
         } finally {
@@ -258,46 +298,6 @@ public class DataPanel extends JComponent implements Paintable {
         return key;
     }
 
-    /**
-     * TODO -- it is assumed the tracks are drawn in the same order for the
-     * image.  This is brittle, the rects could be computed when the image
-     * is drawn.  Really the y position and height are all that is needed.
-     *
-     * @param groups
-     */
-    private void computeMousableRegions(Collection<TrackGroup> groups) {
-
-        removeMousableRegions();
-
-        int trackX = 0;
-        int trackY = 0;
-
-        for (Iterator<TrackGroup> groupIter = groups.iterator(); groupIter.hasNext();) {
-            TrackGroup group = groupIter.next();
-
-            if (groups.size() > 1) {
-                trackY += UIConstants.groupGap;
-            }
-            for (Track track : group.getTracks()) {
-                if (track == null) continue;
-                if (track.isVisible()) {
-
-                    int trackWidth = getWidth();
-                    int trackHeight = track.getHeight();
-
-                    Rectangle actualAreaOnDataPanel = new Rectangle(trackX,
-                            trackY, (trackWidth),
-                            (trackHeight));
-
-                    addMousableRegion(new MouseableRegion(actualAreaOnDataPanel, track));
-
-                    trackY += trackHeight;
-                }
-            }
-        }
-
-    }
-
 
     /**
      * Do not remove - Used for debugging only
@@ -346,7 +346,7 @@ public class DataPanel extends JComponent implements Paintable {
      * @return
      */
     public Track getTrack(int x, int y) {
-        for (MouseableRegion mouseRegion : parent.getTrackRegions()) {
+        for (MouseableRegion mouseRegion : parent.getMouseRegions()) {
             if (mouseRegion.containsPoint(x, y)) {
                 return mouseRegion.getTracks().iterator().next();
             }
@@ -355,94 +355,86 @@ public class DataPanel extends JComponent implements Paintable {
 
     }
 
+
+    @Override
+    public void setToolTipText(String text) {
+        if (!tooltipText.equals(text)) {
+            IGV.getInstance().setStatusWindowText(text);
+            this.tooltipText = text;
+            putClientProperty(TOOL_TIP_TEXT_KEY, text);
+        }
+
+    }
+
+    @Override
+    final public String getToolTipText() {
+        if (IGV.getInstance().isSuppressTooltip() || currentTool instanceof RegionOfInterestTool) {
+            return "";
+        }
+        return tooltipText;
+    }
+
+
     /**
      * Method description
-     *
-     * @param x
-     * @param y
      */
-    public void updateTooltipText(int x, int y) {
+    public void updateTooltipText(int x, int y, String positionString) {
+
         double location = frame.getChromosomePosition(x);
         double displayLocation = location + 1;
 
         Track track = null;
-        List<MouseableRegion> regions = parent.getTrackRegions();
+        List<MouseableRegion> regions = parent.getMouseRegions();
         StringBuffer popupTextBuffer = new StringBuffer();
+        popupTextBuffer.append("<html>");
         for (MouseableRegion mouseRegion : regions) {
             if (mouseRegion.containsPoint(x, y)) {
                 track = mouseRegion.getTracks().iterator().next();
                 if (track != null) {
 
-                    // Calculate y relative to track bounds
-                    //int yRelative = y - mouseRegion.getBounds().y;
-
                     // First see if there is an overlay track.  If there is, give
                     // it first crack
                     List<Track> overlays = IGV.getInstance().getTrackManager().getOverlayTracks(track);
-
+                    boolean foundOverlaidFeature = false;
                     if (overlays != null) {
                         for (Track overlay : overlays) {
                             if ((overlay != track) && (overlay.getValueStringAt(
                                     frame.getChrName(), displayLocation, y, frame) != null)) {
-                                popupTextBuffer.append(getPopUpText(overlay, displayLocation, y));
-                                popupTextBuffer.append("<br>");
+                                String valueString = overlay.getValueStringAt(frame.getChrName(), displayLocation, y, frame);
+                                if (valueString != null) {
+                                    popupTextBuffer.append(valueString);
+                                    popupTextBuffer.append("<br>");
+                                    foundOverlaidFeature = true;
+                                    break;
+                                }
                             }
                         }
                     }
-
-                    popupTextBuffer.append(getPopUpText(track, displayLocation, y));
+                    String valueString = track.getValueStringAt(frame.getChrName(), displayLocation, y, frame);
+                    if (valueString != null) {
+                        if(foundOverlaidFeature) {
+                            popupTextBuffer.append("---------------------<br>");
+                        }
+                        popupTextBuffer.append(valueString);
+                        popupTextBuffer.append("<br>");
+                        break;
+                    }
                 }
-                break;
             }
         }
 
-        String puText = popupTextBuffer.toString().trim();
-        if (puText.length() > 0) {
-            if (!puText.equals(getToolTipText())) {
-                setToolTipText("<html>" + puText);
+        if (popupTextBuffer.length() > 6) {   // 6 characters for <html>
+            //popupTextBuffer.append("<br>--------------------------");
+            //popupTextBuffer.append(positionString);
+            String puText = popupTextBuffer.toString().trim();
+            if (!puText.equals(tooltipText)) {
+                setToolTipText(puText);
             }
         } else {
-            setToolTipText(null);
+            setToolTipText("");
         }
     }
 
-    @Override
-    final public String getToolTipText() {
-
-        if (IGV.getInstance().isSuppressTooltip() || currentTool instanceof RegionOfInterestTool) {
-            return "";
-        }
-
-        if (!isWaitingForToolTipText) {
-            try {
-                isWaitingForToolTipText = true;
-                if (tooltipTextPosition != null) {
-                    updateTooltipText(tooltipTextPosition.x, tooltipTextPosition.y);
-                }
-            } finally {
-                isWaitingForToolTipText = false;
-            }
-
-        }
-        return super.getToolTipText();
-    }
-
-    /**
-     * @param track
-     * @param location in genomic coordinates
-     * @param y        pixel position in panel coordinates
-     * @return
-     */
-    String getPopUpText(Track track, double location, int y) {
-
-        StringBuffer buf = new StringBuffer();
-        String value = track.getValueStringAt(frame.getChrName(), location, y, frame);
-        if (value != null) {
-            buf.append(value);
-        }
-        return buf.toString();
-    }
-
 
     private void init() {
         setBorder(javax.swing.BorderFactory.createLineBorder(new java.awt.Color(0, 0, 0)));
@@ -529,12 +521,8 @@ public class DataPanel extends JComponent implements Paintable {
 
     }
 
-    protected void addMousableRegion(MouseableRegion region) {
-        parent.addMousableRegion(region);
-    }
-
     protected void removeMousableRegions() {
-        parent.getTrackRegions().clear();
+        parent.getMouseRegions().clear();
     }
 
     public ReferenceFrame getFrame() {
@@ -565,12 +553,14 @@ public class DataPanel extends JComponent implements Paintable {
 
         @Override
         public void mouseMoved(MouseEvent e) {
-            tooltipTextPosition = e.getPoint();
+            String position = null;
             if (!frame.getChrName().equals(Globals.CHR_ALL)) {
                 int location = (int) frame.getChromosomePosition(e.getX()) + 1;
-                String position = frame.getChrName() + ":" + locationFormatter.format(location);
+                position = frame.getChrName() + ":" + locationFormatter.format(location);
                 IGV.getInstance().setStatusBarMessage(position);
             }
+            updateTooltipText(e.getX(), e.getY(), position);
+
         }
 
         /**
@@ -705,4 +695,28 @@ public class DataPanel extends JComponent implements Paintable {
             }
         }
     }
+
+    /**
+     * A utility class for sceduling single-click actions "in the future",
+     *
+     * @author jrobinso
+     * @date Dec 17, 2010
+     */
+    public class PopupTextUpdater {
+
+        private TimerTask currentClickTask;
+
+        public void cancelClickTask() {
+            if (currentClickTask != null) {
+                currentClickTask.cancel();
+                currentClickTask = null;
+            }
+        }
+
+        public void scheduleUpdateTask(TimerTask task) {
+            cancelClickTask();
+            currentClickTask = task;
+            (new java.util.Timer()).schedule(currentClickTask, UIConstants.getDoubleClickInterval());
+        }
+    }
 }
\ No newline at end of file
