@@ -44,7 +44,7 @@ public class DataPanelPainter {
 
     private static Logger log = Logger.getLogger(DataPanelPainter.class);
 
-    public void paint(Collection<TrackGroup> groups,
+    public synchronized void paint(Collection<TrackGroup> groups,
                       RenderContext context,
                       int width,
                       int height,
@@ -85,7 +85,7 @@ public class DataPanelPainter {
 
                     List<Track> trackList = group.getTracks();
                     for (Track track : trackList) {
-                        if(track == null) continue;
+                        if (track == null) continue;
                         int trackHeight = track.getHeight();
                         if (visibleRect != null) {
                             if (trackY > visibleRect.y + visibleRect.height) {
@@ -100,7 +100,9 @@ public class DataPanelPainter {
 
 
                         if (track.isVisible()) {
-                            trackY = draw(track, trackX, trackY, width, trackHeight, context);
+                            Rectangle rect = new Rectangle(trackX, trackY, width, trackHeight);
+                            draw(track, rect, context);
+                            trackY += trackHeight;
                         }
                     }
 
@@ -111,7 +113,7 @@ public class DataPanelPainter {
                 }
             }
         }
-        catch(RuntimeException e) {
+        catch (RuntimeException e) {
             log.error(e);
             throw e;
         }
@@ -120,12 +122,7 @@ public class DataPanelPainter {
         }
     }
 
-    final private int draw(Track track, int trackX, int trackY, int trackWidth, int trackHeight, RenderContext context) {
-
-
-        // The rectangle in which the track is drawn.  The height is reduced
-        Rectangle rect = new Rectangle(trackX, trackY, trackWidth, trackHeight);
-
+    final private void draw(Track track, Rectangle rect, RenderContext context) {
 
         track.render(context, rect);
 
@@ -142,10 +139,5 @@ public class DataPanelPainter {
             }
         }
 
-        // Change Y to point to the start of the next track
-        trackY += trackHeight;
-
-        return trackY;
-
     }
 }
