@@ -20,8 +20,7 @@ package org.broad.igv.ui.panel;
 
 import org.apache.log4j.Logger;
 import org.broad.igv.feature.RegionOfInterest;
-import org.broad.igv.feature.SequenceManager;
-import org.broad.igv.feature.genome.GenomeManager;
+import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.util.MessageUtils;
 
@@ -265,21 +264,22 @@ public class RegionNavigatorDialog extends JDialog implements Observer {
             if (firstRow > regions.size() - 1)
                 return;
             //update all rows affected
-            for (int i=firstRow; i<=Math.max(firstRow, Math.min(regionTable.getRowCount(), e.getLastRow())); i++)
+            for (int i = firstRow; i <= Math.max(firstRow, Math.min(regionTable.getRowCount(), e.getLastRow())); i++)
                 updateROIFromRegionTable(i);
         }
     }
-    
+
     /**
      * Updates all ROIs with the values currently stored in the region table
      */
     public void updateROIsFromRegionTable() {
-        for (int i=0; i<regionTable.getRowSorter().getModelRowCount(); i++)
+        for (int i = 0; i < regionTable.getRowSorter().getModelRowCount(); i++)
             updateROIFromRegionTable(i);
     }
 
     /**
      * Updates a single ROI with the values currently stored in the region table
+     *
      * @param tableRow: the viewable index of the table row
      */
     public void updateROIFromRegionTable(int tableRow) {
@@ -293,8 +293,7 @@ public class RegionNavigatorDialog extends JDialog implements Observer {
 
         try {
             rowIdx = regionTable.getRowSorter().convertRowIndexToModel(tableRow);
-        }
-        catch (ArrayIndexOutOfBoundsException x) {
+        } catch (ArrayIndexOutOfBoundsException x) {
             return;
         }
 
@@ -410,23 +409,25 @@ public class RegionNavigatorDialog extends JDialog implements Observer {
 
                     //---- regionTable ----
                     regionTable.setModel(new DefaultTableModel(
-                        new Object[][] {
-                            {null, null, null, null},
-                        },
-                        new String[] {
-                            "Chr", "Start", "End", "Description"
-                        }
+                            new Object[][]{
+                                    {null, null, null, null},
+                            },
+                            new String[]{
+                                    "Chr", "Start", "End", "Description"
+                            }
                     ) {
-                        Class<?>[] columnTypes = new Class<?>[] {
-                            String.class, Integer.class, Integer.class, Object.class
+                        Class<?>[] columnTypes = new Class<?>[]{
+                                String.class, Integer.class, Integer.class, Object.class
                         };
-                        boolean[] columnEditable = new boolean[] {
-                            false, true, true, true
+                        boolean[] columnEditable = new boolean[]{
+                                false, true, true, true
                         };
+
                         @Override
                         public Class<?> getColumnClass(int columnIndex) {
                             return columnTypes[columnIndex];
                         }
+
                         @Override
                         public boolean isCellEditable(int rowIndex, int columnIndex) {
                             return columnEditable[columnIndex];
@@ -556,17 +557,22 @@ public class RegionNavigatorDialog extends JDialog implements Observer {
 
         public void actionPerformed(ActionEvent e) {
             String chr = FrameManager.getDefaultFrame().getChrName();
-            if (chr == null || chr.isEmpty())
+            if (FrameManager.isGeneListMode()) {
+                JOptionPane.showMessageDialog(IGV.getMainFrame(),
+                        "Regions cannot be created in gene list or split-screen views.",
+                        "Error", JOptionPane.INFORMATION_MESSAGE);
+
+            } else if (chr == null || chr.isEmpty()) {
                 JOptionPane.showMessageDialog(IGV.getMainFrame(),
                         "No chromosome is specified. Can't create a region without a chromosome.",
                         "Error", JOptionPane.INFORMATION_MESSAGE);
-            else if (chr.equalsIgnoreCase("All"))
+            } else if (chr.equalsIgnoreCase("All")) {
                 JOptionPane.showMessageDialog(IGV.getMainFrame(),
                         "Regions cannot be created in the All Chromosomes view.",
                         "Error", JOptionPane.INFORMATION_MESSAGE);
-            else {
-                RegionOfInterest newRegion = new RegionOfInterest(FrameManager.getDefaultFrame().getChrName(),
-                        1, 100, "");
+            } else {
+                ReferenceFrame.Range r = FrameManager.getDefaultFrame().getCurrentRange();
+                RegionOfInterest newRegion = new RegionOfInterest(r.getChr(), r.getStart(), r.getEnd(), "");
                 IGV.getInstance().getSession().addRegionOfInterestWithNoListeners(newRegion);
             }
         }
@@ -650,8 +656,8 @@ public class RegionNavigatorDialog extends JDialog implements Observer {
                             } else {
                                 try {
                                     setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
-                                    String genomeId = IGV.getInstance().getGenomeManager().getGenomeId();
-                                    byte[] seqBytes = SequenceManager.readSequence(genomeId, chr, start, end);
+                                    Genome genome = IGV.getInstance().getGenomeManager().getCurrentGenome();
+                                    byte[] seqBytes = genome.getSequence(chr, start, end);
                                     if (seqBytes == null) {
                                         MessageUtils.showMessage("Sequence not available");
                                     } else {
