@@ -31,7 +31,6 @@ import org.broad.igv.PreferenceManager;
 import org.broad.igv.track.Track;
 import org.broad.igv.track.TrackClickEvent;
 import org.broad.igv.track.TrackGroup;
-import org.broad.igv.ui.FontManager;
 import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.UIConstants;
 import org.broad.igv.ui.dnd.AbstractGhostDropManager;
@@ -115,7 +114,7 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
 
             Rectangle clipRect = g.getClipBounds();
 
-            for (Iterator<TrackGroup> groupIter = groups.iterator(); groupIter.hasNext();) {
+            for (Iterator<TrackGroup> groupIter = groups.iterator(); groupIter.hasNext(); ) {
                 TrackGroup group = groupIter.next();
 
                 if (regionY > clipRect.getMaxY()) {
@@ -135,15 +134,14 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
                         g.drawLine(0, regionY - 1, getWidth(), regionY - 1);
                     }
 
-                    int y = regionY;
-                    regionY = printTrackNames(group, visibleRect, clipRect, graphics2D, 0, regionY);
+                    int h = group.getHeight();
+                    Rectangle groupRect = new Rectangle(visibleRect.x, regionY, visibleRect.width, h);
+                    regionY = printTrackNames(group, groupRect, clipRect, graphics2D, 0, regionY);
 
                     if (isGrouped) {
-                        int h = group.getHeight();
-                        groupExtents.add(new GroupExtent(group, y, y + h));
+                        groupExtents.add(new GroupExtent(group, groupRect.y, groupRect.y + groupRect.height));
                         if (showGroupNames) {
-                            Rectangle rect = new Rectangle(visibleRect.x, y, visibleRect.width, h);
-                            Rectangle displayableRect = getDisplayableRect(rect, visibleRect);
+                            Rectangle displayableRect = getDisplayableRect(groupRect, visibleRect);
                             group.renderName(graphics2D, displayableRect, group == selectedGroup);
                         }
                     }
@@ -182,7 +180,7 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
 
         for (Track track : tmp) {
             if (track == null) continue;
-            track.setTop(regionY);
+            track.setY(regionY);
             int trackHeight = track.getHeight();
             if (track.isVisible()) {
 
@@ -199,9 +197,8 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
                         if (track.isSelected()) {
                             graphics2D.setBackground(Color.LIGHT_GRAY);
                             graphics2D.clearRect(rect.x, rect.y, rect.width, rect.height);
-                        }
-                        else {
-                           graphics2D.setBackground(backgroundColor);
+                        } else {
+                            graphics2D.setBackground(backgroundColor);
                         }
                         graphics2D.setRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING,
                                 RenderingHints.VALUE_TEXT_ANTIALIAS_ON);
@@ -272,7 +269,7 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
 
     public String getTooltipTextForLocation(int x, int y) {
 
-        List<MouseableRegion> mouseableRegions = TrackNamePanel.this.getTrackRegions();
+        List<MouseableRegion> mouseableRegions = TrackNamePanel.this.getMouseRegions();
 
         for (MouseableRegion mouseableRegion : mouseableRegions) {
             if (mouseableRegion.containsPoint(x, y)) {
@@ -293,7 +290,7 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
     }
 
     protected void shiftSelectTracks(MouseEvent e) {
-        for (MouseableRegion mouseRegion : trackRegions) {
+        for (MouseableRegion mouseRegion : mouseRegions) {
             if (mouseRegion.containsPoint(e.getX(), e.getY())) {
                 Collection<Track> clickedTracks = mouseRegion.getTracks();
                 if (clickedTracks != null && clickedTracks.size() > 0) {
@@ -347,10 +344,10 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
                 if (isGrouped) {
                     clearTrackSelections();
                     TrackGroup g = getGroup(e.getY());
-                    if (g == selectedGroup) {
+                    if (null == g || g == selectedGroup) {
                         selectedGroup = null;
                     } else {
-                        selectGroup(getGroup(e.getY()));
+                        selectGroup(g);
                     }
                 } else if (!isTrackSelected(e)) {
                     clearTrackSelections();
@@ -536,7 +533,7 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
 
                 @Override
                 public void run() {
-                    for (MouseableRegion mouseRegion : trackRegions) {
+                    for (MouseableRegion mouseRegion : mouseRegions) {
                         if (mouseRegion.containsPoint(e.getX(), e.getY())) {
                             for (Track t : mouseRegion.getTracks()) {
                                 t.handleNameClick(e);
@@ -595,7 +592,7 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
 
             // This cast is horrid but we can't fix everything at once.
             TrackPanel view = ((TrackPanel) getParent());
-            List<MouseableRegion> regions = getTrackRegions();
+            List<MouseableRegion> regions = getMouseRegions();
 
 
             // Find the regions containing the startPoint and point
@@ -634,8 +631,10 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
 
     private void selectGroup(TrackGroup group) {
         selectedGroup = group;
-        for (Track t : selectedGroup.getTracks()) {
-            t.setSelected(true);
+        if (selectedGroup != null) {
+            for (Track t : selectedGroup.getTracks()) {
+                t.setSelected(true);
+            }
         }
     }
 
