@@ -17,21 +17,11 @@
  */
 package org.broad.igv.util;
 
-import org.apache.log4j.Level;
 import org.apache.log4j.Logger;
-import org.apache.log4j.PatternLayout;
-import org.apache.log4j.RollingFileAppender;
-import org.broad.igv.Globals;
 import org.broad.igv.ui.util.MessageUtils;
 
 import java.io.*;
-import java.net.MalformedURLException;
-import java.net.Proxy;
-import java.net.URL;
-import java.net.URLConnection;
-import java.nio.ByteBuffer;
-import java.nio.CharBuffer;
-import java.nio.charset.CharacterCodingException;
+import java.net.*;
 import java.nio.charset.Charset;
 import java.nio.charset.CharsetDecoder;
 import java.util.HashMap;
@@ -46,12 +36,79 @@ public class FileUtils {
     private static Logger log = Logger.getLogger(FileUtils.class);
 
 
+    static Map<String, String> illegalChar = new HashMap();
+
+    static {
+        illegalChar.put("_qm_", "\\?");
+        illegalChar.put("_fbr_", "\\[");
+        illegalChar.put("_rbr_", "]");
+        illegalChar.put("_fsl_", "/");
+        illegalChar.put("_bsl_", "\\\\");
+        illegalChar.put("_eq_", "=");
+        illegalChar.put("_pl_", "\\+");
+        illegalChar.put("_lt_", "<");
+        illegalChar.put("_gt_", ">");
+        illegalChar.put("_co_", ":");
+        illegalChar.put("_sc_", ";");
+        illegalChar.put("_dq_", "\"");
+        illegalChar.put("_sq_", "'");
+        illegalChar.put("_st_", "\\*");
+        illegalChar.put("_pp_", "\\|");
+    }
+
+    public static void main(String [] args) throws IOException {
+        File inputDirectory = new File(args[0]);
+        File outputDirectory = new File(args[1]);
+        searchAndReplace(inputDirectory, outputDirectory, args[2], args[3]);
+    }
+
+    /**
+     * Replace all occurences of str1 with str2 in all files in inputDirectory.  Write the modified files
+     * to outputDirectory.  Note: assumption is all files are text.
+     *
+     * @param inputDirectory
+     * @param outputDirectory
+     * @param str1
+     * @param str2
+     */
+    public static void searchAndReplace(File inputDirectory, File outputDirectory,  String str1, String str2)
+            throws IOException {
+
+        for(File in : inputDirectory.listFiles()) {
+            if(!in.isDirectory() && !in.isHidden()) {
+
+                File of = new File(outputDirectory, in.getName());
+                BufferedReader reader = null;
+                PrintWriter pw = null;
+
+                try {
+                    reader = new BufferedReader(new FileReader(in));
+                    pw = new PrintWriter(new BufferedWriter(new FileWriter(of)));
+                    String nextLine;
+                    while((nextLine = reader.readLine()) != null) {
+                        nextLine = nextLine.replaceAll(str1, str2);
+                        pw.println(nextLine);
+                    }
+                }
+                finally {
+                    reader.close();
+                    pw.close();
+
+                }
+
+
+
+            }
+        }
+
+    }
+
     public static boolean resourceExists(String path) {
         try {
             boolean remoteFile = isRemote(path);
             // TODO -- what if its ftp?
             return (!remoteFile && (new File(path).exists())) ||
-                    (remoteFile && IGVHttpClientUtils.resourceAvailable(new URL(path)));
+                    (remoteFile && HttpUtils.getInstance().resourceAvailable(new URL(path)));
         } catch (IOException e) {
             log.error("Malformed URL: " + path, e);
             return false;
@@ -59,7 +116,8 @@ public class FileUtils {
     }
 
 
-    public static boolean isRemote(String path) {
+    public static boolean isRemote(String p) {
+        String path = URLDecoder.decode(p);
         return path.startsWith("http://") || path.startsWith("https://") || path.startsWith("ftp://");
     }
 
@@ -90,7 +148,6 @@ public class FileUtils {
         } else {
             return f.getParentFile().getAbsolutePath();
         }
-
     }
 
     static public String getRelativePath(File baseFile, String targetFile) {
@@ -253,19 +310,15 @@ public class FileUtils {
             br.close();
             pw.close();
 
-        }
-        catch (Exception e) {
+        } catch (Exception e) {
             e.printStackTrace();
-        }
-        finally {
+        } finally {
 
         }
     }
 
     /**
      * Test to see if a file is ascii by sampling the first few bytes.  Not perfect (obviously) but usually works
-     *
-
      */
     public static boolean isAscii(ResourceLocator loc) throws IOException {
 
@@ -281,14 +334,14 @@ public class FileUtils {
                 for (int i = 0; i < nBytes; i++) {
                     int j = (int) bytes[i];
                     if (j < 1 || j > 127) {
-                    return false;
-                }
+                        return false;
+                    }
                 }
                 nBytes = in.read(bytes);
             }
             return true;
         } finally {
-            if(in != null) {
+            if (in != null) {
                 in.close();
             }
         }
@@ -297,7 +350,6 @@ public class FileUtils {
 
     /**
      * Test to see if the ascii file is tab delimited.  Samples first 5 non-comment (lines starting with #) lines
-     * 
      */
     public static boolean isTabDelimited(ResourceLocator loc, int minColumnCount) throws IOException {
 
@@ -307,26 +359,25 @@ public class FileUtils {
             reader = ParsingUtils.openBufferedReader(loc.getPath());
             int nLinesTested = 0;
             String nextLine;
-            while((nextLine = reader.readLine()) != null && nLinesTested < 5) {
-                if(nextLine.startsWith("#")) {
+            while ((nextLine = reader.readLine()) != null && nLinesTested < 5) {
+                if (nextLine.startsWith("#")) {
                     continue;
                 }
                 nLinesTested++;
-                String [] tokens = nextLine.split("\t");
-                if(tokens.length >= minColumnCount) {
+                String[] tokens = nextLine.split("\t");
+                if (tokens.length >= minColumnCount) {
                     return true;
                 }
             }
             return nLinesTested > 1;
         } finally {
-            if(reader != null) {
+            if (reader != null) {
                 reader.close();
             }
         }
     }
 
 
-
     /**
      * Create a file from an input stream.
      *
@@ -351,16 +402,12 @@ public class FileUtils {
                 totalSize += bytes_read;
             }
 
-        }
-
-
-        catch (Exception e) {
+        } catch (Exception e) {
             outputFile.delete();
             MessageUtils.showMessage("<html>Error copying file: " + outputFile.getAbsoluteFile() +
                     "<br/>" + e.toString());
 
-        }
-        finally {
+        } finally {
             if (in != null) {
                 in.close();
             }
@@ -388,8 +435,7 @@ public class FileUtils {
                 writer.println(nextLine);
             }
 
-        }
-        finally {
+        } finally {
             reader.close();
             writer.close();
 
@@ -397,25 +443,6 @@ public class FileUtils {
     }
 
 
-    static Map<String, String> illegalChar = new HashMap();
-
-    static {
-        illegalChar.put("_qm_", "\\?");
-        illegalChar.put("_fbr_", "\\[");
-        illegalChar.put("_rbr_", "]");
-        illegalChar.put("_fsl_", "/");
-        illegalChar.put("_bsl_", "\\\\");
-        illegalChar.put("_eq_", "=");
-        illegalChar.put("_pl_", "\\+");
-        illegalChar.put("_lt_", "<");
-        illegalChar.put("_gt_", ">");
-        illegalChar.put("_co_", ":");
-        illegalChar.put("_sc_", ";");
-        illegalChar.put("_dq_", "\"");
-        illegalChar.put("_sq_", "'");
-        illegalChar.put("_st_", "\\*");
-        illegalChar.put("_pp_", "\\|");
-    }
 
     static public String legalFileName(String string) {
         for (Map.Entry<String, String> entry : illegalChar.entrySet()) {
