@@ -32,13 +32,13 @@ public class LongRunningTask implements Callable {
 
     private static Logger log = Logger.getLogger(LongRunningTask.class);
 
-    private static ExecutorService threadExecutor = Executors.newFixedThreadPool(3);
+    private static ExecutorService threadExecutor = Executors.newFixedThreadPool(10);
     private static ScheduledExecutorService schedule = Executors.newScheduledThreadPool(1);
 
     NamedRunnable runnable;
 
     public static Future submit(NamedRunnable runnable) {
-        if (Globals.batch || !IGV.getInstance().isStartupComplete()) {
+        if (Globals.isBatch() || !IGV.getInstance().isStartupComplete()) {
             log.debug("Running: " + runnable.getName());
             runnable.run();
             log.debug("Finished : " + runnable.getName());
@@ -69,7 +69,7 @@ public class LongRunningTask implements Callable {
 
         CursorToken token = WaitCursorManager.showWaitCursor();
         try {
-            log.debug("Running " + runnable.getName());
+            //log.info("Running " + runnable.getName());
             long t0 = System.currentTimeMillis();
             runnable.run();
             if (log.isDebugEnabled()) {
@@ -82,6 +82,7 @@ public class LongRunningTask implements Callable {
             return null;
         }
         finally {
+            //log.info("Removing wait cursor " + runnable.getName());
             WaitCursorManager.removeWaitCursor(token);
         }
 
