@@ -20,9 +20,6 @@ package org.broad.igv.util;
 //~--- non-JDK imports --------------------------------------------------------
 
 import org.apache.log4j.Logger;
-import org.broad.igv.feature.Exon;
-import org.broad.igv.feature.IGVFeature;
-import org.broad.igv.feature.Strand;
 import org.broad.igv.renderer.*;
 import org.broad.igv.track.TrackProperties;
 import org.broad.igv.track.WindowFunction;
@@ -44,13 +41,14 @@ public class ParsingUtils {
 
     private static Logger log = Logger.getLogger(ParsingUtils.class);
 
-    public static BufferedReader openBufferedReader(String pathOrUrl)
-            throws FileNotFoundException, IOException {
-        BufferedReader reader = null;
 
-        if (IGVHttpClientUtils.isURL(pathOrUrl)) {
+    public static BufferedReader openBufferedReader(String pathOrUrl) throws IOException {
+
+        BufferedReader reader;
+
+        if (HttpUtils.getInstance().isURL(pathOrUrl)) {
             URL url = new URL(pathOrUrl);
-            reader = new BufferedReader(new InputStreamReader(IGVHttpClientUtils.openConnectionStream(url)));
+            reader = new BufferedReader(new InputStreamReader(HttpUtils.getInstance().openConnectionStream(url)));
         } else {
             File file = new File(pathOrUrl);
 
@@ -89,7 +87,7 @@ public class ParsingUtils {
             long contentLength = -1;
             if (path.startsWith("http:") || path.startsWith("https:")) {
                 URL url = new URL(path);
-                contentLength = IGVHttpClientUtils.getContentLength(url);
+                contentLength = HttpUtils.getInstance().getContentLength(url);
 
             } else if (path.startsWith("ftp:")) {
                 // Use JDK url
@@ -149,35 +147,18 @@ public class ParsingUtils {
 
     }
 
-    /**
-     * Method description
-     *
-     * @param locator
-     * @return
-     * @throws FileNotFoundException
-     * @throws IOException
-     */
-    public static AsciiLineReader openAsciiReader(ResourceLocator locator)
-            throws IOException {
+    public static AsciiLineReader openAsciiReader(ResourceLocator locator) throws IOException {
         InputStream stream = openInputStream(locator);
         return new AsciiLineReader(stream);
 
     }
 
-    /**
-     * Method description
-     *
-     * @param locator
-     * @return
-     * @throws FileNotFoundException
-     * @throws IOException
-     */
-    public static InputStream openInputStream(ResourceLocator locator)
-            throws IOException {
+
+    public static InputStream openInputStream(ResourceLocator locator) throws IOException {
 
         if (locator.getServerURL() != null) {
             URL url = new URL(locator.getServerURL() + "?method=getContents&file=" + locator.getPath());
-            InputStream is = IGVHttpClientUtils.openConnectionStream(url);
+            InputStream is = HttpUtils.getInstance().openConnectionStream(url);
 
             // Note -- assumption that url stream is compressed!
             try {
@@ -193,9 +174,9 @@ public class ParsingUtils {
         } else {
 
             InputStream inputStream = null;
-            if (IGVHttpClientUtils.isURL(locator.getPath())) {
+            if (HttpUtils.getInstance().isURL(locator.getPath())) {
                 URL url = new URL(locator.getPath());
-                inputStream = IGVHttpClientUtils.openConnectionStream(url);
+                inputStream = HttpUtils.getInstance().openConnectionStream(url);
             } else {
                 String path = locator.getPath();
                 if (path.startsWith("file://")) {
@@ -229,12 +210,11 @@ public class ParsingUtils {
         int nTokens = 0;
         int start = 0;
         int end = aString.indexOf(delim);
-        if(end == 0) {
-            if(aString.length() > 1) {
+        if (end == 0) {
+            if (aString.length() > 1) {
                 start = 1;
                 end = aString.indexOf(delim, start);
-            }
-            else {
+            } else {
                 return 0;
             }
         }
@@ -429,33 +409,6 @@ public class ParsingUtils {
         }
     }
 
-    /**
-     * Method description
-     *
-     * @param gene
-     */
-    public static void computeReadingShifts(IGVFeature gene) {
-        List<Exon> exons = gene.getExons();
-        if (exons.size() == 0) {
-            return;
-        }
-
-        int startIndex = (gene.getStrand() == Strand.POSITIVE) ? 0 : exons.size() - 1;
-        int endIndex = (gene.getStrand() == Strand.POSITIVE) ? exons.size() : -1;
-        int increment = (gene.getStrand() == Strand.POSITIVE) ? 1 : -1;
-        int cds = 0;
-        int exonNumber = 1;
-        for (int i = startIndex; i != endIndex; i += increment) {
-            Exon exon = exons.get(i);
-            exon.setNumber(exonNumber);
-            int modCds = cds % 3;
-            int phase = (modCds == 0) ? 0 : 3 - modCds;
-            exon.setPhase(phase);
-            cds += exon.getCodingLength();
-            exonNumber++;
-        }
-    }
-
 
     /**
      * graphType         bar|points           # default is bar
@@ -500,8 +453,7 @@ public class ParsingUtils {
                     } else if (key.equals("description")) {
                         trackProperties.setDescription(value);
                     } else if (key.equals("itemrgb")) {
-                        trackProperties.setItemRGB(value.toLowerCase().equals("on") ||
-                                value.equals("1"));
+                        trackProperties.setItemRGB(value.toLowerCase().equals("on") || value.equals("1"));
                     } else if (key.equals("usescore")) {
                         trackProperties.setUseScore(value.equals("1"));
                     } else if (key.equals("color")) {
@@ -517,11 +469,15 @@ public class ParsingUtils {
                         boolean autoscale = value.equals("on");
                         trackProperties.setAutoScale(autoscale);
                     } else if (key.equals("maxheightpixels")) {
-
-                        // Ignore the min and max
+                        // There should be 3 values per UCSC spec,  max:default:min.  In the past we have accepted
+                        // 2 values,  def:min,  so keep this for backwards compatibility.   IGV currently doesn't
+                        // have a "max height"
                         String[] maxDefMin = value.split(":");
-                        trackProperties.setMinHeight(Integer.parseInt(maxDefMin[1].trim()));
-                        trackProperties.setHeight(Integer.parseInt(maxDefMin[0].trim()));
+                        if (maxDefMin.length >= 2) {
+                            int defIDX = (maxDefMin.length == 2 ? 0 : 1);
+                            trackProperties.setHeight(Integer.parseInt(maxDefMin[defIDX].trim()));
+                            trackProperties.setMinHeight(Integer.parseInt(maxDefMin[defIDX + 1].trim()));
+                        }
 
                     } else if (key.equals("url")) {
                         trackProperties.setUrl(value);
@@ -618,13 +574,13 @@ public class ParsingUtils {
                         // Any value other than 0 or off => on
                         boolean sortable = (value.equals("1") || (value.toLowerCase().equals("true")));
                         trackProperties.setSortable(sortable);
+                    } else if (key.equals("alternateexoncolor")) {
+                        trackProperties.setAlternateExonColor(value.toLowerCase().equals("on") || value.equals("1"));
                     }
                 }
             }
 
-        }
-
-        catch (
+        } catch (
                 Exception exception
                 )
 
@@ -636,13 +592,39 @@ public class ParsingUtils {
 
     }
 
+
     public static boolean pathExists(String covPath) {
         try {
             return (new File(covPath)).exists() ||
-                    (IGVHttpClientUtils.isURL(covPath) && IGVHttpClientUtils.resourceAvailable(new URL(covPath)));
+                    (HttpUtils.getInstance().isURL(covPath) && HttpUtils.getInstance().resourceAvailable(new URL(covPath)));
         } catch (MalformedURLException e) {
             // todo -- log
             return false;
         }
     }
+
+    /**
+     * Return the contents of the resource at path as a byte array
+     *
+     * @param path
+     * @return
+     * @throws IOException
+     */
+    public static byte[] readAll(String path) throws IOException {
+        InputStream is = null;
+        try {
+            byte [] buffer = new byte[100000];
+            ByteArrayOutputStream bos = new ByteArrayOutputStream(1000000);
+            is = openInputStream(new ResourceLocator(path));
+            int nRead;
+            while((nRead = is.read(buffer)) >= 0) {
+                bos.write(buffer, 0, nRead);
+            }
+            return bos.toByteArray();
+        } finally {
+            is.close();
+        }
+
+
+    }
 }
