@@ -1,5 +1,7 @@
 package org.broad.tribble;
 
+import java.io.File;
+
 /**
  * Created by IntelliJ IDEA.
  * User: jrobinso
@@ -9,5 +11,6 @@ package org.broad.tribble;
  */
 public abstract class AbstractFeatureCodec<T extends Feature> implements FeatureCodec {
 
+    public boolean canDecode(final String path) { return false; }
 
 }
