@@ -20,6 +20,8 @@ package org.broad.tribble;
 
 import org.broad.tribble.readers.LineReader;
 
+import java.io.File;
+
 /**
  * the base interface for classes that read in features.
  * @param <T> The feature type this codec reads
@@ -59,4 +61,19 @@ public interface FeatureCodec<T extends Feature> {
      * @return header object
      */
     public Object readHeader(LineReader reader);
+
+    /**
+     * This function returns true iff the File potentialInput can be parsed by this
+     * codec.
+     *
+     * There is an assumption that there's never a situation where two different Codecs
+     * return true for the same file.  If this occurs, the recommendation would be to error out.
+     *
+     * Note this function must never throw an error.  All errors should be trapped
+     * and false returned.
+     *
+     * @param path the file to test for parsability with this codec
+     * @return true if potentialInput can be parsed, false otherwise
+     */
+    public boolean canDecode(final String path);
 }
