@@ -13,6 +13,11 @@ import java.util.List;
 public interface ChrIndex {
 
     public String getName();
+
+    /**
+     * @return all blocks in ChrIndex
+     */
+    List<Block> getBlocks();
     
     List<Block> getBlocks(int start, int end);
 
