@@ -103,19 +103,31 @@ public class LinearIndex extends AbstractIndex implements Index {
     }
 
     @Override
-    public Class getIndexClass() {
+    public Class getChrIndexClass() {
         return ChrIndex.class;
     }
 
-    // by definition the parent class is going to test this all anyway.  No need to override
-//    @Override
-//    public boolean equalsIgnoreTimestamp(Object obj) {
-//        if ( this == obj ) return true;
-//        if ( ! (obj instanceof LinearIndex) ) return false;
-//        LinearIndex other = (LinearIndex)obj;
-//        return super.equalsIgnoreTimestamp(other);
-//    }
 
+    /**
+     * Blocks are organized as a simple flat list:
+     *
+     * Block 0
+     * Block 1
+     * Block 2
+     *
+     * There's a constant bin width, so that each block corresponds to a specific interval
+     * over the genome based on its index, as in:
+     *
+     * Block 0: (0 - binWidth]
+     * Block 1: (binWidth - 2 * binWidth]
+     * Block 2: (2 * binWidth - 3 * binWidth]
+     *
+     * Note that covered regions are open on the left ( and closed on the right ].
+     *
+     * In general, if block i is the ith block (starting from 0), then block i
+     * contains all records that have starting position > (i * binWidth) and
+     * <= ((i + 1) * binWidth))
+     */
     public static class ChrIndex implements org.broad.tribble.index.ChrIndex {
         private String name = "";
         private int binWidth;
@@ -159,20 +171,20 @@ public class LinearIndex extends AbstractIndex implements Index {
         }
 
         public List<Block> getBlocks(int start, int end) {
-            if (blocks == null || blocks.isEmpty()) {
-                // TODO -- throw exception ?
-                return null;
+            if ( blocks.isEmpty()) {
+                return Collections.emptyList();
+            } else {
+                // Adjust position for the longest feature in this chromosome.  This insures we get
+                // features that start before the bin but extend into it
+                int adjustedPosition = Math.max(start - longestFeature, 0);
+                int startBinNumber = adjustedPosition / binWidth;
+                if ( startBinNumber >= blocks.size() ) // are we off the end of the bin list, so return nothing
+                    return Collections.emptyList();
+                else {
+                    int endBinNumber = Math.min((end-1)/ binWidth, blocks.size() - 1);
+                    return blocks.subList(startBinNumber, endBinNumber + 1);
+                }
             }
-            // Adjust position for the longest feature in this chromosome.  This insures we get features that start
-            // before the bin but extend into it
-            int adjustedPosition = Math.max(start - longestFeature, 0);
-
-            int startBinNumber = Math.min(adjustedPosition / binWidth, blocks.size() - 1);
-            // are we off the end of the bin list
-
-            int endBinNumber = Math.min(end / binWidth, blocks.size() - 1);
-
-            return blocks.subList(startBinNumber, endBinNumber + 1);
         }
 
         public void updateLongestFeature(int featureLength) {
@@ -218,13 +230,9 @@ public class LinearIndex extends AbstractIndex implements Index {
             // largestBlockSize and totalBlockSize are old V3 index values.  largest block size should be 0 for
             // all newer V3 block.  This is a nasty hack that should be removed when we go to V4 (XML!) indices
             OLD_V3_INDEX = dis.readInt() > 0;
-//
-//            if ( OLD_V3_INDEX ) {
-//                log.info("OLD v3 index detected -- we be considered out of date");
-//            }
-
             nFeatures = dis.readInt();
 
+            // note the code below accounts for > 60% of the total time to read an index
             blocks = new ArrayList<Block>(nBins);
             long pos = dis.readLong();
             for (int binNumber = 0; binNumber < nBins; binNumber++) {
@@ -233,7 +241,6 @@ public class LinearIndex extends AbstractIndex implements Index {
                 blocks.add(new Block(pos, size));
                 pos = nextPos;
             }
-
         }
 
         public boolean equals(Object obj) {
@@ -397,5 +404,10 @@ public class LinearIndex extends AbstractIndex implements Index {
             }
         }
     }
+
+    // purely for testing purposes
+    protected final void setTS(long ts) {
+        this.indexedFileTS = ts;
+    }
 }
 
