@@ -104,7 +104,6 @@ public class SeekableHTTPStream extends SeekableStream {
 
 
         InputStream is = null;
-        String byteRange = "";
         int n = 0;
         try {
 
@@ -112,7 +111,7 @@ public class SeekableHTTPStream extends SeekableStream {
 
             // If we know the total content length, limit the byte-range requested
             if (contentLength > 0) {
-                if (position > contentLength) {
+                if (position >= contentLength) {
                     log.info("Warning: Unexpected postion value.  position=" + position + " contentLength=" + contentLength);
                     return -1;
                 }
@@ -122,7 +121,11 @@ public class SeekableHTTPStream extends SeekableStream {
                     len = (int) (end - position + 1);
                 }
             }
-            byteRange = "bytes=" + position + "-" + end;
+
+            if(len <= 0) {
+                return -1;
+            }
+
             is = helper.openInputStreamForRange(position, end);
 
             while (n < len) {
@@ -150,8 +153,8 @@ public class SeekableHTTPStream extends SeekableStream {
             //
             //  The BAM file iterator  uses the return value to detect end of file (specifically looks for n == 0).
             if (e.getMessage().contains("416") || (e instanceof EOFException)) {
-                log.error("Error: " + e.getMessage() + " encountered reading " + this.helper.getUrl() + ".  " + byteRange + "  " +
-                        "content-length=" + contentLength);
+                log.error("Error: " + e.getMessage() + " encountered reading " + this.helper.getUrl()   +
+                        " content-length=" + contentLength);
                 if (n < 0) {
                     return -1;
                 } else {
